@@ -20,7 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <ctype.h>
 #include <string.h>
 #include <gtk/gtk.h>
@@ -201,14 +204,19 @@ editor_closed_cb (GtkWidget *w, gpointer closure)
 }
 
 static void
-ce_have_contact (EBook *book, const GError *error, EContact *contact, gpointer closure)
+ce_have_contact (EBook *book,
+                 const GError *error,
+                 EContact *contact,
+                 gpointer closure)
 {
 	QuickAdd *qa = (QuickAdd *) closure;
 
 	if (error) {
 		if (book)
 			g_object_unref (book);
-		g_warning ("Failed to find contact, status %d (%s).", error->code, error->message);
+		g_warning (
+			"Failed to find contact, status %d (%s).",
+			error->code, error->message);
 		quick_add_unref (qa);
 	} else {
 		EShell *shell;
@@ -225,10 +233,10 @@ ce_have_contact (EBook *book, const GError *error, EContact *contact, gpointer c
 		contact_editor = e_contact_editor_new (
 			shell, book, qa->contact, TRUE, TRUE /* XXX */);
 
-		/* mark it as changed so the Save buttons are enabled when we bring up the dialog. */
-		g_object_set (contact_editor,
-				"changed", contact != NULL,
-				NULL);
+		/* Mark it as changed so the Save buttons are
+		 * enabled when we bring up the dialog. */
+		g_object_set (
+			contact_editor, "changed", contact != NULL, NULL);
 
 		/* We pass this via object data, so that we don't get a
 		 * dangling pointer referenced if both the "contact_added"
@@ -304,20 +312,21 @@ clicked_cb (GtkWidget *w, gint button, gpointer closure)
 		gchar *name = NULL;
 		gchar *email = NULL;
 
-		if (qa->name_entry) {
-			gchar *tmp;
-			tmp = gtk_editable_get_chars (GTK_EDITABLE (qa->name_entry), 0, -1);
-			name = tmp;
-		}
+		if (qa->name_entry)
+			name = gtk_editable_get_chars (
+				GTK_EDITABLE (qa->name_entry), 0, -1);
 
-		if (qa->email_entry) {
-			gchar *tmp;
-			tmp = gtk_editable_get_chars (GTK_EDITABLE (qa->email_entry), 0, -1);
-			email = tmp;
-		}
+		if (qa->email_entry)
+			email = gtk_editable_get_chars (
+				GTK_EDITABLE (qa->email_entry), 0, -1);
 
-		e_contact_set (qa->contact, E_CONTACT_FULL_NAME, (gpointer) (name ? name : ""));
-		e_contact_set (qa->contact, E_CONTACT_EMAIL_1,   (gpointer) (email ? email : ""));
+		e_contact_set (
+			qa->contact, E_CONTACT_FULL_NAME,
+			(name != NULL) ? name : "");
+
+		e_contact_set (
+			qa->contact, E_CONTACT_EMAIL_1,
+			(email != NULL) ? email : "");
 
 		g_free (name);
 		g_free (email);
@@ -441,7 +450,7 @@ build_quick_add_dialog (QuickAdd *qa)
 	gtk_table_set_col_spacings (table, 12);
 
 	label = gtk_label_new_with_mnemonic (_("_Full name"));
-	gtk_label_set_mnemonic_widget ((GtkLabel*)label, qa->name_entry);
+	gtk_label_set_mnemonic_widget ((GtkLabel*) label, qa->name_entry);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 
 	gtk_table_attach (table, label,
@@ -452,7 +461,7 @@ build_quick_add_dialog (QuickAdd *qa)
 			  GTK_EXPAND | GTK_FILL, 0, xpad, ypad);
 
 	label = gtk_label_new_with_mnemonic (_("E_mail"));
-	gtk_label_set_mnemonic_widget ((GtkLabel *)label, qa->email_entry);
+	gtk_label_set_mnemonic_widget ((GtkLabel *) label, qa->email_entry);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 
 	gtk_table_attach (table, label,
@@ -463,7 +472,7 @@ build_quick_add_dialog (QuickAdd *qa)
 			  GTK_EXPAND | GTK_FILL, 0, xpad, ypad);
 
 	label = gtk_label_new_with_mnemonic (_("_Select Address Book"));
-	gtk_label_set_mnemonic_widget ((GtkLabel *)label, qa->combo_box);
+	gtk_label_set_mnemonic_widget ((GtkLabel *) label, qa->combo_box);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 
 	gtk_table_attach (table, label,
@@ -673,7 +682,7 @@ e_contact_quick_add_vcard (const gchar *vcard,
 		if (emails) {
 			quick_add_set_email (qa, emails->data);
 
-			g_list_foreach (emails, (GFunc)g_free, NULL);
+			g_list_foreach (emails, (GFunc) g_free, NULL);
 			g_list_free (emails);
 		}
 	} else {
