@@ -20,7 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <string.h>
 #include <glib/gi18n.h>
 #include "e-addressbook-model.h"
@@ -392,19 +395,24 @@ addressbook_model_idle_cb (EAddressbookModel *model)
 		remove_book_view (model);
 
 		if (model->priv->first_get_view) {
+			gboolean do_initial_query;
+
 			model->priv->first_get_view = FALSE;
 
-			if (e_book_check_static_capability (model->priv->book, "do-initial-query")) {
+			do_initial_query = e_book_check_static_capability (
+				model->priv->book, "do-initial-query");
+
+			if (do_initial_query) {
 				e_book_get_book_view_async (
 					model->priv->book, model->priv->query,
 					NULL, limit, book_view_loaded, model);
 			} else {
 				free_data (model);
 
-				g_signal_emit (model,
-					       signals[MODEL_CHANGED], 0);
-				g_signal_emit (model,
-					       signals[STOP_STATE_CHANGED], 0);
+				g_signal_emit (
+					model, signals[MODEL_CHANGED], 0);
+				g_signal_emit (
+					model, signals[STOP_STATE_CHANGED], 0);
 			}
 		} else
 			e_book_get_book_view_async (
@@ -757,7 +765,8 @@ e_addressbook_model_stop (EAddressbookModel *model)
 	g_signal_emit (model, signals[STATUS_MESSAGE], 0, message);
 
 	if (!model->priv->remove_status_id)
-		model->priv->remove_status_id = g_timeout_add_seconds (3, remove_status_cb, model);
+		model->priv->remove_status_id =
+			g_timeout_add_seconds (3, remove_status_cb, model);
 }
 
 gboolean
