@@ -16,7 +16,10 @@
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <string.h>
 
 #include <glib/gi18n.h>
@@ -139,7 +142,7 @@ addressbook_height (EReflowModel *erm, gint i, GnomeCanvasGroup *parent)
 	EContactField field;
 	gint count = 0;
 	gchar *string;
-	EContact *contact = (EContact*)e_addressbook_model_contact_at (priv->model, i);
+	EContact *contact = (EContact*) e_addressbook_model_contact_at (priv->model, i);
 	PangoLayout *layout;
 	gint height;
 
@@ -197,11 +200,19 @@ addressbook_create_cmp_cache (EReflowModel *erm)
 	cmp_cache = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_free);
 
 	for (ii = 0; ii < count; ii++) {
-		EContact *contact = (EContact*) e_addressbook_model_contact_at (priv->model, ii);
-		if (contact) {
-			const gchar *file_as = e_contact_get_const (contact, E_CONTACT_FILE_AS);
-			if (file_as)
-				g_hash_table_insert (cmp_cache, GINT_TO_POINTER (ii), g_utf8_collate_key (file_as, -1));
+		EContact *contact;
+
+		contact  = (EContact *)
+			e_addressbook_model_contact_at (priv->model, ii);
+		if (contact != NULL) {
+			const gchar *file_as;
+
+			file_as = e_contact_get_const (
+				contact, E_CONTACT_FILE_AS);
+			if (file_as != NULL)
+				g_hash_table_insert (
+					cmp_cache, GINT_TO_POINTER (ii),
+					g_utf8_collate_key (file_as, -1));
 		}
 	}
 
@@ -219,8 +230,8 @@ addressbook_compare (EReflowModel *erm, gint n1, gint n2, GHashTable *cmp_cache)
 		return n1-n2;
 	}
 	else {
-		contact1 = (EContact*)e_addressbook_model_contact_at (priv->model, n1);
-		contact2 = (EContact*)e_addressbook_model_contact_at (priv->model, n2);
+		contact1 = (EContact*) e_addressbook_model_contact_at (priv->model, n1);
+		contact2 = (EContact*) e_addressbook_model_contact_at (priv->model, n2);
 
 		if (contact1 && contact2) {
 			const gchar *file_as1, *file_as2;
@@ -549,7 +560,8 @@ e_addressbook_reflow_adapter_get_type (void)
 			(GInstanceInitFunc) e_addressbook_reflow_adapter_init,
 		};
 
-		type = g_type_register_static (PARENT_TYPE, "EAddressbookReflowAdapter", &info, 0);
+		type = g_type_register_static (
+			PARENT_TYPE, "EAddressbookReflowAdapter", &info, 0);
 	}
 
 	return type;
