@@ -21,7 +21,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <glib/gi18n.h>
 #include <table/e-table.h>
@@ -59,10 +61,6 @@
 #include <ctype.h>
 #include <string.h>
 
-#define E_ADDRESSBOOK_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_ADDRESSBOOK_VIEW, EAddressbookViewPrivate))
-
 #define d(x)
 
 static void	status_message			(EAddressbookView *view,
@@ -262,7 +260,7 @@ table_drag_data_get (ETable *table,
 
 			gtk_selection_data_set (
 				selection_data, target, 8,
-				(guchar *)value, strlen (value));
+				(guchar *) value, strlen (value));
 
 			g_free (value);
 			break;
@@ -273,7 +271,7 @@ table_drag_data_get (ETable *table,
 
 			gtk_selection_data_set (
 				selection_data, target, 8,
-				(guchar *)value, strlen (value));
+				(guchar *) value, strlen (value));
 
 			g_free (value);
 			break;
@@ -498,7 +496,7 @@ addressbook_view_dispose (GObject *object)
 {
 	EAddressbookViewPrivate *priv;
 
-	priv = E_ADDRESSBOOK_VIEW_GET_PRIVATE (object);
+	priv = E_ADDRESSBOOK_VIEW (object)->priv;
 
 	if (priv->shell_view != NULL) {
 		g_object_remove_weak_pointer (
@@ -848,7 +846,8 @@ addressbook_view_init (EAddressbookView *view)
 {
 	GtkTargetList *target_list;
 
-	view->priv = E_ADDRESSBOOK_VIEW_GET_PRIVATE (view);
+	view->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		view, E_TYPE_ADDRESSBOOK_VIEW, EAddressbookViewPrivate);
 
 	view->priv->model = e_addressbook_model_new ();
 
@@ -1399,7 +1398,9 @@ e_addressbook_view_delete_selection (EAddressbookView *view, gboolean is_delete)
 		for (l=list;l;l=g_list_next (l)) {
 			contact = l->data;
 
-			ids = g_list_prepend (ids, (gchar *)e_contact_get_const (contact, E_CONTACT_UID));
+			ids = g_list_prepend (
+				ids, (gchar *) e_contact_get_const (
+				contact, E_CONTACT_UID));
 		}
 
 		/* Remove the cards all at once. */
