@@ -22,7 +22,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
@@ -32,6 +35,7 @@
 #include <glib/gstdio.h>
 
 #include <libebook/e-book.h>
+#include <libedataserverui/e-book-auth-util.h>
 #include <libedataserverui/e-source-selector.h>
 
 #include <libebook/e-destination.h>
@@ -312,7 +316,8 @@ date_from_string (const gchar *str)
 		date->day = str[i] - '0' * 1;
 		i = i+2;
 	}
-	date->year = str[i] * 1000 + str[i+1] * 100 + str[i+2] * 10 + str[i+3] - '0' * 1111;
+	date->year = str[i] * 1000 + str[i + 1] * 100 +
+		str[i + 2] * 10 + str[i + 3] - '0' * 1111;
 
 	return date;
 }
@@ -384,7 +389,9 @@ map_fields (const gchar *header_line, gint pimporter)
 	while (value = parseNextValue (&pptr), value != NULL) {
 		for (j = 0; j < n_fields; j++) {
 			if (g_ascii_strcasecmp (fields_array[j].csv_attribute, value->str) == 0) {
-				g_hash_table_insert (fmap, GINT_TO_POINTER (idx), GINT_TO_POINTER (j + 1));
+				g_hash_table_insert (
+					fmap, GINT_TO_POINTER (idx),
+					GINT_TO_POINTER (j + 1));
 				any_found = TRUE;
 				break;
 			}
@@ -441,9 +448,12 @@ parseLine (CSVImporter *gci, EContact *contact, gchar *buf) {
 
 		idx = ii;
 		if (gci->fields_map) {
-			gpointer found = g_hash_table_lookup (gci->fields_map, GINT_TO_POINTER (idx));
+			gpointer found;
 
-			if (!found) {
+			found = g_hash_table_lookup (
+				gci->fields_map, GINT_TO_POINTER (idx));
+
+			if (found == NULL) {
 				g_warning ("%s: No map for index %d, skipping it", G_STRFUNC, idx);
 				idx = -1;
 			} else {
@@ -558,11 +568,17 @@ parseLine (CSVImporter *gci, EContact *contact, gchar *buf) {
 					break;
 
 				case FLAG_DATE_BDAY:
-					e_contact_set (contact, E_CONTACT_BIRTH_DATE, date_from_string (value->str));
+					e_contact_set (
+						contact,
+						E_CONTACT_BIRTH_DATE,
+						date_from_string (value->str));
 					break;
 
 				case FLAG_DATE_ANNIVERSARY:
-					e_contact_set (contact, E_CONTACT_ANNIVERSARY, date_from_string (value->str));
+					e_contact_set (
+						contact,
+						E_CONTACT_ANNIVERSARY,
+						date_from_string (value->str));
 					break;
 
 				case FLAG_BIRTH_DAY:
@@ -780,7 +796,7 @@ csv_supported (EImport *ei, EImportTarget *target, EImportImporter *im)
 	if (target->type != E_IMPORT_TARGET_URI)
 		return FALSE;
 
-	s = (EImportTargetURI *)target;
+	s = (EImportTargetURI *) target;
 	if (s->uri_src == NULL)
 		return TRUE;
 
@@ -826,11 +842,26 @@ csv_import_done (CSVImporter *gci)
 	g_free (gci);
 }
 
+static void
+book_loaded_cb (ESource *source,
+                GAsyncResult *result,
+                CSVImporter *gci)
+{
+	gci->book = e_load_book_source_finish (source, result, NULL);
+
+	if (gci->book == NULL) {
+		csv_import_done (gci);
+		return;
+	}
+
+	gci->idle_id = g_idle_add (csv_import_contacts, gci);
+}
+
 static void
 csv_import (EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	CSVImporter *gci;
-	EBook *book;
+	ESource *source;
 	gchar *filename;
 	FILE *file;
 	EImportTargetURI *s = (EImportTargetURI *) target;
@@ -841,20 +872,11 @@ csv_import (EImport *ei, EImportTarget *target, EImportImporter *im)
 		return;
 	}
 
-	book = e_book_new(g_datalist_get_data(&target->data, "csv-source"), NULL);
-	if (book == NULL) {
-		g_message("Couldn't Create EBook");
-		e_import_complete (ei, target);
-		g_free (filename);
-		return;
-	}
-
 	file = g_fopen (filename, "r");
 	g_free (filename);
 	if (file == NULL) {
 		g_message("Can't open .csv file");
 		e_import_complete (ei, target);
-		g_object_unref (book);
 		return;
 	}
 
@@ -862,7 +884,6 @@ csv_import (EImport *ei, EImportTarget *target, EImportImporter *im)
 	g_datalist_set_data(&target->data, "csv-data", gci);
 	gci->import = g_object_ref (ei);
 	gci->target = target;
-	gci->book = book;
 	gci->file = file;
 	gci->fields_map = NULL;
 	gci->count = 0;
@@ -870,9 +891,11 @@ csv_import (EImport *ei, EImportTarget *target, EImportImporter *im)
 	gci->size = ftell (file);
 	fseek (file, 0, SEEK_SET);
 
-	e_book_open (gci->book, FALSE, NULL);
+	source = g_datalist_get_data (&target->data, "csv-source");
 
-	gci->idle_id = g_idle_add (csv_import_contacts, gci);
+	e_load_book_source_async (
+		source, NULL, NULL, (GAsyncReadyCallback)
+		book_loaded_cb, gci);
 }
 
 static void
@@ -910,7 +933,7 @@ csv_get_preview (EImport *ei, EImportTarget *target, EImportImporter *im)
 	GtkWidget *preview;
 	GList *contacts = NULL;
 	EContact *contact;
-	EImportTargetURI *s = (EImportTargetURI *)target;
+	EImportTargetURI *s = (EImportTargetURI *) target;
 	gchar *filename;
 	FILE *file;
 	CSVImporter *gci;
