@@ -255,7 +255,7 @@ parseLine (GHashTable *dn_contact_hash, EContact *contact,
 		return FALSE;
 	}
 
-	colon = (gchar *)strchr ( ptr, ':' );
+	colon = (gchar *) strchr ( ptr, ':' );
 	if (colon) {
 		gint i;
 
@@ -302,7 +302,10 @@ parseLine (GHashTable *dn_contact_hash, EContact *contact,
 				}
 				else {
 					/* FIXME is everything a string? */
-					e_contact_set (contact, ldif_fields[i].contact_field, ldif_value->str);
+					e_contact_set (
+						contact,
+						ldif_fields[i].contact_field,
+						ldif_value->str);
 					g_message ("set %s to %s", ptr, ldif_value->str);
 				}
 				field_handled = TRUE;
@@ -432,7 +435,8 @@ resolve_list_card (LDIFImporter *gci, EContact *contact)
 			EDestination *dest;
 			EVCardAttribute *attr = e_vcard_attribute_new (NULL, EVC_EMAIL);
 
-			/* Hard-wired for default e-mail, since netscape only exports 1 email address */
+			/* Hard-wired for default e-mail, since
+			 * netscape only exports 1 email address. */
 			dest = e_destination_new ();
 			e_destination_set_contact (dest, dn_contact, 0);
 
@@ -588,7 +592,7 @@ ldif_supported (EImport *ei, EImportTarget *target, EImportImporter *im)
 	if (target->type != E_IMPORT_TARGET_URI)
 		return FALSE;
 
-	s = (EImportTargetURI *)target;
+	s = (EImportTargetURI *) target;
 	if (s->uri_src == NULL)
 		return TRUE;
 
@@ -648,7 +652,7 @@ ldif_import (EImport *ei, EImportTarget *target, EImportImporter *im)
 	LDIFImporter *gci;
 	ESource *source;
 	FILE *file = NULL;
-	EImportTargetURI *s = (EImportTargetURI *)target;
+	EImportTargetURI *s = (EImportTargetURI *) target;
 	gchar *filename;
 
 	filename = g_filename_from_uri (s->uri_src, NULL, NULL);
@@ -697,7 +701,7 @@ ldif_get_preview (EImport *ei, EImportTarget *target, EImportImporter *im)
 	GtkWidget *preview;
 	GList *contacts = NULL;
 	EContact *contact;
-	EImportTargetURI *s = (EImportTargetURI *)target;
+	EImportTargetURI *s = (EImportTargetURI *) target;
 	gchar *filename;
 	GHashTable *dn_contact_hash;
 	FILE *file;
