@@ -36,6 +36,7 @@
 #include <glib/gstdio.h>
 
 #include <libebook/e-book.h>
+#include <libedataserverui/e-book-auth-util.h>
 #include <libedataserverui/e-source-selector.h>
 
 #include <util/eab-book-util.h>
@@ -47,6 +48,15 @@
 
 #include "evolution-addressbook-importers.h"
 
+enum _VCardEncoding {
+	VCARD_ENCODING_NONE,
+	VCARD_ENCODING_UTF8,
+	VCARD_ENCODING_UTF16,
+	VCARD_ENCODING_LOCALE
+};
+
+typedef enum _VCardEncoding VCardEncoding;
+
 typedef struct {
 	EImport *import;
 	EImportTarget *target;
@@ -62,9 +72,13 @@ typedef struct {
 	GList *contactlist;
 	GList *iterator;
 	EBook *book;
+
+	/* when opening book */
+	gchar *contents;
+	VCardEncoding encoding;
 } VCardImporter;
 
-static void vcard_import_done(VCardImporter *gci);
+static void vcard_import_done (VCardImporter *gci);
 
 static void
 add_to_notes (EContact *contact, EContactField field)
@@ -91,7 +105,7 @@ add_to_notes (EContact *contact, EContactField field)
 }
 
 static void
-vcard_import_contact(VCardImporter *gci, EContact *contact)
+vcard_import_contact (VCardImporter *gci, EContact *contact)
 {
 	EContactPhoto *photo;
 	GList *attrs, *attr;
@@ -118,7 +132,7 @@ vcard_import_contact(VCardImporter *gci, EContact *contact)
 
 		if (v && v->data) {
 			if (!strncmp ((gchar *)v->data, "<?xml", 5)) {
-				EDestination *dest = e_destination_import ((gchar *)v->data);
+				EDestination *dest = e_destination_import ((gchar *) v->data);
 
 				e_destination_export_to_vcard_attribute (dest, a);
 
@@ -239,7 +253,7 @@ vcard_import_contact(VCardImporter *gci, EContact *contact)
 }
 
 static gboolean
-vcard_import_contacts(gpointer data)
+vcard_import_contacts (gpointer data)
 {
 	VCardImporter *gci = data;
 	gint count = 0;
@@ -247,7 +261,7 @@ vcard_import_contacts(gpointer data)
 
 	if (gci->state == 0) {
 		while (count < 50 && iterator) {
-			vcard_import_contact(gci, iterator->data);
+			vcard_import_contact (gci, iterator->data);
 			count++;
 			iterator = iterator->next;
 		}
@@ -257,7 +271,7 @@ vcard_import_contacts(gpointer data)
 			gci->state = 1;
 	}
 	if (gci->state == 1) {
-		vcard_import_done(gci);
+		vcard_import_done (gci);
 		return FALSE;
 	} else {
 		e_import_status (
@@ -320,15 +334,6 @@ utf16_to_utf8 (gunichar2 *utf16)
 	return g_utf16_to_utf8 (utf16, -1, NULL, NULL, NULL);
 }
 
-enum _VCardEncoding {
-	VCARD_ENCODING_NONE,
-	VCARD_ENCODING_UTF8,
-	VCARD_ENCODING_UTF16,
-	VCARD_ENCODING_LOCALE
-};
-
-typedef enum _VCardEncoding VCardEncoding;
-
 /* Actually check the contents of this file */
 static VCardEncoding
 guess_vcard_encoding (const gchar *filename)
@@ -352,8 +357,8 @@ guess_vcard_encoding (const gchar *filename)
 	}
 	fclose (handle);
 
-	if (has_bom ((gunichar2*)line)) {
-		gunichar2 *utf16 = (gunichar2*)line;
+	if (has_bom ((gunichar2*) line)) {
+		gunichar2 *utf16 = (gunichar2*) line;
 		/* Check for a BOM to try to detect UTF-16 encoded vcards
 		 * (MacOSX address book creates such vcards for example)
 		 */
@@ -385,12 +390,12 @@ static void
 primary_selection_changed_cb (ESourceSelector *selector, EImportTarget *target)
 {
 	g_datalist_set_data_full(&target->data, "vcard-source",
-				 g_object_ref(e_source_selector_peek_primary_selection(selector)),
+				 g_object_ref (e_source_selector_get_primary_selection (selector)),
 				 g_object_unref);
 }
 
 static GtkWidget *
-vcard_getwidget(EImport *ei, EImportTarget *target, EImportImporter *im)
+vcard_getwidget (EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	GtkWidget *vbox, *selector;
 	ESource *primary;
@@ -409,7 +414,7 @@ vcard_getwidget(EImport *ei, EImportTarget *target, EImportImporter *im)
 	primary = g_datalist_get_data(&target->data, "vcard-source");
 	if (primary == NULL) {
 		primary = e_source_list_peek_source_any (source_list);
-		g_object_ref(primary);
+		g_object_ref (primary);
 		g_datalist_set_data_full (
 			&target->data, "vcard-source", primary,
 			(GDestroyNotify) g_object_unref);
@@ -428,7 +433,7 @@ vcard_getwidget(EImport *ei, EImportTarget *target, EImportImporter *im)
 }
 
 static gboolean
-vcard_supported(EImport *ei, EImportTarget *target, EImportImporter *im)
+vcard_supported (EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	EImportTargetURI *s;
 	gchar *filename;
@@ -437,7 +442,7 @@ vcard_supported(EImport *ei, EImportTarget *target, EImportImporter *im)
 	if (target->type != E_IMPORT_TARGET_URI)
 		return FALSE;
 
-	s = (EImportTargetURI *)target;
+	s = (EImportTargetURI *) target;
 	if (s->uri_src == NULL)
 		return TRUE;
 
@@ -447,104 +452,115 @@ vcard_supported(EImport *ei, EImportTarget *target, EImportImporter *im)
 	filename = g_filename_from_uri (s->uri_src, NULL, NULL);
 	if (filename == NULL)
 		return FALSE;
-	retval = (guess_vcard_encoding(filename) != VCARD_ENCODING_NONE);
+	retval = (guess_vcard_encoding (filename) != VCARD_ENCODING_NONE);
 	g_free (filename);
 
 	return retval;
 }
 
 static void
-vcard_import_done(VCardImporter *gci)
+vcard_import_done (VCardImporter *gci)
 {
 	if (gci->idle_id)
-		g_source_remove(gci->idle_id);
+		g_source_remove (gci->idle_id);
 
+	g_free (gci->contents);
 	g_object_unref (gci->book);
 	g_list_foreach (gci->contactlist, (GFunc) g_object_unref, NULL);
 	g_list_free (gci->contactlist);
 
-	e_import_complete(gci->import, gci->target);
-	g_object_unref(gci->import);
+	e_import_complete (gci->import, gci->target);
+	g_object_unref (gci->import);
 	g_free (gci);
 }
 
 static void
-vcard_import(EImport *ei, EImportTarget *target, EImportImporter *im)
+book_loaded_cb (ESource *source,
+                GAsyncResult *result,
+                VCardImporter *gci)
 {
-	VCardImporter *gci;
-	gchar *contents;
-	VCardEncoding encoding;
-	EBook *book;
-	EImportTargetURI *s = (EImportTargetURI *)target;
-	gchar *filename;
+	gci->book = e_load_book_source_finish (source, result, NULL);
 
-	filename = g_filename_from_uri(s->uri_src, NULL, NULL);
-	if (filename == NULL) {
-		g_message(G_STRLOC ": Couldn't get filename from URI '%s'", s->uri_src);
-		e_import_complete(ei, target);
+	if (gci->book == NULL) {
+		vcard_import_done (gci);
 		return;
 	}
-	encoding = guess_vcard_encoding(filename);
+
+	if (gci->encoding == VCARD_ENCODING_UTF16) {
+		gchar *tmp;
+
+		gunichar2 *contents_utf16 = (gunichar2*) gci->contents;
+		tmp = utf16_to_utf8 (contents_utf16);
+		g_free (gci->contents);
+		gci->contents = tmp;
+	} else if (gci->encoding == VCARD_ENCODING_LOCALE) {
+		gchar *tmp;
+		tmp = g_locale_to_utf8 (gci->contents, -1, NULL, NULL, NULL);
+		g_free (gci->contents);
+		gci->contents = tmp;
+	}
+
+	gci->contactlist = eab_contact_list_from_string (gci->contents);
+	g_free (gci->contents);
+	gci->contents = NULL;
+	gci->iterator = gci->contactlist;
+	gci->total = g_list_length (gci->contactlist);
+
+	if (gci->iterator)
+		gci->idle_id = g_idle_add (vcard_import_contacts, gci);
+	else
+		vcard_import_done (gci);
+}
+
+static void
+vcard_import (EImport *ei, EImportTarget *target, EImportImporter *im)
+{
+	VCardImporter *gci;
+	ESource *source;
+	EImportTargetURI *s = (EImportTargetURI *) target;
+	gchar *filename;
+	gchar *contents;
+	VCardEncoding encoding;
+
+	filename = g_filename_from_uri (s->uri_src, NULL, NULL);
+	if (filename == NULL) {
+		g_message(G_STRLOC ": Couldn't get filename from URI '%s'", s->uri_src);
+		e_import_complete (ei, target);
+		return;
+	}
+	encoding = guess_vcard_encoding (filename);
 	if (encoding == VCARD_ENCODING_NONE) {
 		g_free (filename);
 		/* This check is superfluous, we've already
 		 * checked otherwise we can't get here ... */
-		e_import_complete(ei, target);
-		return;
-	}
-
-	book = e_book_new(g_datalist_get_data(&target->data, "vcard-source"), NULL);
-	if (book == NULL) {
-		g_message(G_STRLOC ":Couldn't create EBook.");
-		g_free (filename);
-		e_import_complete(ei, target);
+		e_import_complete (ei, target);
 		return;
 	}
 
 	if (!g_file_get_contents (filename, &contents, NULL, NULL)) {
 		g_message (G_STRLOC ":Couldn't read file.");
 		g_free (filename);
-		e_import_complete(ei, target);
-		g_object_unref(book);
+		e_import_complete (ei, target);
 		return;
 	}
 
 	g_free (filename);
-	gci = g_malloc0(sizeof(*gci));
+	gci = g_malloc0 (sizeof (*gci));
 	g_datalist_set_data(&target->data, "vcard-data", gci);
-	gci->import = g_object_ref(ei);
+	gci->import = g_object_ref (ei);
 	gci->target = target;
-	gci->book = book;
+	gci->encoding = encoding;
+	gci->contents = contents;
 
-	e_book_open (gci->book, FALSE, NULL);
+	source = g_datalist_get_data (&target->data, "vcard-source");
 
-	if (encoding == VCARD_ENCODING_UTF16) {
-		gchar *tmp;
-
-		gunichar2 *contents_utf16 = (gunichar2*)contents;
-		tmp = utf16_to_utf8 (contents_utf16);
-		g_free (contents);
-		contents = tmp;
-	} else if (encoding == VCARD_ENCODING_LOCALE) {
-		gchar *tmp;
-		tmp = g_locale_to_utf8 (contents, -1, NULL, NULL, NULL);
-		g_free (contents);
-		contents = tmp;
-	}
-
-	gci->contactlist = eab_contact_list_from_string (contents);
-	g_free (contents);
-	gci->iterator = gci->contactlist;
-	gci->total = g_list_length(gci->contactlist);
-
-	if (gci->iterator)
-		gci->idle_id = g_idle_add(vcard_import_contacts, gci);
-	else
-		vcard_import_done(gci);
+	e_load_book_source_async (
+		source, NULL, NULL, (GAsyncReadyCallback)
+		book_loaded_cb, gci);
 }
 
 static void
-vcard_cancel(EImport *ei, EImportTarget *target, EImportImporter *im)
+vcard_cancel (EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	VCardImporter *gci = g_datalist_get_data(&target->data, "vcard-data");
 
@@ -559,7 +575,7 @@ vcard_get_preview (EImport *ei, EImportTarget *target, EImportImporter *im)
 	GList *contacts;
 	gchar *contents;
 	VCardEncoding encoding;
-	EImportTargetURI *s = (EImportTargetURI *)target;
+	EImportTargetURI *s = (EImportTargetURI *) target;
 	gchar *filename;
 
 	filename = g_filename_from_uri (s->uri_src, NULL, NULL);
@@ -618,7 +634,7 @@ static EImportImporter vcard_importer = {
 };
 
 EImportImporter *
-evolution_vcard_importer_peek(void)
+evolution_vcard_importer_peek (void)
 {
 	vcard_importer.name = _("vCard (.vcf, .gcrd)");
 	vcard_importer.description = _("Evolution vCard Importer");
@@ -739,28 +755,40 @@ preview_contact (EWebViewPreview *preview, EContact *contact)
 				g_date_set_dmy (&gd, dt->day, dt->month, dt->year);
 				g_date_to_struct_tm (&gd, &tm);
 
-				value = e_datetime_format_format_tm ("addressbook", "table", DTFormatKindDate, &tm);
+				value = e_datetime_format_format_tm (
+					"addressbook", "table",
+					DTFormatKindDate, &tm);
 				if (value) {
-					e_web_view_preview_add_section (preview, e_contact_pretty_name (field), value);
+					e_web_view_preview_add_section (
+						preview,
+						e_contact_pretty_name (field),
+						value);
 					had_value = TRUE;
 				}
 
 				g_free (value);
 				e_contact_date_free (dt);
 			}
-		} else if (field == E_CONTACT_IS_LIST || field == E_CONTACT_WANTS_HTML || field == E_CONTACT_LIST_SHOW_ADDRESSES) {
+		} else if (field == E_CONTACT_IS_LIST ||
+			   field == E_CONTACT_WANTS_HTML ||
+			   field == E_CONTACT_LIST_SHOW_ADDRESSES) {
 			if (e_contact_get (contact, field)) {
-				e_web_view_preview_add_text (preview, e_contact_pretty_name (field));
+				e_web_view_preview_add_text (
+					preview, e_contact_pretty_name (field));
 				had_value = TRUE;
 			}
-		} else if (field == E_CONTACT_ADDRESS_HOME || field == E_CONTACT_ADDRESS_WORK || field == E_CONTACT_ADDRESS_OTHER) {
+		} else if (field == E_CONTACT_ADDRESS_HOME ||
+			   field == E_CONTACT_ADDRESS_WORK ||
+			   field == E_CONTACT_ADDRESS_OTHER) {
 			EContactAddress *addr = e_contact_get (contact, field);
 			if (addr) {
 				gboolean have = FALSE;
 
 				#define add_it(_what)	\
 					if (addr->_what && *addr->_what) {	\
-						e_web_view_preview_add_section (preview, have ? NULL : e_contact_pretty_name (field), addr->_what);	\
+						e_web_view_preview_add_section ( \
+							preview, have ? NULL : \
+							e_contact_pretty_name (field), addr->_what);	\
 						have = TRUE;	\
 						had_value = TRUE;	\
 					}
@@ -777,13 +805,20 @@ preview_contact (EWebViewPreview *preview, EContact *contact)
 
 				e_contact_address_free (addr);
 			}
-		} else if (field == E_CONTACT_IM_AIM || field == E_CONTACT_IM_GROUPWISE ||
-			   field == E_CONTACT_IM_JABBER || field == E_CONTACT_IM_YAHOO ||
-			   field == E_CONTACT_IM_MSN || field == E_CONTACT_IM_ICQ ||
-			   field == E_CONTACT_IM_GADUGADU || field == E_CONTACT_IM_SKYPE ||
+		} else if (field == E_CONTACT_IM_AIM ||
+			   field == E_CONTACT_IM_GROUPWISE ||
+			   field == E_CONTACT_IM_JABBER ||
+			   field == E_CONTACT_IM_YAHOO ||
+			   field == E_CONTACT_IM_MSN ||
+			   field == E_CONTACT_IM_ICQ ||
+			   field == E_CONTACT_IM_GADUGADU ||
+			   field == E_CONTACT_IM_SKYPE ||
 			   field == E_CONTACT_EMAIL) {
 			GList *attrs, *a;
 			gboolean have = FALSE;
+			const gchar *pretty_name;
+
+			pretty_name = e_contact_pretty_name (field);
 
 			attrs = e_contact_get_attributes (contact, field);
 			for (a = attrs; a; a = a->next) {
@@ -793,33 +828,50 @@ preview_contact (EWebViewPreview *preview, EContact *contact)
 				if (!attr)
 					continue;
 
-				for (value = e_vcard_attribute_get_values (attr); value; value = value->next) {
+				value = e_vcard_attribute_get_values (attr);
+
+				while (value != NULL) {
 					const gchar *str = value->data;
 
 					if (str && *str) {
-						e_web_view_preview_add_section (preview, have ? NULL : e_contact_pretty_name (field), str);
+						e_web_view_preview_add_section (
+							preview, have ? NULL :
+							pretty_name, str);
 						have = TRUE;
 						had_value = TRUE;
 					}
+
+					value = value->next;
 				}
+
 				e_vcard_attribute_free (attr);
 			}
 
 			g_list_free (attrs);
-		} else if (field == E_CONTACT_CATEGORIES) {
-			gchar *value = e_contact_get (contact, field);
 
-			if (value && *value) {
-				e_web_view_preview_add_section (preview, e_contact_pretty_name (field), value);
+		} else if (field == E_CONTACT_CATEGORIES) {
+			const gchar *pretty_name;
+			const gchar *value;
+
+			pretty_name = e_contact_pretty_name (field);
+			value = e_contact_get_const (contact, field);
+
+			if (value != NULL && *value != '\0') {
+				e_web_view_preview_add_section (
+					preview, pretty_name, value);
 				had_value = TRUE;
 			}
 
-			g_free (value);
 		} else {
-			const gchar *value = e_contact_get_const (contact, field);
+			const gchar *pretty_name;
+			const gchar *value;
 
-			if (value && *value) {
-				e_web_view_preview_add_section (preview, e_contact_pretty_name (field), value);
+			pretty_name = e_contact_pretty_name (field);
+			value = e_contact_get_const (contact, field);
+
+			if (value != NULL && *value != '\0') {
+				e_web_view_preview_add_section (
+					preview, pretty_name, value);
 				had_value = TRUE;
 			}
 		}
@@ -884,7 +936,9 @@ evolution_contact_importer_get_preview_widget (const GList *contacts)
 			if (description) {
 				const gchar *at = strchr (description, '@');
 				if (at) {
-					free_description = g_strndup (description, (gsize)(at - description));
+					free_description = g_strndup (
+						description,
+						(gsize) (at - description));
 					description = free_description;
 				}
 			}
@@ -921,7 +975,9 @@ evolution_contact_importer_get_preview_widget (const GList *contacts)
 
 	selection = gtk_tree_view_get_selection (tree_view);
 	gtk_tree_selection_select_iter (selection, &iter);
-	g_signal_connect (selection, "changed", G_CALLBACK (preview_selection_changed_cb), preview);
+	g_signal_connect (
+		selection, "changed",
+		G_CALLBACK (preview_selection_changed_cb), preview);
 
 	preview_selection_changed_cb (selection, E_WEB_VIEW_PREVIEW (preview));
 
