@@ -19,7 +19,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <ctype.h>
 #include <sys/types.h>
@@ -507,7 +509,7 @@ e_contact_build_style (EContactPrintStyle *style)
 		xmlNodePtr stylenode = xmlDocGetRootElement (styledoc);
 		xmlNodePtr node;
 		for (node = stylenode->children; node; node = node->next) {
-			gchar *data = (gchar *)xmlNodeGetContent ( node );
+			gchar *data = (gchar *) xmlNodeGetContent ( node );
 			if (!strcmp( (gchar *)node->name, "title" )) {
 				get_string (data, &(style->title));
 			} else if (!strcmp( (gchar *)node->name, "type" )) {
@@ -650,7 +652,8 @@ contact_draw (EContact *contact,
 		if (!ctxt->first_contact) {
 			if (ctxt->style->sections_start_new_page)
 				e_contact_start_new_page (ctxt);
-			else if ((ctxt->y + e_contact_get_contact_height (contact, ctxt)) > page_height)
+			else if ((ctxt->y + e_contact_get_contact_height (
+					contact, ctxt)) > page_height)
 				e_contact_start_new_column (ctxt);
 		}
 		if (ctxt->style->letter_headings)
