@@ -20,10 +20,11 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <string.h>
-#include <glib.h>
 #include <glib/gi18n.h>
 
 #include <libebook/e-book.h>
