@@ -21,12 +21,13 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include "eab-book-util.h"
 
 #include <string.h>
-#include <glib.h>
-#include <glib-object.h>
 
 /*
  *
@@ -193,7 +194,7 @@ eab_contact_list_from_string (const gchar *str)
 	GList *contacts = NULL;
 	GString *gstr = g_string_new (NULL);
 	gchar *str_stripped;
-	gchar *p = (gchar *)str;
+	gchar *p = (gchar *) str;
 	gchar *q;
 
 	if (!p)
