@@ -22,7 +22,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <glib/gi18n.h>
@@ -123,7 +126,7 @@ an_update_days_label (GtkSpinButton *sb, gpointer data)
 	an = (AlarmNotify *) data;
 
 	snooze_timeout_days  = gtk_spin_button_get_value_as_int (sb);
-	gtk_label_set_text (GTK_LABEL (an->days_label), ngettext ("days", "days", snooze_timeout_days));
+	gtk_label_set_text (GTK_LABEL (an->days_label), ngettext ("day", "days", snooze_timeout_days));
 }
 
 static void
@@ -141,20 +144,18 @@ dialog_response_cb (GtkDialog *dialog, guint response_id, gpointer user_data)
 
 	if (!funcinfo) {
 		GtkTreeModel *treemodel = gtk_tree_view_get_model (GTK_TREE_VIEW (an->treeview));
-		if (!gtk_tree_model_get_iter_first (treemodel, &iter))
-			return;
-
+		gtk_tree_model_get_iter_first (treemodel, &iter);
 		gtk_tree_model_get (treemodel, &iter, ALARM_FUNCINFO_COLUMN, &funcinfo, -1);
 	}
-
 	g_return_if_fail (funcinfo);
-
 	switch (response_id) {
 	case GTK_RESPONSE_CLOSE:
 	case GTK_RESPONSE_DELETE_EVENT:
 		(* funcinfo->func) (ALARM_NOTIFY_CLOSE, -1, funcinfo->func_data);
 		break;
 	}
+
+	return;
 }
 
 static void
