@@ -27,7 +27,6 @@
 #endif
 
 #include <string.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
@@ -187,10 +186,11 @@ create_thread_pool (void)
 static void
 message_push (Message *msg)
 {
-	/* This used be pushed through the thread pool. This fix is made to work-around
-	the crashers in dbus due to threading. The threading is not completely removed as
-	its better to have alarm daemon running in a thread rather than blocking main thread.
-	 This is the reason the creation of thread pool is commented out */
+	/* This used be pushed through the thread pool. This fix is made to
+	 * work-around the crashers in dbus due to threading. The threading
+	 * is not completely removed as its better to have alarm daemon
+	 * running in a thread rather than blocking main thread.  This is
+	 * the reason the creation of thread pool is commented out. */
 	msg->func (msg);
 }
 
@@ -749,8 +749,6 @@ query_objects_changed_async (struct _query_msg *msg)
 
 	day_end = time_day_end_with_zone (time (NULL), zone);
 
-	debug (("Querying for object between %s to %s", e_ctime (&from), e_ctime (&day_end)));
-
 	for (l = objects; l != NULL; l = l->next) {
 		ECalComponentId *id;
 		GSList *sl;
@@ -786,7 +784,8 @@ query_objects_changed_async (struct _query_msg *msg)
 		 * remove it after updating the cqa structure. */
 		if (alarms == NULL || alarms->alarms == NULL) {
 
-			/* update the cqa and its queued alarms for changes in summary and alarm_uid  */
+			/* Update the cqa and its queued alarms
+			 * for changes in summary and alarm_uid.  */
 			update_cqa (cqa, comp);
 
 			if (alarms)
@@ -807,16 +806,12 @@ query_objects_changed_async (struct _query_msg *msg)
 
 			instance = sl->data;
 
-			if (!has_known_notification (cqa->alarms->comp, instance->auid)) {
-				g_debug ("Could not recognize alarm's notification type, discarding.");
+			if (!has_known_notification (cqa->alarms->comp, instance->auid))
 				continue;
-			}
 
 			alarm_id = alarm_add (instance->trigger, alarm_trigger_cb, cqa, NULL);
-			if (!alarm_id) {
-				debug (("Unable to schedule trigger for %s", e_ctime (&(instance->trigger))));
+			if (!alarm_id)
 				continue;
-			}
 
 			qa = g_new (QueuedAlarm, 1);
 			qa->alarm_id = alarm_id;
@@ -1151,7 +1146,9 @@ tray_list_remove_async (Message *msg)
 			gboolean status;
 
 			tray_icons_list = g_list_remove_link (tray_icons_list, list);
-			status = remove_queued_alarm (tray_data->cqa, tray_data->alarm_id, FALSE, TRUE);
+			status = remove_queued_alarm (
+				tray_data->cqa,
+				tray_data->alarm_id, FALSE, TRUE);
 			if (status) {
 				g_hash_table_remove (
 					tray_data->cqa->parent_client->uid_alarms_hash,
@@ -1488,7 +1485,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	e_cal_component_get_description_list (comp, &text_list);
 
 	if (text_list) {
-		text = *((ECalComponentText *)text_list->data);
+		text = *((ECalComponentText *) text_list->data);
 		if (text.value)
 			description = text.value;
 		else
@@ -1690,25 +1687,28 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 
 	if (attach && icalattach_get_is_url (attach)) {
 		const gchar *url;
-		gchar *filename;
-		GError *error = NULL;
 
 		url = icalattach_get_url (attach);
-		filename = g_filename_from_uri (url, NULL, &error);
+		if (url && *url) {
+			gchar *filename;
+			GError *error = NULL;
 
-		if (error != NULL) {
-			g_warning ("%s: %s", G_STRFUNC, error->message);
-			g_error_free (error);
-		} else if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-			flag = 1;
+			filename = g_filename_from_uri (url, NULL, &error);
+
+			if (error != NULL) {
+				g_warning ("%s: %s", G_STRFUNC, error->message);
+				g_error_free (error);
+			} else if (filename && g_file_test (filename, G_FILE_TEST_EXISTS)) {
 #ifdef HAVE_CANBERRA
-			ca_context_play (
-				ca_gtk_context_get (), 0,
-				CA_PROP_MEDIA_FILENAME, filename, NULL);
+				flag = 1;
+				ca_context_play (
+					ca_gtk_context_get (), 0,
+					CA_PROP_MEDIA_FILENAME, filename, NULL);
 #endif
-		}
+			}
 
-		g_free (filename);
+			g_free (filename);
+		}
 	}
 
 	if (!flag)
@@ -2102,14 +2102,14 @@ remove_cqa (ClientAlarms *ca, ECalComponentId *id, CompQueuedAlarms *cqa)
 static gboolean
 remove_comp_by_id (gpointer key, gpointer value, gpointer userdata) {
 
-	ClientAlarms *ca = (ClientAlarms *)userdata;
+	ClientAlarms *ca = (ClientAlarms *) userdata;
 
 	debug (("..."));
 
 /*	if (!g_hash_table_size (ca->uid_alarms_hash)) */
 /*		return; */
 
-	remove_cqa (ca, (ECalComponentId *)key, (CompQueuedAlarms *) value);
+	remove_cqa (ca, (ECalComponentId *) key, (CompQueuedAlarms *) value);
 
 	return TRUE;
 }
@@ -2120,7 +2120,8 @@ remove_client_alarms (ClientAlarms *ca)
 {
 	debug (("size %d", g_hash_table_size (ca->uid_alarms_hash)));
 
-	g_hash_table_foreach_remove  (ca->uid_alarms_hash, (GHRFunc)remove_comp_by_id, ca);
+	g_hash_table_foreach_remove  (
+		ca->uid_alarms_hash, (GHRFunc) remove_comp_by_id, ca);
 
 	/* The hash table should be empty now */
 	g_return_if_fail (g_hash_table_size (ca->uid_alarms_hash) == 0);
