@@ -26,7 +26,6 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
 #include <glib/gi18n.h>
 #include "calendar-view-factory.h"
 #include "calendar-view.h"
@@ -96,8 +95,8 @@ calendar_view_factory_finalize (GObject *object)
 	g_free (priv);
 	cal_view_factory->priv = NULL;
 
-	if (G_OBJECT_CLASS (calendar_view_factory_parent_class)->finalize)
-		(* G_OBJECT_CLASS (calendar_view_factory_parent_class)->finalize) (object);
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (calendar_view_factory_parent_class)->finalize (object);
 }
 
 
