@@ -477,9 +477,14 @@ save_comp (CompEditor *editor)
 		if (result)
 			g_signal_emit_by_name (editor, "object_created");
 	} else {
+		gboolean has_recurrences;
 
-		if (e_cal_component_has_recurrences (priv->comp) && priv->mod == CALOBJ_MOD_ALL)
-			comp_util_sanitize_recurrence_master (priv->comp, priv->client);
+		has_recurrences =
+			e_cal_component_has_recurrences (priv->comp);
+
+		if (has_recurrences && priv->mod == CALOBJ_MOD_ALL)
+			comp_util_sanitize_recurrence_master (
+				priv->comp, priv->client);
 
 		if (priv->mod == CALOBJ_MOD_THIS) {
 			e_cal_component_set_rdate_list (priv->comp, NULL);
@@ -841,12 +846,12 @@ action_save_cb (GtkAction *action,
 		ECalComponentVType vtype = e_cal_component_get_vtype (editor->priv->comp);
 
 		if (vtype == E_CAL_COMPONENT_EVENT)
-			response = em_utils_prompt_user ((GtkWindow *)widget,
+			response = em_utils_prompt_user ((GtkWindow *) widget,
 							 NULL,
 							 "calendar:ask-send-event-pending-download",
 							  NULL);
 		else
-			response = em_utils_prompt_user ((GtkWindow *)widget,
+			response = em_utils_prompt_user ((GtkWindow *) widget,
 							 NULL,
 							 "calendar:ask-send-task-pending-download",
 							  NULL);
@@ -904,7 +909,9 @@ action_save_cb (GtkAction *action,
 				e_cal_component_has_recurrences (priv->comp)) {
 				gchar *rid;
 				rid = e_cal_component_get_recurid_as_string (priv->comp);
-				e_cal_remove_object_with_mod (priv->client, uid, rid, priv->mod, &error);
+				e_cal_remove_object_with_mod (
+					priv->client, uid, rid,
+					priv->mod, &error);
 				g_free (rid);
 			} else
 				e_cal_remove_object (priv->client, uid, &error);
@@ -2959,7 +2966,7 @@ fill_widgets (CompEditor *editor)
 		g_signal_handlers_unblock_by_func (
 			store, G_CALLBACK (attachment_store_changed_cb),
 			editor);
-		g_slist_foreach (attachment_list, (GFunc)g_free, NULL);
+		g_slist_foreach (attachment_list, (GFunc) g_free, NULL);
 		g_slist_free (attachment_list);
 	}
 
@@ -3020,8 +3027,8 @@ set_attendees_for_delegation (ECalComponent *comp,
 	icalcomp = e_cal_component_get_icalcomponent (comp);
 
 	for (prop = icalcomponent_get_first_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
-			prop;
-			prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY)) {
+	     prop;
+	     prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY)) {
 		const gchar *attendee = icalproperty_get_attendee (prop);
 		const gchar *delfrom = NULL;
 
@@ -3049,14 +3056,17 @@ get_users_from_memo_comp (ECalComponent *comp, GList **users)
 	icalcomp = e_cal_component_get_icalcomponent (comp);
 
 	for (icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
-		icalprop != NULL;
-		icalprop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY)) {
-		if (g_str_equal (icalproperty_get_x_name (icalprop), "X-EVOLUTION-RECIPIENTS")) {
+	     icalprop != NULL;
+	     icalprop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY)) {
+		const gchar *x_name;
+
+		x_name = icalproperty_get_x_name (icalprop);
+
+		if (g_str_equal (x_name, "X-EVOLUTION-RECIPIENTS"))
 			break;
-		}
 	}
 
-	if (icalprop)	 {
+	if (icalprop) {
 		attendees = icalproperty_get_x (icalprop);
 		emails = g_strsplit (attendees, ";", -1);
 
@@ -3369,7 +3379,7 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 
 		camel_mime_part_set_content_id (mime_part, NULL);
 
-		cal_mime_attach->encoded_data = (gchar *)buffer;
+		cal_mime_attach->encoded_data = (gchar *) buffer;
 		cal_mime_attach->length = byte_array->len;
 		cal_mime_attach->filename =
 			g_strdup (camel_mime_part_get_filename (mime_part));
@@ -3461,6 +3471,7 @@ obj_removed_cb (ECal *client,
 {
 	CompEditorPrivate *priv = editor->priv;
 
-	if (changed_component_dialog ((GtkWindow *) editor, priv->comp, TRUE, priv->changed))
+	if (changed_component_dialog (
+		GTK_WINDOW (editor), priv->comp, TRUE, priv->changed))
 		close_dialog (editor);
 }
