@@ -28,7 +28,6 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
 #include <glib/gi18n.h>
 #include "e-util/e-categories-config.h"
 #include <libecal/e-cal-time-util.h>
@@ -37,10 +36,6 @@
 #include "e-calendar-view.h"
 #include "e-day-view-top-item.h"
 
-#define E_DAY_VIEW_TOP_ITEM_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_DAY_VIEW_TOP_ITEM, EDayViewTopItemPrivate))
-
 struct _EDayViewTopItemPrivate {
 	/* The parent EDayView widget. */
 	EDayView *day_view;
@@ -523,7 +518,7 @@ day_view_top_item_dispose (GObject *object)
 {
 	EDayViewTopItemPrivate *priv;
 
-	priv = E_DAY_VIEW_TOP_ITEM_GET_PRIVATE (object);
+	priv = E_DAY_VIEW_TOP_ITEM (object)->priv;
 
 	if (priv->day_view != NULL) {
 		g_object_unref (priv->day_view);
@@ -625,7 +620,8 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 	if (!show_dates) {
 		/* Clear the main area background. */
 		cairo_save (cr);
-		gdk_cairo_set_source_color (cr, &day_view->colors[E_DAY_VIEW_COLOR_BG_TOP_CANVAS]);
+		gdk_cairo_set_source_color (
+			cr, &day_view->colors[E_DAY_VIEW_COLOR_BG_TOP_CANVAS]);
 		cairo_rectangle (cr, left_edge - x, - y,
 				 canvas_width - left_edge,
 				 canvas_height);
@@ -788,7 +784,8 @@ day_view_top_item_class_init (EDayViewTopItemClass *class)
 static void
 day_view_top_item_init (EDayViewTopItem *top_item)
 {
-	top_item->priv = E_DAY_VIEW_TOP_ITEM_GET_PRIVATE (top_item);
+	top_item->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		top_item, E_TYPE_DAY_VIEW_TOP_ITEM, EDayViewTopItemPrivate);
 }
 
 GType
@@ -819,24 +816,31 @@ e_day_view_top_item_get_type (void)
 }
 
 void
-e_day_view_top_item_get_day_label (EDayView *day_view, gint day,
-				   gchar *buffer, gint buffer_len)
+e_day_view_top_item_get_day_label (EDayView *day_view,
+                                   gint day,
+                                   gchar *buffer,
+                                   gint buffer_len)
 {
+	ECalendarView *view;
 	struct icaltimetype day_start_tt;
+	const icaltimezone *zone;
 	struct tm day_start = { 0 };
 	const gchar *format;
 
-	day_start_tt = icaltime_from_timet_with_zone (day_view->day_starts[day],
-						      FALSE,
-						      e_calendar_view_get_timezone (E_CALENDAR_VIEW (day_view)));
+	view = E_CALENDAR_VIEW (day_view);
+	zone = e_calendar_view_get_timezone (view);
+
+	day_start_tt = icaltime_from_timet_with_zone (
+		day_view->day_starts[day], FALSE, zone);
 	day_start.tm_year = day_start_tt.year - 1900;
 	day_start.tm_mon = day_start_tt.month - 1;
 	day_start.tm_mday = day_start_tt.day;
 	day_start.tm_isdst = -1;
 
-	day_start.tm_wday = time_day_of_week (day_start_tt.day,
-					      day_start_tt.month - 1,
-					      day_start_tt.year);
+	day_start.tm_wday = time_day_of_week (
+		day_start_tt.day,
+		day_start_tt.month - 1,
+		day_start_tt.year);
 
 	if (day_view->date_format == E_DAY_VIEW_DATE_FULL)
 		/* strftime format %A = full weekday name, %d = day of month,
