@@ -24,27 +24,16 @@
 #ifndef _E_MEETING_UTILS_H_
 #define _E_MEETING_UTILS_H_
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <glib.h>
 #include "e-meeting-types.h"
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 
 gint e_meeting_time_compare_times (EMeetingTime *time1,
 				   EMeetingTime *time2);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* _E_MEETING_UTILS_H_ */
 
-
