@@ -60,10 +60,6 @@
 #include <e-util/e-icon-factory.h>
 #include "misc.h"
 
-#define E_MEMO_TABLE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MEMO_TABLE, EMemoTablePrivate))
-
 struct _EMemoTablePrivate {
 	gpointer shell_view;  /* weak pointer */
 	ECalModel *model;
@@ -297,7 +293,7 @@ memo_table_dispose (GObject *object)
 {
 	EMemoTablePrivate *priv;
 
-	priv = E_MEMO_TABLE_GET_PRIVATE (object);
+	priv = E_MEMO_TABLE (object)->priv;
 
 	if (priv->shell_view != NULL) {
 		g_object_remove_weak_pointer (
@@ -347,6 +343,7 @@ memo_table_constructed (GObject *object)
 	cell = e_cell_text_new (NULL, GTK_JUSTIFY_LEFT);
 	g_object_set (cell, "bg_color_column", E_CAL_MODEL_FIELD_COLOR, NULL);
 	e_table_extras_add_cell (extras, "calstring", cell);
+	g_object_unref (cell);
 
 	/*
 	 * Date fields.
@@ -377,6 +374,7 @@ memo_table_constructed (GObject *object)
 		G_BINDING_SYNC_CREATE);
 
 	e_table_extras_add_cell (extras, "dateedit", popup_cell);
+	g_object_unref (popup_cell);
 	memo_table->dates_cell = E_CELL_DATE_EDIT (popup_cell);
 
 	e_cell_date_edit_set_get_time_callback (
@@ -391,6 +389,8 @@ memo_table_constructed (GObject *object)
 
 	cell = e_cell_toggle_new (icon_names, G_N_ELEMENTS (icon_names));
 	e_table_extras_add_cell (extras, "icon", cell);
+	g_object_unref (cell);
+
 	e_table_extras_add_icon_name (extras, "icon", "stock_notes");
 
 	/* set proper format component for a default 'date' cell renderer */
@@ -418,8 +418,8 @@ memo_table_constructed (GObject *object)
 	if (a11y)
 		atk_object_set_name (a11y, _("Memos"));
 
-	if (G_OBJECT_CLASS (parent_class)->constructed)
-		G_OBJECT_CLASS (parent_class)->constructed (object);
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (parent_class)->constructed (object);
 }
 
 static gboolean
@@ -495,7 +495,7 @@ memo_table_query_tooltip (GtkWidget *widget,
 		comp_data->client, comp_data->icalcomp, &free_text);
 	if (!(str && *str)) {
 		if (free_text)
-			g_free ((gchar *)str);
+			g_free ((gchar *) str);
 		free_text = FALSE;
 		str = _("* No Summary *");
 	}
@@ -514,7 +514,7 @@ memo_table_query_tooltip (GtkWidget *widget,
 	g_free (tmp);
 
 	if (free_text)
-		g_free ((gchar *)str);
+		g_free ((gchar *) str);
 	free_text = FALSE;
 
 	w = gtk_event_box_new ();
@@ -1125,7 +1125,8 @@ memo_table_init (EMemoTable *memo_table)
 {
 	GtkTargetList *target_list;
 
-	memo_table->priv = E_MEMO_TABLE_GET_PRIVATE (memo_table);
+	memo_table->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		memo_table, E_TYPE_MEMO_TABLE, EMemoTablePrivate);
 
 	target_list = gtk_target_list_new (NULL, 0);
 	e_target_list_add_calendar_targets (target_list, 0);
@@ -1173,7 +1174,7 @@ e_memo_table_get_type (void)
 		};
 
 		type = g_type_register_static (
-			E_TABLE_TYPE, "EMemoTable", &type_info, 0);
+			E_TYPE_TABLE, "EMemoTable", &type_info, 0);
 
 		g_type_add_interface_static (
 			type, E_TYPE_SELECTABLE, &selectable_info);
