@@ -20,6 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "ea-week-view.h"
 #include "ea-cal-view-event.h"
 #include "ea-calendar-helpers.h"
@@ -29,8 +33,8 @@
 
 static void ea_week_view_class_init (EaWeekViewClass *klass);
 
-static G_CONST_RETURN gchar * ea_week_view_get_name (AtkObject *accessible);
-static G_CONST_RETURN gchar * ea_week_view_get_description (AtkObject *accessible);
+static const gchar * ea_week_view_get_name (AtkObject *accessible);
+static const gchar * ea_week_view_get_description (AtkObject *accessible);
 static gint         ea_week_view_get_n_children      (AtkObject *obj);
 static AtkObject*   ea_week_view_ref_child           (AtkObject *obj,
 						      gint i);
@@ -117,7 +121,7 @@ ea_week_view_new (GtkWidget *widget)
 	return accessible;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 ea_week_view_get_name (AtkObject *accessible)
 {
 	EWeekView *week_view;
@@ -166,7 +170,7 @@ ea_week_view_get_name (AtkObject *accessible)
 	return accessible->name;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 ea_week_view_get_description (AtkObject *accessible)
 {
 	EWeekView *week_view;
@@ -330,7 +334,7 @@ ea_week_view_ref_child (AtkObject *accessible, gint index)
 
 #ifdef ACC_DEBUG
 	printf ("EvoAcc: ea_week_view_ref_child [%d]=%p\n",
-		index, (gpointer)atk_object);
+		index, (gpointer) atk_object);
 #endif
 	return atk_object;
 }
