@@ -24,7 +24,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <gtk/gtkx.h>
@@ -37,7 +37,6 @@
 
 #include <e-util/e-util.h>
 
-#include "mail-decoration.h"
 #include <mail/em-utils.h>
 #include <mail/em-composer-utils.h>
 #include <mail/mail-config.h>
@@ -67,7 +66,7 @@ static guint mail_capplet_shell_signals[LAST_SIGNAL];
 
 struct  _MailCappletShellPrivate {
 
-	EMailSession *session;
+	EMailBackend *backend;
 	GtkWidget *box;
 
 	GtkWidget * top_bar;
@@ -105,7 +104,7 @@ mail_capplet_shell_finalize (GObject *object)
 static void
 ms_ctrl_w_pressed (MailCappletShell *shell)
 {
-	mail_view_close_view ((MailView *)shell->view);
+	mail_view_close_view ((MailView *) shell->view);
 }
 
 static void
@@ -178,7 +177,7 @@ mail_capplet_shell_quit (MailCappletShell *shell)
 	if (priv->main_loop)
 		gtk_main_quit ();
 	else
-		gtk_widget_hide ((GtkWidget *)shell);
+		gtk_widget_hide ((GtkWidget *) shell);
 }
 
 static void
@@ -203,34 +202,35 @@ mail_capplet_shell_construct (MailCappletShell *shell, gint socket_id, gboolean
 {
 	MailCappletShellPrivate *priv = shell->priv;
 	GtkStyle *style = gtk_widget_get_default_style ();
+	EMailSession *session;
 	gchar *custom_dir;
 
 	gtk_window_set_icon_name ((GtkWindow *)shell, "evolution");
 	gtk_window_set_title ((GtkWindow *)shell, _("Evolution account assistant"));
 	ms_init_style (style);
 	g_signal_connect ((GObject *)shell, "delete-event", G_CALLBACK (ms_delete_event), NULL);
-	gtk_window_set_type_hint ((GtkWindow *)shell, GDK_WINDOW_TYPE_HINT_NORMAL);
+	gtk_window_set_type_hint ((GtkWindow *) shell, GDK_WINDOW_TYPE_HINT_NORMAL);
 	if (g_getenv("ANJAL_NO_MAX") == NULL && FALSE) {
-		 GdkScreen *scr = gtk_widget_get_screen ((GtkWidget *)shell);
-		 gtk_window_set_default_size ((GtkWindow *)shell, gdk_screen_get_width (scr), gdk_screen_get_height (scr));
-		 gtk_window_set_decorated ((GtkWindow *)shell, FALSE);
+		 GdkScreen *scr = gtk_widget_get_screen ((GtkWidget *) shell);
+		 gtk_window_set_default_size ((GtkWindow *) shell, gdk_screen_get_width (scr), gdk_screen_get_height (scr));
+		 gtk_window_set_decorated ((GtkWindow *) shell, FALSE);
 	} else  {
-		gtk_window_set_default_size ((GtkWindow *)shell, 1024, 500);
+		gtk_window_set_default_size ((GtkWindow *) shell, 1024, 500);
 	}
 
 	priv->main_loop = main_loop;
 	priv->box = (GtkWidget *) gtk_vbox_new (FALSE, 0);
-	gtk_widget_show ((GtkWidget *)priv->box);
+	gtk_widget_show ((GtkWidget *) priv->box);
 
 	if (!socket_id) {
-		gtk_container_add ((GtkContainer *)shell, priv->box);
+		gtk_container_add ((GtkContainer *) shell, priv->box);
 	} else {
 		GtkWidget *plug = gtk_plug_new (socket_id);
 
-		gtk_container_add ((GtkContainer *)plug, priv->box);
+		gtk_container_add ((GtkContainer *) plug, priv->box);
 		g_signal_connect (plug, "destroy", G_CALLBACK (gtk_main_quit), NULL);
 		gtk_widget_show (plug);
-		gtk_widget_hide ((GtkWidget *)shell);
+		gtk_widget_hide ((GtkWidget *) shell);
 
 	}
 
@@ -239,46 +239,32 @@ mail_capplet_shell_construct (MailCappletShell *shell, gint socket_id, gboolean
 
 	camel_provider_init ();
 
-	shell->priv->session = e_mail_session_new ();
+	shell->priv->backend = g_object_new (E_TYPE_MAIL_BACKEND, NULL);
+	session = e_mail_backend_get_session (shell->priv->backend);
 
 	shell->view = mail_view_new ();
-	shell->view->session = shell->priv->session;
-	gtk_widget_show ((GtkWidget *)shell->view);
-	gtk_box_pack_end ((GtkBox *)priv->box, (GtkWidget *)shell->view, TRUE, TRUE, 2);
+	shell->view->backend = shell->priv->backend;
+	gtk_widget_show ((GtkWidget *) shell->view);
+	gtk_box_pack_end ((GtkBox *) priv->box, (GtkWidget *) shell->view, TRUE, TRUE, 2);
 
-	mail_config_init (shell->priv->session);
+	mail_config_init (session);
 	mail_msg_init ();
 	custom_dir = g_build_filename (e_get_user_data_dir (), "mail", NULL);
-	e_mail_store_init (shell->priv->session, custom_dir);
+	e_mail_store_init (session, custom_dir);
 	g_free (custom_dir);
 
 	if (just_druid) {
 		MailViewChild *mc;
-		gchar *pdir = g_build_filename (g_get_home_dir(), ".gnome2_private", NULL);
 
-		gtk_notebook_set_show_tabs ((GtkNotebook *)shell->view, FALSE);
-		mc = mail_view_add_page ((MailView *)shell->view, MAIL_VIEW_ACCOUNT, NULL);
+		gtk_notebook_set_show_tabs ((GtkNotebook *) shell->view, FALSE);
+		mc = mail_view_add_page ((MailView *) shell->view, MAIL_VIEW_ACCOUNT, NULL);
 		g_signal_connect (mc, "view-close", G_CALLBACK(ms_show_post_druid), shell);
 		setup_abooks ();
-		if (!g_file_test (pdir, G_FILE_TEST_EXISTS)) {
-			g_mkdir (pdir, 0700);
-		}
-		g_free (pdir);
 	} else
-		shell->priv->settings_view = mail_view_add_page ((MailView *)shell->view, MAIL_VIEW_SETTINGS, NULL);
+		shell->priv->settings_view = mail_view_add_page ((MailView *) shell->view, MAIL_VIEW_SETTINGS, NULL);
 
 }
 
-gint
-mail_capplet_shell_toolbar_height (MailCappletShell *shell)
-{
-	GtkAllocation allocation;
-
-	gtk_widget_get_allocation (shell->priv->top_bar, &allocation);
-
-	return allocation.height;
-}
-
 GtkWidget *
 mail_capplet_shell_new (gint socket_id, gboolean just_druid, gboolean main_loop)
 {
