@@ -16,9 +16,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-mail-session-utils.h"
 
-#include <config.h>
 #include <glib/gi18n-lib.h>
 
 #include <mail/mail-tools.h>
@@ -406,7 +409,14 @@ mail_session_send_to_thread (GSimpleAsyncResult *simple,
 		service = camel_session_get_service (
 			CAMEL_SESSION (session), context->transport_uid);
 
-		g_return_if_fail (CAMEL_IS_TRANSPORT (service));
+		if (!CAMEL_IS_TRANSPORT (service)) {
+			g_simple_async_result_set_error (simple,
+				CAMEL_SERVICE_ERROR,
+				CAMEL_SERVICE_ERROR_URL_INVALID,
+				_("Cannot get transport for account '%s'"),
+				context->transport_uid);
+			return;
+		}
 
 		/* XXX This API does not allow for cancellation. */
 		if (!camel_service_connect_sync (service, &error)) {
@@ -761,7 +771,7 @@ e_mail_session_send_to (EMailSession *session,
 	/* Failure here emits a runtime warning but is non-fatal. */
 	context->driver = camel_session_get_filter_driver (
 		CAMEL_SESSION (session), E_FILTER_SOURCE_OUTGOING, &error);
-	if (context->driver != NULL)
+	if (context->driver != NULL && get_folder_func)
 		camel_filter_driver_set_folder_func (
 			context->driver, get_folder_func, get_folder_data);
 	if (error != NULL) {
