@@ -69,6 +69,8 @@
 
 #define d(x)
 
+typedef struct _AsyncContext AsyncContext;
+
 struct _selected_uri {
 	gchar *key;		/* store:path or account/path */
 	gchar *uri;
@@ -77,7 +79,8 @@ struct _selected_uri {
 };
 
 struct _EMFolderTreePrivate {
-	EMailSession *session;
+	EMailBackend *backend;
+	EAlertSink *alert_sink;
 
 	/* selected_uri structures of each path pending selection. */
 	GSList *select_uris;
@@ -117,12 +120,20 @@ struct _EMFolderTreePrivate {
 	gulong selection_changed_handler_id;
 };
 
+struct _AsyncContext {
+	EActivity *activity;
+	EMFolderTree *folder_tree;
+	GtkTreeRowReference *root;
+	gchar *full_name;
+};
+
 enum {
 	PROP_0,
+	PROP_ALERT_SINK,
+	PROP_BACKEND,
 	PROP_COPY_TARGET_LIST,
 	PROP_ELLIPSIZE,
-	PROP_PASTE_TARGET_LIST,
-	PROP_SESSION
+	PROP_PASTE_TARGET_LIST
 };
 
 enum {
@@ -175,191 +186,209 @@ struct _folder_tree_selection_data {
 
 static gpointer parent_class = NULL;
 
-struct _EMFolderTreeGetFolderInfo {
-	MailMsg base;
-
-	/* input data */
-	GtkTreeRowReference *root;
-	EMFolderTree *folder_tree;
-	CamelStore *store;
-	guint32 flags;
-	gchar *top;
-
-	/* output data */
-	CamelFolderInfo *fi;
-};
-
-static gchar *
-folder_tree_get_folder_info__desc (struct _EMFolderTreeGetFolderInfo *m)
+static void
+async_context_free (AsyncContext *context)
 {
-	gchar *ret, *name;
+	if (context->activity != NULL)
+		g_object_unref (context->activity);
 
-	name = camel_service_get_name ((CamelService *)m->store, TRUE);
-	ret = g_strdup_printf(_("Scanning folders in \"%s\""), name);
-	g_free (name);
-	return ret;
+	if (context->folder_tree != NULL)
+		g_object_unref (context->folder_tree);
+
+	gtk_tree_row_reference_free (context->root);
+
+	g_free (context->full_name);
+
+	g_slice_free (AsyncContext, context);
 }
 
 static void
-folder_tree_get_folder_info__exec (struct _EMFolderTreeGetFolderInfo *m,
-                                   GCancellable *cancellable,
-                                   GError **error)
-{
-	guint32 flags = m->flags | CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
-	GError *local_error = NULL;
-
-	m->fi = camel_store_get_folder_info_sync (
-		m->store, m->top, flags, cancellable, &local_error);
-
-	/* XXX POP3 stores always return an error because they have
-	 *     no folder hierarchy to scan.  Clear that error so the
-	 *     user doesn't see it. */
-	if (g_error_matches (local_error,
-		CAMEL_STORE_ERROR, CAMEL_STORE_ERROR_NO_FOLDER))
-		g_error_free (local_error);
-	else if (local_error != NULL)
-		g_propagate_error (error, local_error);
-}
-
-static void
-folder_tree_get_folder_info__done (struct _EMFolderTreeGetFolderInfo *m)
+folder_tree_get_folder_info_cb (CamelStore *store,
+                                GAsyncResult *result,
+                                AsyncContext *context)
 {
 	struct _EMFolderTreeModelStoreInfo *si;
-	GtkTreeIter root, iter, titer;
-	CamelFolderInfo *fi;
+	CamelFolderInfo *folder_info;
+	CamelFolderInfo *child_info;
+	EAlertSink *alert_sink;
 	GtkTreeView *tree_view;
 	GtkTreeModel *model;
 	GtkTreePath *path;
-	gboolean is_store, need_add_node;
+	GtkTreeIter root;
+	GtkTreeIter iter;
+	GtkTreeIter titer;
+	gboolean is_store;
+	gboolean iter_is_placeholder;
+	gboolean valid;
+	GError *error = NULL;
 
-	/* check that we haven't been destroyed */
-	g_return_if_fail (GTK_IS_TREE_VIEW (m->folder_tree));
+	alert_sink = e_activity_get_alert_sink (context->activity);
 
-	/* check that our parent folder hasn't been deleted/unsubscribed */
-	if (!gtk_tree_row_reference_valid (m->root))
-		return;
+	folder_info = camel_store_get_folder_info_finish (
+		store, result, &error);
 
-	tree_view = GTK_TREE_VIEW (m->folder_tree);
+	tree_view = GTK_TREE_VIEW (context->folder_tree);
 	model = gtk_tree_view_get_model (tree_view);
 
-	si = em_folder_tree_model_lookup_store_info (
-		EM_FOLDER_TREE_MODEL (model), m->store);
-	if (si == NULL) {
-		/* store has been removed in the interim - do nothing */
-		return;
+	/* Check if our parent folder has been deleted/unsubscribed. */
+	if (!gtk_tree_row_reference_valid (context->root)) {
+		g_clear_error (&error);
+		goto exit;
 	}
 
-	path = gtk_tree_row_reference_get_path (m->root);
-	gtk_tree_model_get_iter (model, &root, path);
+	path = gtk_tree_row_reference_get_path (context->root);
+	valid = gtk_tree_model_get_iter (model, &root, path);
+	g_return_if_fail (valid);
+
+	gtk_tree_model_get (model, &root, COL_BOOL_IS_STORE, &is_store, -1);
 
 	/* If we had an error, then we need to re-set the
 	 * load subdirs state and collapse the node. */
-	if (!m->fi && m->base.error != NULL) {
+	if (error != NULL) {
 		gtk_tree_store_set (
 			GTK_TREE_STORE (model), &root,
 			COL_BOOL_LOAD_SUBDIRS, TRUE, -1);
 		gtk_tree_view_collapse_row (tree_view, path);
-		gtk_tree_path_free (path);
-		return;
 	}
 
 	gtk_tree_path_free (path);
 
-	/* make sure we still need to load the tree subfolders... */
-	gtk_tree_model_get (model, &root, COL_BOOL_IS_STORE, &is_store, -1);
+	if (e_activity_handle_cancellation (context->activity, error)) {
+		g_warn_if_fail (folder_info == NULL);
+		async_context_free (context);
+		g_error_free (error);
+		return;
 
-	/* get the first child (which will be a dummy node) */
-	gtk_tree_model_iter_children (model, &iter, &root);
+	/* XXX POP3 stores always return a "no folder" error because they
+	 *     have no folder hierarchy to scan.  Just ignore the error. */
+	} else if (g_error_matches (
+			error, CAMEL_STORE_ERROR,
+			CAMEL_STORE_ERROR_NO_FOLDER)) {
+		g_warn_if_fail (folder_info == NULL);
+		async_context_free (context);
+		g_error_free (error);
+		return;
 
-	need_add_node = TRUE;
+	} else if (error != NULL) {
+		g_warn_if_fail (folder_info == NULL);
+		e_alert_submit (
+			alert_sink, "mail:folder-open",
+			error->message, NULL);
+		async_context_free (context);
+		g_error_free (error);
+		return;
+	}
 
-	/* Traverse to the last valid iter, or the "Loading..." node */
-	do {
-		gboolean is_store_node = FALSE, is_folder_node = FALSE;
+	if (!folder_info) {
+		g_warn_if_fail (folder_info != NULL);
+		async_context_free (context);
+		return;
+	}
+
+	g_return_if_fail (folder_info != NULL);
+
+	/* Check if the store has been removed. */
+	si = em_folder_tree_model_lookup_store_info (
+		EM_FOLDER_TREE_MODEL (model), store);
+	if (si == NULL)
+		goto exit;
+
+	/* Make sure we still need to load the tree subfolders. */
+
+	iter_is_placeholder = FALSE;
+
+	/* Get the first child (which will be a placeholder row). */
+	valid = gtk_tree_model_iter_children (model, &iter, &root);
+
+	/* Traverse to the last valid iter, or the placeholder row. */
+	while (valid) {
+		gboolean is_store_node = FALSE;
+		gboolean is_folder_node = FALSE;
 
 		titer = iter; /* Preserve the last valid iter */
 
 		gtk_tree_model_get (
-			model, &iter, COL_BOOL_IS_STORE, &is_store_node,
+			model, &iter,
+			COL_BOOL_IS_STORE, &is_store_node,
 			COL_BOOL_IS_FOLDER, &is_folder_node, -1);
 
-		/* stop on a "Loading..." node */
+		/* Stop on a "Loading..." placeholder row. */
 		if (!is_store_node && !is_folder_node) {
-			/* remember it found a "Loading..." node and overwrite or remove it later */
-			need_add_node = FALSE;
+			iter_is_placeholder = TRUE;
 			break;
 		}
 
-	} while (gtk_tree_model_iter_next (model, &iter));
+		valid = gtk_tree_model_iter_next (model, &iter);
+	}
 
 	iter = titer;
 
-	/* FIXME: camel's IMAP code is totally on crack here, @top's
-	 * folder info should be @fi and fi->child should be what we
-	 * want to fill our tree with... *sigh* */
-	if (m->top && m->fi && !strcmp (m->fi->full_name, m->top)) {
-		if (!(fi = m->fi->child))
-			fi = m->fi->next;
+	/* FIXME Camel's IMAP code is totally on crack here: the
+	 *       folder_info we got back should be for the folder
+	 *       we're expanding, and folder_info->child should be
+	 *       what we want to fill our tree with... *sigh* */
+	if (g_strcmp0 (folder_info->full_name, context->full_name) == 0) {
+		child_info = folder_info->child;
+		if (child_info == NULL)
+			child_info = folder_info->next;
 	} else
-		fi = m->fi;
+		child_info = folder_info;
 
-	if (fi == NULL) {
-		/* no children afterall... remove the "Loading..." placeholder node */
-		if (!need_add_node)
+	/* The folder being expanded has no children after all.  Remove
+	 * the "Loading..." placeholder row and collapse the parent. */
+	if (child_info == NULL) {
+		if (iter_is_placeholder)
 			gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
 
 		if (is_store) {
 			path = gtk_tree_model_get_path (model, &root);
 			gtk_tree_view_collapse_row (tree_view, path);
 			gtk_tree_path_free (path);
-			return;
+			goto exit;
 		}
-	} else {
-		gint fully_loaded = (m->flags & CAMEL_STORE_FOLDER_INFO_RECURSIVE) ? TRUE : FALSE;
 
-		do {
-			if (g_hash_table_lookup (si->full_hash, fi->full_name) == NULL) {
-				if (need_add_node)
-					gtk_tree_store_append (GTK_TREE_STORE (model), &iter, &root);
-				need_add_node = TRUE;
+	} else {
+		while (child_info != NULL) {
+			GtkTreeRowReference *reference;
+
+			/* Check if we already have this row cached. */
+			reference = g_hash_table_lookup (
+				si->full_hash, child_info->full_name);
+
+			if (reference == NULL) {
+				/* If we're on a placeholder row, reuse
+				 * the row for the first child folder. */
+				if (iter_is_placeholder)
+					iter_is_placeholder = FALSE;
+				else
+					gtk_tree_store_append (
+						GTK_TREE_STORE (model),
+						&iter, &root);
 
 				em_folder_tree_model_set_folder_info (
 					EM_FOLDER_TREE_MODEL (model),
-					&iter, si, fi, fully_loaded);
+					&iter, si, child_info, TRUE);
 			}
 
-			fi = fi->next;
-		} while (fi != NULL);
+			child_info = child_info->next;
+		}
 
-		/* all children are known, remove the "Loading..." node */
-		if (!need_add_node)
+		/* Remove the "Loading..." placeholder row. */
+		if (iter_is_placeholder)
 			gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
 	}
 
 	gtk_tree_store_set (
 		GTK_TREE_STORE (model), &root,
 		COL_BOOL_LOAD_SUBDIRS, FALSE, -1);
+
+exit:
+	if (folder_info != NULL)
+		camel_store_free_folder_info (store, folder_info);
+
+	async_context_free (context);
 }
 
-static void
-folder_tree_get_folder_info__free (struct _EMFolderTreeGetFolderInfo *m)
-{
-	camel_store_free_folder_info (m->store, m->fi);
-
-	gtk_tree_row_reference_free (m->root);
-	g_object_unref (m->folder_tree);
-	g_object_unref (m->store);
-	g_free (m->top);
-}
-
-static MailMsgInfo get_folder_info_info = {
-	sizeof (struct _EMFolderTreeGetFolderInfo),
-	(MailMsgDescFunc) folder_tree_get_folder_info__desc,
-	(MailMsgExecFunc) folder_tree_get_folder_info__exec,
-	(MailMsgDoneFunc) folder_tree_get_folder_info__done,
-	(MailMsgFreeFunc) folder_tree_get_folder_info__free
-};
-
 static void
 folder_tree_emit_popup_event (EMFolderTree *folder_tree,
                               GdkEvent *event)
@@ -451,6 +480,7 @@ folder_tree_expand_node (const gchar *key,
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	EAccount *account;
+	EMailBackend *backend;
 	EMailSession *session;
 	CamelStore *store;
 	const gchar *p;
@@ -470,7 +500,8 @@ folder_tree_expand_node (const gchar *key,
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	model = gtk_tree_view_get_model (tree_view);
 
-	session = em_folder_tree_get_session (folder_tree);
+	backend = em_folder_tree_get_backend (folder_tree);
+	session = e_mail_backend_get_session (backend);
 
 	if ((account = e_get_account_by_uid (uid)) && account->enabled) {
 		store = (CamelStore *) camel_session_get_service (
@@ -478,6 +509,8 @@ folder_tree_expand_node (const gchar *key,
 
 		if (store == NULL)
 			return;
+
+		g_object_ref (store);
 	} else if (!strcmp (uid, "vfolder")) {
 		if (!(store = vfolder_store))
 			return;
@@ -524,30 +557,19 @@ folder_tree_maybe_expand_row (EMFolderTreeModel *model,
                               EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
-	struct _EMFolderTreeModelStoreInfo *si;
-	gboolean is_store;
 	CamelStore *store;
-	EAccount *account;
 	gchar *full_name;
 	gchar *key;
+	const gchar *uid;
 	struct _selected_uri *u;
 
-	gtk_tree_model_get ((GtkTreeModel *) model, iter,
-			    COL_STRING_FULL_NAME, &full_name,
-			    COL_POINTER_CAMEL_STORE, &store,
-			    COL_BOOL_IS_STORE, &is_store,
-			    -1);
+	gtk_tree_model_get (
+		GTK_TREE_MODEL (model), iter,
+		COL_STRING_FULL_NAME, &full_name,
+		COL_POINTER_CAMEL_STORE, &store, -1);
 
-	si = em_folder_tree_model_lookup_store_info (model, store);
-	if ((account = e_get_account_by_name (si->display_name))) {
-		key = g_strdup_printf ("%s/%s", account->uid, full_name ? full_name : "");
-	} else if (CAMEL_IS_VEE_STORE (store)) {
-		/* vfolder store */
-		key = g_strdup_printf ("vfolder/%s", full_name ? full_name : "");
-	} else {
-		/* local store */
-		key = g_strdup_printf ("local/%s", full_name ? full_name : "");
-	}
+	uid = camel_service_get_uid (CAMEL_SERVICE (store));
+	key = g_strdup_printf ("%s/%s", uid, full_name ? full_name : "");
 
 	u = g_hash_table_lookup (priv->select_uris_table, key);
 	if (u) {
@@ -712,13 +734,23 @@ exit:
 }
 
 static void
-folder_tree_set_session (EMFolderTree *folder_tree,
-                         EMailSession *session)
+folder_tree_set_alert_sink (EMFolderTree *folder_tree,
+                            EAlertSink *alert_sink)
 {
-	g_return_if_fail (CAMEL_IS_SESSION (session));
-	g_return_if_fail (folder_tree->priv->session == NULL);
+	g_return_if_fail (E_IS_ALERT_SINK (alert_sink));
+	g_return_if_fail (folder_tree->priv->alert_sink == NULL);
 
-	folder_tree->priv->session = g_object_ref (session);
+	folder_tree->priv->alert_sink = g_object_ref (alert_sink);
+}
+
+static void
+folder_tree_set_backend (EMFolderTree *folder_tree,
+                         EMailBackend *backend)
+{
+	g_return_if_fail (E_IS_MAIL_BACKEND (backend));
+	g_return_if_fail (folder_tree->priv->backend == NULL);
+
+	folder_tree->priv->backend = g_object_ref (backend);
 }
 
 static GtkTargetList *
@@ -758,17 +790,23 @@ folder_tree_set_property (GObject *object,
                           GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_ALERT_SINK:
+			folder_tree_set_alert_sink (
+				EM_FOLDER_TREE (object),
+				g_value_get_object (value));
+			return;
+
+		case PROP_BACKEND:
+			folder_tree_set_backend (
+				EM_FOLDER_TREE (object),
+				g_value_get_object (value));
+			return;
+
 		case PROP_ELLIPSIZE:
 			em_folder_tree_set_ellipsize (
 				EM_FOLDER_TREE (object),
 				g_value_get_enum (value));
 			return;
-
-		case PROP_SESSION:
-			folder_tree_set_session (
-				EM_FOLDER_TREE (object),
-				g_value_get_object (value));
-			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -781,6 +819,20 @@ folder_tree_get_property (GObject *object,
                           GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_ALERT_SINK:
+			g_value_set_object (
+				value,
+				em_folder_tree_get_alert_sink (
+				EM_FOLDER_TREE (object)));
+			return;
+
+		case PROP_BACKEND:
+			g_value_set_object (
+				value,
+				em_folder_tree_get_backend (
+				EM_FOLDER_TREE (object)));
+			return;
+
 		case PROP_COPY_TARGET_LIST:
 			g_value_set_boxed (
 				value,
@@ -801,13 +853,6 @@ folder_tree_get_property (GObject *object,
 				folder_tree_get_paste_target_list (
 				EM_FOLDER_TREE (object)));
 			return;
-
-		case PROP_SESSION:
-			g_value_set_object (
-				value,
-				em_folder_tree_get_session (
-				EM_FOLDER_TREE (object)));
-			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -840,9 +885,14 @@ folder_tree_dispose (GObject *object)
 		priv->autoexpand_id = 0;
 	}
 
-	if (priv->session != NULL) {
-		g_object_unref (priv->session);
-		priv->session = NULL;
+	if (priv->alert_sink != NULL) {
+		g_object_unref (priv->alert_sink);
+		priv->alert_sink = NULL;
+	}
+
+	if (priv->backend != NULL) {
+		g_object_unref (priv->backend);
+		priv->backend = NULL;
 	}
 
 	if (priv->text_renderer != NULL) {
@@ -1036,12 +1086,16 @@ folder_tree_row_expanded (GtkTreeView *tree_view,
                           GtkTreeIter *iter,
                           GtkTreePath *path)
 {
-	struct _EMFolderTreeGetFolderInfo *msg;
+	EActivity *activity;
+	GCancellable *cancellable;
+	EMFolderTree *folder_tree;
+	AsyncContext *context;
 	GtkTreeModel *model;
 	CamelStore *store;
 	gchar *full_name;
 	gboolean load;
 
+	folder_tree = EM_FOLDER_TREE (tree_view);
 	model = gtk_tree_view_get_model (tree_view);
 
 	gtk_tree_model_get (
@@ -1059,17 +1113,27 @@ folder_tree_row_expanded (GtkTreeView *tree_view,
 		GTK_TREE_STORE (model), iter,
 		COL_BOOL_LOAD_SUBDIRS, FALSE, -1);
 
-	msg = mail_msg_new (&get_folder_info_info);
-	msg->root = gtk_tree_row_reference_new (model, path);
-	g_object_ref (store);
-	msg->store = store;
-	msg->folder_tree = g_object_ref (tree_view);
-	msg->top = full_name;
-	msg->flags =
-		CAMEL_STORE_FOLDER_INFO_RECURSIVE |
-		CAMEL_STORE_FOLDER_INFO_FAST;
+	/* Retrieve folder info asynchronously. */
 
-	mail_msg_unordered_push (msg);
+	activity = em_folder_tree_new_activity (folder_tree);
+	cancellable = e_activity_get_cancellable (activity);
+
+	context = g_slice_new0 (AsyncContext);
+	context->activity = activity;
+	context->folder_tree = g_object_ref (folder_tree);
+	context->root = gtk_tree_row_reference_new (model, path);
+	context->full_name = g_strdup (full_name);
+
+	camel_store_get_folder_info (
+		store, full_name,
+		CAMEL_STORE_FOLDER_INFO_FAST |
+		CAMEL_STORE_FOLDER_INFO_RECURSIVE |
+		CAMEL_STORE_FOLDER_INFO_SUBSCRIBED,
+		G_PRIORITY_DEFAULT, cancellable,
+		(GAsyncReadyCallback) folder_tree_get_folder_info_cb,
+		context);
+
+	g_free (full_name);
 }
 
 static void
@@ -1098,6 +1162,30 @@ folder_tree_class_init (EMFolderTreeClass *class)
 	tree_view_class->test_collapse_row = folder_tree_test_collapse_row;
 	tree_view_class->row_expanded = folder_tree_row_expanded;
 
+	g_object_class_install_property (
+		object_class,
+		PROP_ALERT_SINK,
+		g_param_spec_object (
+			"alert-sink",
+			NULL,
+			NULL,
+			E_TYPE_ALERT_SINK,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT_ONLY |
+			G_PARAM_STATIC_STRINGS));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_BACKEND,
+		g_param_spec_object (
+			"backend",
+			NULL,
+			NULL,
+			E_TYPE_MAIL_BACKEND,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT_ONLY |
+			G_PARAM_STATIC_STRINGS));
+
 	/* Inherited from ESelectableInterface */
 	g_object_class_override_property (
 		object_class,
@@ -1121,17 +1209,6 @@ folder_tree_class_init (EMFolderTreeClass *class)
 		PROP_PASTE_TARGET_LIST,
 		"paste-target-list");
 
-	g_object_class_install_property (
-		object_class,
-		PROP_SESSION,
-		g_param_spec_object (
-			"session",
-			NULL,
-			NULL,
-			E_TYPE_MAIL_SESSION,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT_ONLY));
-
 	signals[FOLDER_SELECTED] = g_signal_new (
 		"folder-selected",
 		G_OBJECT_CLASS_TYPE (object_class),
@@ -1386,7 +1463,7 @@ folder_tree_new (EMFolderTree *folder_tree)
 		folder_tree_select_func, NULL, NULL);
 	gtk_tree_view_set_headers_visible ((GtkTreeView *) tree, FALSE);
 
-	gtk_tree_view_set_search_column ((GtkTreeView *)tree, COL_STRING_DISPLAY_NAME);
+	gtk_tree_view_set_search_column ((GtkTreeView *) tree, COL_STRING_DISPLAY_NAME);
 
 	return (GtkTreeView *) tree;
 }
@@ -1697,22 +1774,49 @@ em_folder_tree_get_type (void)
 }
 
 GtkWidget *
-em_folder_tree_new (EMailSession *session)
+em_folder_tree_new (EMailBackend *backend,
+                    EAlertSink *alert_sink)
 {
+	EMailSession *session;
 	const gchar *data_dir;
-	EShell *default_shell;
-	EShellBackend *mail_backend;
 
-	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
+	g_return_val_if_fail (E_IS_MAIL_BACKEND (backend), NULL);
+	g_return_val_if_fail (E_IS_ALERT_SINK (alert_sink), NULL);
 
-	default_shell = e_shell_get_default ();
-	mail_backend = e_shell_get_backend_by_name (default_shell, "mail");
-	data_dir = e_shell_backend_get_data_dir (mail_backend);
+	session = e_mail_backend_get_session (backend);
+	data_dir = e_shell_backend_get_data_dir (E_SHELL_BACKEND (backend));
 
 	e_mail_store_init (session, data_dir);
 
 	return g_object_new (
-		EM_TYPE_FOLDER_TREE, "session", session, NULL);
+		EM_TYPE_FOLDER_TREE,
+		"alert-sink", alert_sink,
+		"backend", backend, NULL);
+}
+
+EActivity *
+em_folder_tree_new_activity (EMFolderTree *folder_tree)
+{
+	EActivity *activity;
+	EMailBackend *backend;
+	EAlertSink *alert_sink;
+	GCancellable *cancellable;
+
+	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
+
+	activity = e_activity_new ();
+
+	alert_sink = em_folder_tree_get_alert_sink (folder_tree);
+	e_activity_set_alert_sink (activity, alert_sink);
+
+	cancellable = camel_operation_new ();
+	e_activity_set_cancellable (activity, cancellable);
+	g_object_unref (cancellable);
+
+	backend = em_folder_tree_get_backend (folder_tree);
+	e_shell_backend_add_activity (E_SHELL_BACKEND (backend), activity);
+
+	return activity;
 }
 
 PangoEllipsizeMode
@@ -1737,12 +1841,20 @@ em_folder_tree_set_ellipsize (EMFolderTree *folder_tree,
 	g_object_notify (G_OBJECT (folder_tree), "ellipsize");
 }
 
-EMailSession *
-em_folder_tree_get_session (EMFolderTree *folder_tree)
+EAlertSink *
+em_folder_tree_get_alert_sink (EMFolderTree *folder_tree)
 {
 	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
 
-	return folder_tree->priv->session;
+	return folder_tree->priv->alert_sink;
+}
+
+EMailBackend *
+em_folder_tree_get_backend (EMFolderTree *folder_tree)
+{
+	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
+
+	return folder_tree->priv->backend;
 }
 
 static void
@@ -1785,7 +1897,11 @@ tree_drag_data_delete (GtkWidget *widget,
 	CamelStore *store;
 	GtkTreeIter iter;
 
-	if (!priv->drag_row || (src_path = gtk_tree_row_reference_get_path (priv->drag_row)))
+	if (!priv->drag_row)
+		return;
+
+	src_path = gtk_tree_row_reference_get_path (priv->drag_row);
+	if (src_path == NULL)
 		return;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (folder_tree));
@@ -1930,27 +2046,24 @@ folder_tree_drop_folder (struct _DragDataReceivedAsync *m)
 static gchar *
 folder_tree_drop_async__desc (struct _DragDataReceivedAsync *m)
 {
-	CamelURL *url;
 	const guchar *data;
-	gchar *buf;
 
 	data = gtk_selection_data_get_data (m->selection);
 
 	if (m->info == DND_DROP_TYPE_FOLDER) {
-		url = camel_url_new ((gchar *)data, NULL);
+		gchar *folder_name = NULL;
+
+		e_mail_folder_uri_parse (
+			CAMEL_SESSION (m->session),
+			(gchar *) data, NULL, &folder_name, NULL);
+		g_return_val_if_fail (folder_name != NULL, NULL);
 
 		if (m->move)
-			buf = g_strdup_printf (
-				_("Moving folder %s"), url->fragment ?
-				url->fragment : url->path + 1);
+			return g_strdup_printf (
+				_("Moving folder %s"), folder_name);
 		else
-			buf = g_strdup_printf (
-				_("Copying folder %s"), url->fragment ?
-				url->fragment : url->path + 1);
-
-		camel_url_free (url);
-
-		return buf;
+			return g_strdup_printf (
+				_("Copying folder %s"), folder_name);
 	} else {
 		if (m->move)
 			return g_strdup_printf (
@@ -2043,6 +2156,7 @@ tree_drag_data_received (GtkWidget *widget,
 	GtkTreeModel *model;
 	GtkTreeView *tree_view;
 	GtkTreePath *dest_path = NULL;
+	EMailBackend *backend;
 	EMailSession *session;
 	struct _DragDataReceivedAsync *m;
 	gboolean is_store;
@@ -2053,7 +2167,8 @@ tree_drag_data_received (GtkWidget *widget,
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	model = gtk_tree_view_get_model (tree_view);
 
-	session = em_folder_tree_get_session (folder_tree);
+	backend = em_folder_tree_get_backend (folder_tree);
+	session = e_mail_backend_get_session (backend);
 
 	if (!gtk_tree_view_get_dest_row_at_pos (tree_view, x, y, &dest_path, &pos))
 		return;
@@ -2123,13 +2238,19 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
                          GdkDragAction *suggested_action)
 {
 	EMFolderTreePrivate *p = folder_tree->priv;
-	gchar *full_name = NULL, *uri = NULL, *src_uri = NULL;
-	CamelStore *local, *sstore, *dstore;
+	gchar *dst_full_name = NULL;
+	gchar *src_full_name = NULL;
+	CamelStore *local;
+	CamelStore *dst_store;
+	CamelStore *src_store = NULL;
 	GdkAtom atom = GDK_NONE;
 	gboolean is_store;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	GList *targets;
+	const gchar *uid;
+	gboolean src_is_vfolder;
+	gboolean dst_is_vfolder;
 	guint32 flags = 0;
 
 	/* This is a bit of a mess, but should handle all the cases properly */
@@ -2146,29 +2267,34 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 	gtk_tree_model_get (
 		model, &iter,
 		COL_BOOL_IS_STORE, &is_store,
-		COL_STRING_FULL_NAME, &full_name,
-		COL_UINT_FLAGS, &flags,
-		COL_POINTER_CAMEL_STORE, &dstore,
-		COL_STRING_URI, &uri, -1);
+		COL_POINTER_CAMEL_STORE, &dst_store,
+		COL_STRING_FULL_NAME, &dst_full_name,
+		COL_UINT_FLAGS, &flags, -1);
 
 	local = e_mail_local_get_store ();
 
+	uid = camel_service_get_uid (CAMEL_SERVICE (dst_store));
+	dst_is_vfolder = (g_strcmp0 (uid, "vfolder") == 0);
+
 	targets = gdk_drag_context_list_targets (context);
 
 	/* Check for special destinations */
-	if (uri && full_name) {
-		/* don't allow copying/moving into the UNMATCHED vfolder */
-		if (!strncmp (uri, "vfolder:", 8) && !strcmp (full_name, CAMEL_UNMATCHED_NAME))
+
+	/* Don't allow copying/moving into the UNMATCHED vfolder. */
+	if (dst_is_vfolder)
+		if (g_strcmp0 (dst_full_name, CAMEL_UNMATCHED_NAME) == 0)
 			goto done;
 
-		/* don't allow copying/moving into a vTrash/vJunk folder */
-		if (!strcmp (full_name, CAMEL_VTRASH_NAME)
-		    || !strcmp (full_name, CAMEL_VJUNK_NAME))
-			goto done;
+	/* Don't allow copying/moving into a vTrash folder. */
+	if (g_strcmp0 (dst_full_name, CAMEL_VTRASH_NAME) == 0)
+		goto done;
 
-		if (flags & CAMEL_FOLDER_NOSELECT)
-			goto done;
-	}
+	/* Don't allow copying/moving into a vJunk folder. */
+	if (g_strcmp0 (dst_full_name, CAMEL_VJUNK_NAME) == 0)
+		goto done;
+
+	if (flags & CAMEL_FOLDER_NOSELECT)
+		goto done;
 
 	if (p->drag_row) {
 		GtkTreePath *src_path = gtk_tree_row_reference_get_path (p->drag_row);
@@ -2179,8 +2305,8 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 			if (gtk_tree_model_get_iter (model, &iter, src_path))
 				gtk_tree_model_get (
 					model, &iter,
-					COL_POINTER_CAMEL_STORE, &sstore,
-					COL_STRING_URI, &src_uri,
+					COL_POINTER_CAMEL_STORE, &src_store,
+					COL_STRING_FULL_NAME, &src_full_name,
 					COL_UINT_FLAGS, &src_flags, -1);
 
 			/* can't dnd onto itself or below itself - bad things happen,
@@ -2188,7 +2314,8 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 			if (gtk_tree_path_compare (path, src_path) == 0
 			    || gtk_tree_path_is_descendant (path, src_path)
 			    || (gtk_tree_path_is_ancestor (path, src_path)
-				&& gtk_tree_path_get_depth (path) == gtk_tree_path_get_depth (src_path)-1)) {
+				&& gtk_tree_path_get_depth (path) ==
+				   gtk_tree_path_get_depth (src_path) - 1)) {
 				gtk_tree_path_free (src_path);
 				goto done;
 			}
@@ -2219,62 +2346,58 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 	}
 
 	/* Check for special sources, and vfolder stuff */
-	if (src_uri) {
-		CamelURL *url;
-		gchar *url_path;
+	if (src_store != NULL && src_full_name != NULL) {
+
+		uid = camel_service_get_uid (CAMEL_SERVICE (src_store));
+		src_is_vfolder = (g_strcmp0 (uid, "vfolder") == 0);
 
 		/* FIXME: this is a total hack, but i think all we can do at present */
 		/* Check for dragging from special folders which can't be moved/copied */
-		url = camel_url_new (src_uri, NULL);
-		url_path = url->fragment?url->fragment:url->path;
-		if (url_path && url_path[0]) {
-			/* don't allow moving any of the the local special folders */
-			if (sstore == local && is_special_local_folder (url_path)) {
-				GdkAtom xfolder;
 
-				camel_url_free (url);
+		/* Don't allow moving any of the the special local folders. */
+		if (src_store == local && is_special_local_folder (src_full_name)) {
+			GdkAtom xfolder;
 
-				/* force copy for special local folders */
-				*suggested_action = GDK_ACTION_COPY;
-				*actions = GDK_ACTION_COPY;
-				xfolder = drop_atoms[DND_DROP_TYPE_FOLDER];
-				while (targets != NULL) {
-					if (targets->data == (gpointer) xfolder) {
-						atom = xfolder;
-						goto done;
-					}
-
-					targets = targets->next;
+			/* force copy for special local folders */
+			*suggested_action = GDK_ACTION_COPY;
+			*actions = GDK_ACTION_COPY;
+			xfolder = drop_atoms[DND_DROP_TYPE_FOLDER];
+			while (targets != NULL) {
+				if (targets->data == (gpointer) xfolder) {
+					atom = xfolder;
+					goto done;
 				}
 
-				goto done;
+				targets = targets->next;
 			}
 
-			/* Don't allow copying/moving the UNMATCHED vfolder. */
-			if (!strcmp (url->protocol, "vfolder") &&
-				!strcmp (url_path, CAMEL_UNMATCHED_NAME)) {
-				camel_url_free (url);
-				goto done;
-			}
-
-			/* Don't allow copying/moving any vTrash/vJunk
-			 * folder nor maildir 'inbox'. */
-			if (strcmp (url_path, CAMEL_VTRASH_NAME) == 0
-			    || strcmp (url_path, CAMEL_VJUNK_NAME) == 0
-			    /* Dont allow drag from maildir 'inbox' */
-			    || strcmp(url_path, ".") == 0) {
-				camel_url_free (url);
-				goto done;
-			}
+			goto done;
 		}
-		camel_url_free (url);
 
-		/* Search Folders can only be dropped into other Search Folders */
-		if (strncmp(src_uri, "vfolder:", 8) == 0) {
+		/* Don't allow copying/moving the UNMATCHED vfolder. */
+		if (src_is_vfolder)
+			if (g_strcmp0 (src_full_name, CAMEL_UNMATCHED_NAME) == 0)
+				goto done;
+
+		/* Don't allow copying/moving any vTrash folder. */
+		if (g_strcmp0 (src_full_name, CAMEL_VTRASH_NAME) == 0)
+			goto done;
+
+		/* Don't allow copying/moving any vJunk folder. */
+		if (g_strcmp0 (src_full_name, CAMEL_VJUNK_NAME) == 0)
+			goto done;
+
+		/* Don't allow copying/moving any maildir 'inbox'. */
+		if (g_strcmp0 (src_full_name, ".") == 0)
+			goto done;
+
+		/* Search Folders can only be dropped into other
+		 * Search Folders. */
+		if (src_is_vfolder) {
 			/* force move only for vfolders */
 			*suggested_action = GDK_ACTION_MOVE;
 
-			if (uri && strncmp(uri, "vfolder:", 8) == 0) {
+			if (dst_is_vfolder) {
 				GdkAtom xfolder;
 
 				xfolder = drop_atoms[DND_DROP_TYPE_FOLDER];
@@ -2292,11 +2415,11 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 		}
 	}
 
-	/* can't drag anything but a vfolder into a vfolder */
-	if (uri && strncmp(uri, "vfolder:", 8) == 0)
+	/* Can't drag anything but a Search Folder into a Search Folder. */
+	if (dst_is_vfolder)
 		goto done;
 
-	/* Now we either have a store or a normal folder */
+	/* Now we either have a store or a normal folder. */
 
 	if (is_store) {
 		GdkAtom xfolder;
@@ -2327,8 +2450,8 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 
  done:
 
-	g_free (full_name);
-	g_free (uri);
+	g_free (dst_full_name);
+	g_free (src_full_name);
 
 	return atom;
 }
@@ -2660,8 +2783,11 @@ em_folder_tree_get_selected_uris (EMFolderTree *folder_tree)
 	selection = gtk_tree_view_get_selection (tree_view);
 
 	/* at first, add lost uris */
-	for (sl = folder_tree->priv->select_uris; sl; sl = g_slist_next (sl))
-		list = g_list_append (list, g_strdup (((struct _selected_uri *)sl->data)->uri));
+	for (sl = folder_tree->priv->select_uris; sl; sl = g_slist_next (sl)) {
+		const gchar *uri;
+		uri = ((struct _selected_uri *) sl->data)->uri;
+		list = g_list_append (list, g_strdup (uri));
+	}
 
 	rows = gtk_tree_selection_get_selected_rows (selection, &model);
 	for (l=rows; l; l=g_list_next (l)) {
@@ -2716,9 +2842,11 @@ em_folder_tree_set_selected_list (EMFolderTree *folder_tree,
                                   gboolean expand_only)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
+	EMailBackend *backend;
 	EMailSession *session;
 
-	session = em_folder_tree_get_session (folder_tree);
+	backend = em_folder_tree_get_backend (folder_tree);
+	session = e_mail_backend_get_session (backend);
 
 	/* FIXME: need to remove any currently selected stuff? */
 	if (!expand_only)
@@ -2803,7 +2931,7 @@ em_folder_tree_set_selected (EMFolderTree *folder_tree,
 	g_return_if_fail (EM_IS_FOLDER_TREE (folder_tree));
 
 	if (uri && uri[0])
-		l = g_list_append (l, (gpointer)uri);
+		l = g_list_append (l, (gpointer) uri);
 
 	em_folder_tree_set_selected_list (folder_tree, l, expand_only);
 	g_list_free (l);
@@ -2835,7 +2963,11 @@ em_folder_tree_select_next_path (EMFolderTree *folder_tree, gboolean skip_read_f
 			iter = child;
 		} else {
 			while (1) {
-				gboolean has_parent = gtk_tree_model_iter_parent (model, &parent, &iter);
+				gboolean has_parent;
+
+				has_parent = gtk_tree_model_iter_parent (
+					model, &parent, &iter);
+
 				if (gtk_tree_model_iter_next (model, &iter)) {
 					path = gtk_tree_model_get_path (model, &iter);
 					break;
@@ -3023,6 +3155,90 @@ em_folder_tree_edit_selected (EMFolderTree *folder_tree)
 	gtk_tree_path_free (path);
 }
 
+gboolean
+em_folder_tree_get_selected (EMFolderTree *folder_tree,
+                             CamelStore **out_store,
+                             gchar **out_folder_name)
+{
+	GtkTreeView *tree_view;
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	CamelStore *store = NULL;
+	gchar *folder_name = NULL;
+
+	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), FALSE);
+
+	tree_view = GTK_TREE_VIEW (folder_tree);
+	selection = gtk_tree_view_get_selection (tree_view);
+
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
+		return FALSE;
+
+	gtk_tree_model_get (
+		model, &iter,
+		COL_POINTER_CAMEL_STORE, &store,
+		COL_STRING_FULL_NAME, &folder_name, -1);
+
+	/* We should always get a valid store. */
+	g_return_val_if_fail (CAMEL_IS_STORE (store), FALSE);
+
+	/* If a store is selected, the folder name will be NULL.
+	 * Treat this as though nothing is selected, so that callers
+	 * can assume a TRUE return value means a folder is selected. */
+	if (folder_name == NULL)
+		return FALSE;
+
+	/* FIXME We really should be storing the CamelStore as a GObject
+	 *       so it gets referenced.  The pointer type is a relic of
+	 *       days before Camel used GObject. */
+	if (out_store != NULL)
+		*out_store = g_object_ref (store);
+
+	if (out_folder_name != NULL)
+		*out_folder_name = folder_name;
+	else
+		g_free (folder_name);
+
+	return TRUE;
+}
+
+gboolean
+em_folder_tree_store_root_selected (EMFolderTree *folder_tree, CamelStore **out_store)
+{
+	GtkTreeView *tree_view;
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	CamelStore *store = NULL;
+	gboolean is_store = FALSE;
+
+	g_return_val_if_fail (folder_tree != NULL, FALSE);
+	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), FALSE);
+
+	tree_view = GTK_TREE_VIEW (folder_tree);
+	selection = gtk_tree_view_get_selection (tree_view);
+
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
+		return FALSE;
+
+	gtk_tree_model_get (
+		model, &iter,
+		COL_POINTER_CAMEL_STORE, &store,
+		COL_BOOL_IS_STORE, &is_store, -1);
+
+	/* We should always get a valid store. */
+	g_return_val_if_fail (CAMEL_IS_STORE (store), FALSE);
+
+	if (!is_store)
+		return FALSE;
+
+	if (out_store != NULL)
+		*out_store = g_object_ref (store);
+
+	return TRUE;
+}
+
 gchar *
 em_folder_tree_get_selected_uri (EMFolderTree *folder_tree)
 {
@@ -3045,56 +3261,23 @@ em_folder_tree_get_selected_uri (EMFolderTree *folder_tree)
 	return uri;
 }
 
-gchar *
-em_folder_tree_get_selected_path (EMFolderTree *folder_tree)
-{
-	GtkTreeView *tree_view;
-	GtkTreeSelection *selection;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-	gchar *name = NULL;
-
-	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
-
-	tree_view = GTK_TREE_VIEW (folder_tree);
-	selection = gtk_tree_view_get_selection (tree_view);
-
-	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
-		return NULL;
-
-	gtk_tree_model_get (model, &iter, COL_STRING_FULL_NAME, &name, -1);
-
-	return name;
-}
-
 CamelFolder *
 em_folder_tree_get_selected_folder (EMFolderTree *folder_tree)
 {
-	GtkTreeView *tree_view;
-	GtkTreeSelection *selection;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-	gchar *full_name = NULL;
-	CamelStore *store = NULL;
-	CamelFolder *folder = NULL;
+	CamelFolder *folder;
+	CamelStore *store;
+	gchar *full_name;
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
 
-	tree_view = GTK_TREE_VIEW (folder_tree);
-	selection = gtk_tree_view_get_selection (tree_view);
-
-	if (gtk_tree_selection_get_selected (selection, &model, &iter))
-		gtk_tree_model_get (
-			model, &iter,
-			COL_POINTER_CAMEL_STORE, &store,
-			COL_STRING_FULL_NAME, &full_name, -1);
+	if (!em_folder_tree_get_selected (folder_tree, &store, &full_name))
+		return NULL;
 
 	/* FIXME camel_store_get_folder_sync() may block. */
-	if (store && full_name)
-		folder = camel_store_get_folder_sync (
-			store, full_name,
-			CAMEL_STORE_FOLDER_INFO_FAST, NULL, NULL);
+	folder = camel_store_get_folder_sync (
+		store, full_name, CAMEL_STORE_FOLDER_INFO_FAST, NULL, NULL);
 
+	g_object_unref (store);
 	g_free (full_name);
 
 	return folder;
@@ -3112,6 +3295,9 @@ em_folder_tree_get_selected_account (EMFolderTree *folder_tree)
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
 
+	/* Don't use em_folder_tree_get_selected() here because we
+	 * want this to work whether a folder or store is selected. */
+
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	selection = gtk_tree_view_get_selection (tree_view);
 
