@@ -58,16 +58,40 @@
 #include "em-folder-selector.h"
 #include "em-folder-properties.h"
 
+#include "e-mail-folder-utils.h"
 #include "e-mail-local.h"
 #include "e-mail-session.h"
 #include "e-mail-store.h"
+#include "e-mail-store-utils.h"
 
 #define d(x)
 
+typedef struct _AsyncContext AsyncContext;
+
+struct _AsyncContext {
+	EMFolderTree *folder_tree;
+	gchar *folder_uri;
+};
+
+static void
+async_context_free (AsyncContext *context)
+{
+	if (context->folder_tree != NULL)
+		g_object_unref (context->folder_tree);
+
+	g_free (context->folder_uri);
+
+	g_slice_free (AsyncContext, context);
+}
+
 static gboolean
 emfu_is_special_local_folder (const gchar *name)
 {
-	return (!strcmp (name, "Drafts") || !strcmp (name, "Inbox") || !strcmp (name, "Outbox") || !strcmp (name, "Sent") || !strcmp (name, "Templates"));
+	return (!strcmp (name, "Drafts") ||
+		!strcmp (name, "Inbox") ||
+		!strcmp (name, "Outbox") ||
+		!strcmp (name, "Sent") ||
+		!strcmp (name, "Templates"));
 }
 
 struct _EMCopyFolders {
@@ -146,14 +170,20 @@ emft_copy_folders__exec (struct _EMCopyFolders *m,
 				pending = g_list_append (pending, info->child);
 
 			if (m->tobase[0])
-				g_string_printf (toname, "%s/%s", m->tobase, info->full_name + fromlen);
+				g_string_printf (
+					toname, "%s/%s", m->tobase,
+					info->full_name + fromlen);
 			else
-				g_string_printf (toname, "%s", info->full_name + fromlen);
+				g_string_printf (
+					toname, "%s",
+					info->full_name + fromlen);
 
 			d(printf ("Copying from '%s' to '%s'\n", info->full_name, toname->str));
 
-			/* This makes sure we create the same tree, e.g. from a nonselectable source */
-			/* Not sure if this is really the 'right thing', e.g. for spool stores, but it makes the ui work */
+			/* This makes sure we create the same tree,
+			 * e.g. from a nonselectable source. */
+			/* Not sure if this is really the 'right thing',
+			 * e.g. for spool stores, but it makes the ui work. */
 			if ((info->flags & CAMEL_FOLDER_NOSELECT) == 0) {
 				d(printf ("this folder is selectable\n"));
 				if (m->tostore == m->fromstore && m->delete) {
@@ -217,7 +247,8 @@ emft_copy_folders__exec (struct _EMCopyFolders *m,
 		}
 	}
 
-	/* delete the folders in reverse order from how we copyied them, if we are deleting any */
+	/* Delete the folders in reverse order from how we copied them,
+	 * if we are deleting any. */
 	l = deleting;
 	while (l) {
 		CamelFolderInfo *info = l->data;
@@ -264,7 +295,11 @@ static MailMsgInfo copy_folders_info = {
 };
 
 gint
-em_folder_utils_copy_folders (CamelStore *fromstore, const gchar *frombase, CamelStore *tostore, const gchar *tobase, gint delete)
+em_folder_utils_copy_folders (CamelStore *fromstore,
+                              const gchar *frombase,
+                              CamelStore *tostore,
+                              const gchar *tobase,
+                              gint delete)
 {
 	struct _EMCopyFolders *m;
 	gint seq;
@@ -285,7 +320,8 @@ em_folder_utils_copy_folders (CamelStore *fromstore, const gchar *frombase, Came
 }
 
 struct _copy_folder_data {
-	CamelFolderInfo *fi;
+	CamelStore *source_store;
+	gchar *source_folder_name;
 	gboolean delete;
 };
 
@@ -296,90 +332,100 @@ emfu_copy_folder_selected (EMailBackend *backend,
 {
 	EMailSession *session;
 	struct _copy_folder_data *cfd = data;
-	CamelStore *fromstore = NULL, *tostore = NULL;
+	CamelStore *tostore = NULL;
 	CamelStore *local_store;
-	const gchar *tobase = NULL;
-	CamelURL *url;
+	CamelService *service;
+	gchar *tobase = NULL;
 	GError *local_error = NULL;
 
-	if (uri == NULL) {
-		g_free (cfd);
-		return;
-	}
+	if (uri == NULL)
+		goto fail;
 
 	local_store = e_mail_local_get_store ();
 	session = e_mail_backend_get_session (backend);
 
-	fromstore = camel_session_get_store (
-		CAMEL_SESSION (session), cfd->fi->uri, &local_error);
-	if (fromstore == NULL) {
+	service = CAMEL_SERVICE (cfd->source_store);
+	camel_service_connect_sync (service, &local_error);
+
+	if (local_error != NULL) {
 		e_mail_backend_submit_alert (
 			backend, cfd->delete ?
 				"mail:no-move-folder-notexist" :
 				"mail:no-copy-folder-notexist",
-			cfd->fi->full_name, uri,
+			cfd->source_folder_name, uri,
 			local_error->message, NULL);
 		goto fail;
 	}
 
-	if (cfd->delete && fromstore == local_store && emfu_is_special_local_folder (cfd->fi->full_name)) {
+	g_return_if_fail (CAMEL_IS_STORE (service));
+
+	if (cfd->delete && cfd->source_store == local_store &&
+		emfu_is_special_local_folder (cfd->source_folder_name)) {
 		e_mail_backend_submit_alert (
 			backend, "mail:no-rename-special-folder",
-			cfd->fi->full_name, NULL);
+			cfd->source_folder_name, NULL);
 		goto fail;
 	}
 
-	tostore = camel_session_get_store (
-		CAMEL_SESSION (session), uri, &local_error);
-	if (tostore == NULL) {
+	if (!e_mail_folder_uri_parse (
+		CAMEL_SESSION (session), uri,
+		&tostore, &tobase, &local_error))
+		tostore = NULL;
+
+	if (tostore != NULL)
+		camel_service_connect_sync (
+			CAMEL_SERVICE (tostore), &local_error);
+
+	if (local_error != NULL) {
 		e_mail_backend_submit_alert (
 			backend, cfd->delete ?
 				"mail:no-move-folder-to-notexist" :
 				"mail:no-copy-folder-to-notexist",
-			cfd->fi->full_name, uri,
+			cfd->source_folder_name, uri,
 			local_error->message, NULL);
 		goto fail;
 	}
 
-	url = camel_url_new (uri, NULL);
-	if (((CamelService *)tostore)->provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH)
-		tobase = url->fragment;
-	else if (url->path && url->path[0])
-		tobase = url->path+1;
-	if (tobase == NULL)
-		tobase = "";
+	g_return_if_fail (CAMEL_IS_STORE (tostore));
 
 	em_folder_utils_copy_folders (
-		fromstore, cfd->fi->full_name, tostore, tobase, cfd->delete);
+		cfd->source_store, cfd->source_folder_name,
+		tostore, tobase ? tobase : "", cfd->delete);
 
-	camel_url_free (url);
 fail:
-	if (fromstore)
-		g_object_unref (fromstore);
-	if (tostore)
-		g_object_unref (tostore);
-
 	g_clear_error (&local_error);
 
+	g_object_unref (cfd->source_store);
+	g_free (cfd->source_folder_name);
 	g_free (cfd);
+	g_free (tobase);
 }
 
 /* tree here is the 'destination' selector, not 'self' */
 static gboolean
-emfu_copy_folder_exclude (EMFolderTree *tree, GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
+emfu_copy_folder_exclude (EMFolderTree *tree,
+                          GtkTreeModel *model,
+                          GtkTreeIter *iter,
+                          gpointer data)
 {
 	struct _copy_folder_data *cfd = data;
+	CamelStore *store;
+	const gchar *uid;
 	gint fromvfolder, tovfolder;
-	gchar *touri;
 	guint flags;
-	gboolean is_store;
 
 	/* handles moving to/from vfolders */
 
-	fromvfolder = strncmp(cfd->fi->uri, "vfolder:", 8) == 0;
-	gtk_tree_model_get (model, iter, COL_STRING_URI, &touri, COL_UINT_FLAGS, &flags, COL_BOOL_IS_STORE, &is_store, -1);
-	tovfolder = strncmp(touri, "vfolder:", 8) == 0;
-	g_free (touri);
+	uid = camel_service_get_uid (CAMEL_SERVICE (cfd->source_store));
+	fromvfolder = (g_strcmp0 (uid, "vfolder") == 0);
+
+	gtk_tree_model_get (
+		model, iter,
+		COL_UINT_FLAGS, &flags,
+		COL_POINTER_CAMEL_STORE, &store, -1);
+
+	uid = camel_service_get_uid (CAMEL_SERVICE (store));
+	tovfolder = (g_strcmp0 (uid, "vfolder") == 0);
 
 	/* moving from vfolder to normal- not allowed */
 	if (fromvfolder && !tovfolder && cfd->delete)
@@ -394,367 +440,195 @@ emfu_copy_folder_exclude (EMFolderTree *tree, GtkTreeModel *model, GtkTreeIter *
 	return (flags & EMFT_EXCLUDE_NOINFERIORS) == 0;
 }
 
-/* FIXME: this interface references the folderinfo without copying it  */
-/* FIXME: these functions must be documented */
 void
 em_folder_utils_copy_folder (GtkWindow *parent,
                              EMailBackend *backend,
-                             CamelFolderInfo *folderinfo,
+                             const gchar *folder_uri,
                              gint delete)
 {
 	GtkWidget *dialog;
-	EMFolderTree *emft;
+	EMFolderSelector *selector;
+	EMFolderTree *folder_tree;
 	EMailSession *session;
 	const gchar *label;
 	const gchar *title;
 	struct _copy_folder_data *cfd;
+	GError *error = NULL;
 
 	g_return_if_fail (E_IS_MAIL_BACKEND (backend));
-	g_return_if_fail (folderinfo != NULL);
+	g_return_if_fail (folder_uri != NULL);
 
 	session = e_mail_backend_get_session (backend);
 
 	cfd = g_malloc (sizeof (*cfd));
-	cfd->fi = folderinfo;
 	cfd->delete = delete;
 
-	/* XXX Do we leak this reference. */
-	emft = (EMFolderTree *) em_folder_tree_new (session);
-	emu_restore_folder_tree_state (emft);
+	e_mail_folder_uri_parse (
+		CAMEL_SESSION (session), folder_uri,
+		&cfd->source_store, &cfd->source_folder_name, &error);
 
-	em_folder_tree_set_excluded_func (
-		emft, emfu_copy_folder_exclude, cfd);
+	if (error != NULL) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+		g_free (cfd);
+		return;
+	}
 
 	label = delete ? _("_Move") : _("C_opy");
 	title = delete ? _("Move Folder To") : _("Copy Folder To");
 
 	dialog = em_folder_selector_new (
-		parent, emft,
+		parent, backend,
 		EM_FOLDER_SELECTOR_CAN_CREATE,
 		title, NULL, label);
 
+	selector = EM_FOLDER_SELECTOR (dialog);
+	folder_tree = em_folder_selector_get_folder_tree (selector);
+
+	em_folder_tree_set_excluded_func (
+		folder_tree, emfu_copy_folder_exclude, cfd);
+
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
 		const gchar *uri;
 
-		uri = em_folder_selector_get_selected_uri (
-			EM_FOLDER_SELECTOR (dialog));
+		uri = em_folder_selector_get_selected_uri (selector);
 		emfu_copy_folder_selected (backend, uri, cfd);
 	}
 
 	gtk_widget_destroy (dialog);
 }
 
-typedef struct {
-	EMailBackend *backend;
-	GtkWidget *dialog;
-} DeleteFolderData;
-
 static void
-emfu_delete_done (CamelFolder *folder,
-                  gboolean removed,
-                  GError **error,
-                  gpointer user_data)
+new_folder_created_cb (CamelStore *store,
+                       GAsyncResult *result,
+                       AsyncContext *context)
 {
-	DeleteFolderData *data = user_data;
+	GError *error = NULL;
 
-	if (error != NULL && *error != NULL) {
-		e_mail_backend_submit_alert (
-			data->backend,
-			"mail:no-delete-folder",
-			camel_folder_get_full_name (folder),
-			(*error)->message, NULL);
-		g_clear_error (error);
+	e_mail_store_create_folder_finish (store, result, &error);
+
+	/* FIXME Use an EActivity here. */
+	if (error != NULL) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+
+	} else if (context->folder_tree != NULL) {
+		gpointer data;
+		gboolean expand_only;
+
+		/* XXX What in the hell kind of lazy hack is this? */
+		data = g_object_get_data (
+			G_OBJECT (context->folder_tree), "select");
+		expand_only = GPOINTER_TO_INT (data) ? TRUE : FALSE;
+
+		em_folder_tree_set_selected (
+			context->folder_tree,
+			context->folder_uri, expand_only);
 	}
 
-	g_object_unref (data->backend);
-	gtk_widget_destroy (data->dialog);
-	g_slice_free (DeleteFolderData, data);
+	async_context_free (context);
 }
 
-/* FIXME: these functions must be documented */
 void
-em_folder_utils_delete_folder (EMailBackend *backend,
-                               CamelFolder *folder)
+em_folder_utils_create_folder (GtkWindow *parent,
+                               EMailBackend *backend,
+                               EMFolderTree *emft,
+                               const gchar *initial_uri)
 {
-	CamelStore *local_store;
-	CamelStore *parent_store;
 	EMailSession *session;
-	MailFolderCache *folder_cache;
-	GtkWindow *parent = e_shell_get_active_window (NULL);
+	EMFolderSelector *selector;
+	EMFolderTree *folder_tree;
+	CamelStore *store = NULL;
+	gchar *folder_name = NULL;
 	GtkWidget *dialog;
-	const gchar *full_name;
-	gint flags = 0;
+	GError *error = NULL;
 
+	g_return_if_fail (GTK_IS_WINDOW (parent));
 	g_return_if_fail (E_IS_MAIL_BACKEND (backend));
-	g_return_if_fail (CAMEL_IS_FOLDER (folder));
 
-	full_name = camel_folder_get_full_name (folder);
-	parent_store = camel_folder_get_parent_store (folder);
-
-	local_store = e_mail_local_get_store ();
 	session = e_mail_backend_get_session (backend);
-	folder_cache = e_mail_session_get_folder_cache (session);
 
-	if (parent_store == local_store && emfu_is_special_local_folder (full_name)) {
-		e_mail_backend_submit_alert (
-			backend, "mail:no-delete-special-folder",
-			full_name, NULL);
-		return;
-	}
+	dialog = em_folder_selector_create_new (
+		parent, backend, 0,
+		_("Create Folder"),
+		_("Specify where to create the folder:"));
 
-	if (mail_folder_cache_get_folder_info_flags (folder_cache, folder, &flags) && (flags & CAMEL_FOLDER_SYSTEM)) {
-		e_mail_backend_submit_alert (
-			backend, "mail:no-delete-special-folder",
-			camel_folder_get_name (folder), NULL);
-		return;
-	}
+	selector = EM_FOLDER_SELECTOR (dialog);
+	folder_tree = em_folder_selector_get_folder_tree (selector);
 
-	g_object_ref (folder);
+	if (initial_uri != NULL)
+		em_folder_tree_set_selected (folder_tree, initial_uri, FALSE);
 
-	if (mail_folder_cache_get_folder_info_flags (folder_cache, folder, &flags) && (flags & CAMEL_FOLDER_CHILDREN)) {
-		if (parent_store && CAMEL_IS_VEE_STORE (parent_store))
-			dialog = e_alert_dialog_new_for_args (
-				parent, "mail:ask-delete-vfolder",
-				full_name, NULL);
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_OK)
+		goto exit;
+
+	if (em_folder_tree_store_root_selected (folder_tree, &store)) {
+		const gchar *folder_uri;
+
+		folder_uri = em_folder_selector_get_selected_uri (selector);
+
+		if (!folder_uri || !strrchr (folder_uri, '/'))
+			g_set_error (
+				&error, CAMEL_FOLDER_ERROR,
+				CAMEL_FOLDER_ERROR_INVALID,
+				_("Invalid folder URI '%s'"),
+				folder_uri ? folder_uri : "null");
 		else
-			dialog = e_alert_dialog_new_for_args (
-				parent, "mail:ask-delete-folder",
-				full_name, NULL);
-	}
-	else {
-		if (parent_store && CAMEL_IS_VEE_STORE (parent_store))
-			dialog = e_alert_dialog_new_for_args (
-				parent, "mail:ask-delete-vfolder-nochild",
-				full_name, NULL);
-		else
-			dialog = e_alert_dialog_new_for_args (
-				parent, "mail:ask-delete-folder-nochild",
-				full_name, NULL);
-	}
-
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
-		DeleteFolderData *data;
-
-		/* disable dialog until operation finishes */
-		gtk_widget_set_sensitive (dialog, FALSE);
-
-		data = g_slice_new0 (DeleteFolderData);
-		data->backend = g_object_ref (backend);
-		data->dialog = dialog;
-
-		mail_remove_folder (folder, emfu_delete_done, data);
-	} else
-		gtk_widget_destroy (dialog);
-}
-
-struct _EMCreateFolder {
-	MailMsg base;
-
-	/* input data */
-	CamelStore *store;
-	gchar *full_name;
-	gchar *parent;
-	gchar *name;
-
-	/* output data */
-	CamelFolderInfo *fi;
-
-	/* callback data */
-	void (* done) (CamelFolderInfo *fi, gpointer user_data);
-	gpointer user_data;
-};
-
-/* Temporary Structure to hold data to pass across function */
-struct _EMCreateFolderTempData
-{
-	EMFolderTree * emft;
-	EMFolderSelector * emfs;
-	gchar *uri;
-};
-
-static gchar *
-emfu_create_folder__desc (struct _EMCreateFolder *m)
-{
-	return g_strdup_printf (_("Creating folder '%s'"), m->full_name);
-}
-
-static void
-emfu_create_folder__exec (struct _EMCreateFolder *m,
-                          GCancellable *cancellable,
-                          GError **error)
-{
-	if ((m->fi = camel_store_create_folder_sync (
-		m->store, m->parent, m->name, cancellable, error))) {
-
-		if (camel_store_supports_subscriptions (m->store))
-			camel_store_subscribe_folder_sync (
-				m->store, m->full_name,
-				cancellable, error);
-	}
-}
-
-static void
-emfu_create_folder__done (struct _EMCreateFolder *m)
-{
-	if (m->done)
-		m->done (m->fi, m->user_data);
-}
-
-static void
-emfu_create_folder__free (struct _EMCreateFolder *m)
-{
-	camel_store_free_folder_info (m->store, m->fi);
-	g_object_unref (m->store);
-	g_free (m->full_name);
-	g_free (m->parent);
-	g_free (m->name);
-}
-
-static MailMsgInfo create_folder_info = {
-	sizeof (struct _EMCreateFolder),
-	(MailMsgDescFunc) emfu_create_folder__desc,
-	(MailMsgExecFunc) emfu_create_folder__exec,
-	(MailMsgDoneFunc) emfu_create_folder__done,
-	(MailMsgFreeFunc) emfu_create_folder__free
-};
-
-static gint
-emfu_create_folder_real (CamelStore *store, const gchar *full_name, void (* done) (CamelFolderInfo *fi, gpointer user_data), gpointer user_data)
-{
-	gchar *name, *namebuf = NULL;
-	struct _EMCreateFolder *m;
-	const gchar *parent;
-	gint id;
-
-	namebuf = g_strdup (full_name);
-	if (!(name = strrchr (namebuf, '/'))) {
-		name = namebuf;
-		parent = "";
+			folder_name = g_strdup (strrchr (folder_uri, '/'));
 	} else {
-		*name++ = '\0';
-		parent = namebuf;
+		const gchar *folder_uri;
+
+		folder_uri = em_folder_selector_get_selected_uri (selector);
+
+		e_mail_folder_uri_parse (
+			CAMEL_SESSION (session), folder_uri,
+			&store, &folder_name, &error);
 	}
 
-	m = mail_msg_new (&create_folder_info);
-	g_object_ref (store);
-	m->store = store;
-	m->full_name = g_strdup (full_name);
-	m->parent = g_strdup (parent);
-	m->name = g_strdup (name);
-	m->user_data = user_data;
-	m->done = done;
-
-	g_free (namebuf);
-
-	id = m->base.seq;
-	mail_msg_unordered_push (m);
-
-	return id;
-}
-
-static void
-new_folder_created_cb (CamelFolderInfo *fi, gpointer user_data)
-{
-	struct _EMCreateFolderTempData *emcftd=user_data;
-	if (fi) {
-		/* Exapnding newly created folder */
-		if (emcftd->emft)
-			em_folder_tree_set_selected ((EMFolderTree *) emcftd->emft, emcftd->uri, GPOINTER_TO_INT(g_object_get_data ((GObject *)emcftd->emft, "select")) ? FALSE : TRUE);
-
-		gtk_widget_destroy ((GtkWidget *) emcftd->emfs);
-	}
-	g_object_unref (emcftd->emfs);
-	g_free (emcftd->uri);
-	g_free (emcftd);
-}
-
-static void
-emfu_popup_new_folder_response (EMFolderSelector *emfs,
-                                gint response,
-                                EMFolderTree *folder_tree)
-{
-	EMFolderTreeModelStoreInfo *si;
-	EMailSession *session;
-	GtkTreeModel *model;
-	const gchar *uri, *path;
-	CamelStore *store;
-	struct _EMCreateFolderTempData  *emcftd;
-
-	if (response != GTK_RESPONSE_OK) {
-		gtk_widget_destroy ((GtkWidget *) emfs);
-		return;
-	}
-
-	uri = em_folder_selector_get_selected_uri (emfs);
-	path = em_folder_selector_get_selected_path (emfs);
-
-	d(printf ("Creating new folder: %s (%s)\n", path, uri));
-
-	g_print ("DEBUG: %s (%s)\n", path, uri);
-
-	session = em_folder_tree_get_session (folder_tree);
-
-	store = (CamelStore *) camel_session_get_service (
-		CAMEL_SESSION (session), uri,
-		CAMEL_PROVIDER_STORE, NULL);
-	if (store == NULL)
-		return;
-
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (emfs->emft));
-	si = em_folder_tree_model_lookup_store_info (
-		EM_FOLDER_TREE_MODEL (model), store);
-	if (si == NULL) {
-		g_object_unref (store);
-		g_return_if_reached ();
+	/* XXX This is unlikely to fail since the URI comes straight from
+	 *     EMFolderSelector, but leave a breadcrumb if it does fail. */
+	if (error != NULL) {
+		g_warn_if_fail (store == NULL);
+		g_warn_if_fail (folder_name == NULL);
+		g_warning ("%s", error->message);
+		g_error_free (error);
+		goto exit;
 	}
 
 	/* HACK: we need to create vfolders using the vfolder editor */
 	if (CAMEL_IS_VEE_STORE (store)) {
 		EFilterRule *rule;
+		const gchar *skip_slash;
 
-		rule = em_vfolder_rule_new (session);
-		e_filter_rule_set_name (rule, path);
+		if (*folder_name == '/')
+			skip_slash = folder_name + 1;
+		else
+			skip_slash = folder_name;
+
+		rule = em_vfolder_rule_new (backend);
+		e_filter_rule_set_name (rule, skip_slash);
 		vfolder_gui_add_rule (EM_VFOLDER_RULE (rule));
-		gtk_widget_destroy ((GtkWidget *)emfs);
 	} else {
-		/* Temp data to pass to create_folder_real function */
-		emcftd = (struct _EMCreateFolderTempData *) g_malloc (sizeof (struct _EMCreateFolderTempData));
-		emcftd->emfs = emfs;
-		emcftd->uri = g_strdup (uri);
-		emcftd->emft = folder_tree;
+		AsyncContext *context;
 
-		g_object_ref (emfs);
-		emfu_create_folder_real (si->store, path, new_folder_created_cb, emcftd);
+		context = g_slice_new0 (AsyncContext);
+		context->folder_uri = e_mail_folder_uri_build (store, folder_name);
+
+		if (EM_IS_FOLDER_TREE (emft))
+			context->folder_tree = g_object_ref (emft);
+
+		/* FIXME Not passing a GCancellable. */
+		e_mail_store_create_folder (
+			store, folder_name, G_PRIORITY_DEFAULT, NULL,
+			(GAsyncReadyCallback) new_folder_created_cb,
+			context);
 	}
 
+	g_free (folder_name);
 	g_object_unref (store);
-}
 
-/* FIXME: these functions must be documented */
-void
-em_folder_utils_create_folder (CamelFolderInfo *folderinfo,
-                               EMFolderTree *emft,
-			       EMailSession *session,
-                               GtkWindow *parent)
-{
-	EMFolderTree *folder_tree;
-	GtkWidget *dialog;
-
-	folder_tree = (EMFolderTree *) em_folder_tree_new (session);
-	emu_restore_folder_tree_state (folder_tree);
-
-	dialog = em_folder_selector_create_new (
-		parent, folder_tree, 0,
-		_("Create Folder"),
-		_("Specify where to create the folder:"));
-	if (folderinfo != NULL)
-		em_folder_selector_set_selected ((EMFolderSelector *) dialog, folderinfo->uri);
-	g_signal_connect (dialog, "response", G_CALLBACK (emfu_popup_new_folder_response), emft ? emft : folder_tree);
-
-	if (!parent || !GTK_IS_DIALOG (parent))
-		gtk_widget_show (dialog);
-	else
-		gtk_dialog_run (GTK_DIALOG (dialog));
+exit:
+	gtk_widget_destroy (dialog);
 }
 
 const gchar *
