@@ -82,18 +82,16 @@ mbox_getwidget (EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
-	EMailSession *session;
 	GtkWindow *window;
 	GtkWidget *hbox, *w;
 	GtkLabel *label;
 	gchar *select_uri = NULL;
 
-	/* XXX Dig up the EMailSession from the default EShell.
+	/* XXX Dig up the mail backend from the default EShell.
 	 *     Since the EImport framework doesn't allow for user
 	 *     data, I don't see how else to get to it. */
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
-	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
 
 	/* preselect the folder selected in a mail view */
 	window = e_shell_get_active_window (shell);
@@ -105,41 +103,54 @@ mbox_getwidget (EImport *ei, EImportTarget *target, EImportImporter *im)
 		view = e_shell_window_get_active_view (shell_window);
 
 		if (view && g_str_equal (view, "mail")) {
-			EShellView *shell_view = e_shell_window_get_shell_view (shell_window, view);
+			EShellView *shell_view;
+			EShellSidebar *shell_sidebar;
+			EMFolderTree *folder_tree = NULL;
 
-			if (shell_view) {
-				EMFolderTree *folder_tree = NULL;
-				EShellSidebar *shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
+			shell_view = e_shell_window_get_shell_view (
+				shell_window, view);
 
-				g_object_get (shell_sidebar, "folder-tree", &folder_tree, NULL);
+			shell_sidebar =
+				e_shell_view_get_shell_sidebar (shell_view);
 
-				if (folder_tree)
-					select_uri = em_folder_tree_get_selected_uri (folder_tree);
-			}
+			g_object_get (
+				shell_sidebar, "folder-tree",
+				&folder_tree, NULL);
+
+			select_uri =
+				em_folder_tree_get_selected_uri (folder_tree);
+
+			g_object_unref (folder_tree);
 		}
 	}
 
-	if (!select_uri)
-		select_uri = g_strdup (e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_INBOX));
+	if (!select_uri) {
+		const gchar *uri;
+		uri = e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_INBOX);
+		select_uri = g_strdup (uri);
+	}
 
 	hbox = gtk_hbox_new (FALSE, 0);
 
 	w = gtk_label_new_with_mnemonic (_("_Destination folder:"));
-	gtk_box_pack_start ((GtkBox *)hbox, w, FALSE, TRUE, 6);
+	gtk_box_pack_start ((GtkBox *) hbox, w, FALSE, TRUE, 6);
 
 	label = GTK_LABEL (w);
 
 	w = em_folder_selection_button_new (
-		session, _("Select folder"),
+		E_MAIL_BACKEND (shell_backend),
+		_("Select folder"),
 		_("Select folder to import into"));
 	gtk_label_set_mnemonic_widget (label, w);
-	em_folder_selection_button_set_selection ((EMFolderSelectionButton *)w, select_uri);
-	folder_selected (EM_FOLDER_SELECTION_BUTTON (w), (EImportTargetURI *)target);
+	em_folder_selection_button_set_selection (
+		EM_FOLDER_SELECTION_BUTTON (w), select_uri);
+	folder_selected (
+		EM_FOLDER_SELECTION_BUTTON (w), (EImportTargetURI *) target);
 	g_signal_connect (w, "selected", G_CALLBACK(folder_selected), target);
-	gtk_box_pack_start ((GtkBox *)hbox, w, FALSE, TRUE, 6);
+	gtk_box_pack_start ((GtkBox *) hbox, w, FALSE, TRUE, 6);
 
 	w = gtk_vbox_new (FALSE, 0);
-	gtk_box_pack_start ((GtkBox *)w, hbox, FALSE, FALSE, 0);
+	gtk_box_pack_start ((GtkBox *) w, hbox, FALSE, FALSE, 0);
 	gtk_widget_show_all (w);
 
 	g_free (select_uri);
@@ -159,7 +170,7 @@ mbox_supported (EImport *ei, EImportTarget *target, EImportImporter *im)
 	if (target->type != E_IMPORT_TARGET_URI)
 		return FALSE;
 
-	s = (EImportTargetURI *)target;
+	s = (EImportTargetURI *) target;
 	if (s->uri_src == NULL)
 		return TRUE;
 
@@ -204,7 +215,9 @@ mbox_status_timeout (gpointer data)
 		pc = importer->status_pc;
 		g_mutex_unlock (importer->status_lock);
 
-		e_import_status (importer->import, (EImportTarget *)importer->target, what, pc);
+		e_import_status (
+			importer->import, (EImportTarget *)
+			importer->target, what, pc);
 	}
 
 	return TRUE;
@@ -254,9 +267,10 @@ mbox_import (EImport *ei, EImportTarget *target, EImportImporter *im)
 		importer->cancellable, "status",
 		G_CALLBACK (mbox_status), importer);
 
-	filename = g_filename_from_uri (((EImportTargetURI *)target)->uri_src, NULL, NULL);
+	filename = g_filename_from_uri (
+		((EImportTargetURI *) target)->uri_src, NULL, NULL);
 	mail_importer_import_mbox (
-		session, filename, ((EImportTargetURI *)target)->uri_dest,
+		session, filename, ((EImportTargetURI *) target)->uri_dest,
 		importer->cancellable, mbox_import_done, importer);
 	g_free (filename);
 }
@@ -314,7 +328,7 @@ static GtkWidget *
 mbox_get_preview (EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	GtkWidget *preview = NULL;
-	EImportTargetURI *s = (EImportTargetURI *)target;
+	EImportTargetURI *s = (EImportTargetURI *) target;
 	gchar *filename;
 	gint fd;
 	CamelMimeParser *mp;
@@ -355,7 +369,7 @@ mbox_get_preview (EImport *ei, EImportTarget *target, EImportImporter *im)
 
 		msg = camel_mime_message_new ();
 		if (!camel_mime_part_construct_from_parser_sync (
-			(CamelMimePart *)msg, mp, NULL, NULL)) {
+			(CamelMimePart *) msg, mp, NULL, NULL)) {
 			g_object_unref (msg);
 			break;
 		}
