@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-cal-shell-backend.h"
 
 #include <string.h>
@@ -534,7 +538,7 @@ cal_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 
 		header = (gchar *) cp;
 		header[header_len] = '\0';
-		cp += header_len + 2;
+		cp += header_len + 1;
 
 		content_len = strcspn (cp, "&");
 
@@ -555,7 +559,7 @@ cal_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 			comp_rid = g_strdup (content);
 		g_free (content);
 
-		cp += content_len + 1;
+		cp += content_len;
 		if (*cp == '&') {
 			cp++;
 			if (strcmp (cp, "amp;") == 0)
