@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-cal-shell-view-private.h"
 
 static gpointer parent_class;
@@ -231,15 +235,19 @@ get_attendee_prop (icalcomponent *icalcomp, const gchar *address)
 	if (!(address && *address))
 		return NULL;
 
-	for (prop = icalcomponent_get_first_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
-			prop;
-			prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY)) {
+	prop = icalcomponent_get_first_property (
+		icalcomp, ICAL_ATTENDEE_PROPERTY);
+
+	while (prop != NULL) {
 		const gchar *attendee = icalproperty_get_attendee (prop);
 
-		if (g_str_equal (itip_strip_mailto (attendee), address)) {
+		if (g_str_equal (itip_strip_mailto (attendee), address))
 			return prop;
-		}
+
+		prop = icalcomponent_get_next_property (
+			icalcomp, ICAL_ATTENDEE_PROPERTY);
 	}
+
 	return NULL;
 }
 
@@ -252,27 +260,31 @@ is_delegated (icalcomponent *icalcomp, const gchar *user_email)
 
 	prop = get_attendee_prop (icalcomp, user_email);
 
-	if (prop) {
-		param = icalproperty_get_first_parameter (prop, ICAL_DELEGATEDTO_PARAMETER);
-		if (param)
+	if (prop != NULL) {
+		param = icalproperty_get_first_parameter (
+			prop, ICAL_DELEGATEDTO_PARAMETER);
+		if (param != NULL)
 			delto = icalparameter_get_delegatedto (param);
 	} else
 		return FALSE;
 
 	prop = get_attendee_prop (icalcomp, itip_strip_mailto (delto));
 
-	if (prop) {
+	if (prop != NULL) {
 		const gchar *delfrom = NULL;
 		icalparameter_partstat status = ICAL_PARTSTAT_NONE;
 
-		param = icalproperty_get_first_parameter (prop, ICAL_DELEGATEDFROM_PARAMETER);
-		if (param)
+		param = icalproperty_get_first_parameter (
+			prop, ICAL_DELEGATEDFROM_PARAMETER);
+		if (param != NULL)
 			delfrom = icalparameter_get_delegatedfrom (param);
-		param = icalproperty_get_first_parameter (prop, ICAL_PARTSTAT_PARAMETER);
-		if (param)
+		param = icalproperty_get_first_parameter (
+			prop, ICAL_PARTSTAT_PARAMETER);
+		if (param != NULL)
 			status = icalparameter_get_partstat (param);
-		if ((delfrom && *delfrom) && g_str_equal (itip_strip_mailto (delfrom), user_email)
-				&& status != ICAL_PARTSTAT_DECLINED)
+		if ((delfrom != NULL && *delfrom != '\0') &&
+			g_str_equal (itip_strip_mailto (delfrom),
+			user_email) && status != ICAL_PARTSTAT_DECLINED)
 			return TRUE;
 	}
 
@@ -321,7 +333,7 @@ cal_shell_view_update_actions (EShellView *shell_view)
 		/* Hide the New button on the toolbar. */
 		widget = e_shell_window_get_managed_widget (
 			shell_window, "/main-toolbar");
-		widget = (GtkWidget *)gtk_toolbar_get_nth_item (
+		widget = (GtkWidget *) gtk_toolbar_get_nth_item (
 			GTK_TOOLBAR (widget), 0);
 		gtk_widget_hide (widget);
 
@@ -474,7 +486,7 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	gtk_action_set_sensitive (action, sensitive);
 
 	action = ACTION (EVENT_MEETING_NEW);
-	visible = itip_addresses_get_default () != NULL;
+	visible = e_get_default_account () != NULL;
 	gtk_action_set_visible (action, visible);
 }
 
