@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-memo-shell-sidebar.h"
 
 #include <string.h>
@@ -35,10 +39,6 @@
 #include "e-memo-shell-backend.h"
 #include "e-memo-shell-content.h"
 
-#define E_MEMO_SHELL_SIDEBAR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MEMO_SHELL_SIDEBAR, EMemoShellSidebarPrivate))
-
 struct _EMemoShellSidebarPrivate {
 	GtkWidget *selector;
 
@@ -101,24 +101,12 @@ memo_shell_sidebar_emit_status_message (EMemoShellSidebar *memo_shell_sidebar,
 	g_signal_emit (memo_shell_sidebar, signal_id, 0, status_message, -1.0);
 }
 
-static EAlertSink *
-get_alert_sink (EShellView *shell_view)
-{
-	EShellWindow *shell_window;
-
-	shell_window = e_shell_view_get_shell_window (shell_view);
-
-	if (g_strcmp0 (e_shell_window_get_active_view (shell_window), "calendar") == 0)
-		shell_view = e_shell_window_peek_shell_view (shell_window, "calendar");
-
-	return E_ALERT_SINK (e_shell_view_get_shell_content (shell_view));
-}
-
 static void
 memo_shell_sidebar_backend_died_cb (EMemoShellSidebar *memo_shell_sidebar,
                                     ECal *client)
 {
 	EShellView *shell_view;
+	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	GHashTable *client_table;
 	ESource *source;
@@ -128,6 +116,7 @@ memo_shell_sidebar_backend_died_cb (EMemoShellSidebar *memo_shell_sidebar,
 
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	source = e_cal_get_source (client);
 	uid = e_source_peek_uid (source);
@@ -137,7 +126,8 @@ memo_shell_sidebar_backend_died_cb (EMemoShellSidebar *memo_shell_sidebar,
 	g_hash_table_remove (client_table, uid);
 	memo_shell_sidebar_emit_status_message (memo_shell_sidebar, NULL);
 
-	e_alert_submit (get_alert_sink (shell_view),
+	e_alert_submit (
+		E_ALERT_SINK (shell_content),
 		"calendar:memos-crashed", NULL);
 
 	g_object_unref (source);
@@ -149,18 +139,23 @@ memo_shell_sidebar_backend_error_cb (EMemoShellSidebar *memo_shell_sidebar,
                                      ECal *client)
 {
 	EShellView *shell_view;
+	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	ESourceGroup *source_group;
 	ESource *source;
 
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	source = e_cal_get_source (client);
 	source_group = e_source_peek_group (source);
 
-	e_alert_submit (get_alert_sink (shell_view),
-		"calendar:backend-error", e_source_group_peek_name (source_group), e_source_peek_name (source), message, NULL);
+	e_alert_submit (
+		E_ALERT_SINK (shell_content),
+		"calendar:backend-error",
+		e_source_group_peek_name (source_group),
+		e_source_peek_name (source), message, NULL);
 }
 
 static void
@@ -169,11 +164,13 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
                                      ECal *client)
 {
 	EShellView *shell_view;
+	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	const gchar *message;
 
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	if (g_error_matches (error, E_CALENDAR_ERROR,
 		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
@@ -194,14 +191,16 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 			return;
 
 		case E_CALENDAR_STATUS_REPOSITORY_OFFLINE:
-			e_alert_submit (get_alert_sink (shell_view),
+			e_alert_submit (
+				E_ALERT_SINK (shell_content),
 				"calendar:prompt-no-contents-offline-memos",
 				NULL);
 			/* fall through */
 
 		default:
 			if (error->code != E_CALENDAR_STATUS_REPOSITORY_OFFLINE) {
-				e_alert_submit (get_alert_sink (shell_view),
+				e_alert_submit (
+					E_ALERT_SINK (shell_content),
 					"calendar:failed-open-memos",
 					error->message, NULL);
 			}
@@ -230,13 +229,15 @@ memo_shell_sidebar_default_loaded_cb (ESource *source,
                                       EShellSidebar *shell_sidebar)
 {
 	EMemoShellSidebarPrivate *priv;
+	EShellContent *shell_content;
 	EShellView *shell_view;
 	ECal *client;
 	GError *error = NULL;
 
-	priv = E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
+	priv = E_MEMO_SHELL_SIDEBAR (shell_sidebar)->priv;
 
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	client = e_load_cal_source_finish (source, result, &error);
 
@@ -245,7 +246,8 @@ memo_shell_sidebar_default_loaded_cb (ESource *source,
 		goto exit;
 
 	} else if (error != NULL) {
-		e_alert_submit (get_alert_sink (shell_view),
+		e_alert_submit (
+			E_ALERT_SINK (shell_content),
 			"calendar:failed-open-memos",
 			error->message, NULL);
 		g_error_free (error);
@@ -333,15 +335,8 @@ memo_shell_sidebar_row_changed_cb (EMemoShellSidebar *memo_shell_sidebar,
 	ESourceSelector *selector;
 	ESource *source;
 
-	/* XXX ESourceSelector's underlying tree store has only one
-	 *     column: ESource objects.  While we're not supposed to
-	 *     know this, listening for "row-changed" signals from
-	 *     the model is easier to deal with than the selector's
-	 *     "selection-changed" signal, which doesn't tell you
-	 *     _which_ row changed. */
-
 	selector = e_memo_shell_sidebar_get_selector (memo_shell_sidebar);
-	gtk_tree_model_get (tree_model, tree_iter, 0, &source, -1);
+	source = e_source_selector_get_source_by_path (selector, tree_path);
 
 	/* XXX This signal gets emitted a lot while the model is being
 	 *     rebuilt, during which time we won't get a valid ESource.
@@ -417,7 +412,7 @@ memo_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 	GtkTreeModel *model;
 	GSList *list, *iter;
 
-	priv = E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
+	priv = E_MEMO_SHELL_SIDEBAR (shell_sidebar)->priv;
 
 	shell = e_shell_window_get_shell (shell_window);
 	shell_settings = e_shell_get_shell_settings (shell);
@@ -504,7 +499,7 @@ memo_shell_sidebar_dispose (GObject *object)
 {
 	EMemoShellSidebarPrivate *priv;
 
-	priv = E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (object);
+	priv = E_MEMO_SHELL_SIDEBAR (object)->priv;
 
 	if (priv->selector != NULL) {
 		g_object_unref (priv->selector);
@@ -533,7 +528,7 @@ memo_shell_sidebar_finalize (GObject *object)
 {
 	EMemoShellSidebarPrivate *priv;
 
-	priv = E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (object);
+	priv = E_MEMO_SHELL_SIDEBAR (object)->priv;
 
 	g_hash_table_destroy (priv->client_table);
 
@@ -554,7 +549,7 @@ memo_shell_sidebar_constructed (GObject *object)
 	GtkWidget *widget;
 	AtkObject *a11y;
 
-	priv = E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (object);
+	priv = E_MEMO_SHELL_SIDEBAR (object)->priv;
 
 	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (parent_class)->constructed (object);
@@ -660,6 +655,7 @@ memo_shell_sidebar_client_removed (EMemoShellSidebar *memo_shell_sidebar,
 
 	source = e_cal_get_source (client);
 	uid = e_source_peek_uid (source);
+	g_return_if_fail (uid != NULL);
 
 	g_hash_table_remove (client_table, uid);
 	e_source_selector_unselect_source (selector, source);
@@ -749,8 +745,9 @@ memo_shell_sidebar_init (EMemoShellSidebar *memo_shell_sidebar)
 		(GDestroyNotify) g_free,
 		(GDestroyNotify) g_object_unref);
 
-	memo_shell_sidebar->priv =
-		E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (memo_shell_sidebar);
+	memo_shell_sidebar->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		memo_shell_sidebar, E_TYPE_MEMO_SHELL_SIDEBAR,
+		EMemoShellSidebarPrivate);
 
 	memo_shell_sidebar->priv->client_table = client_table;
 
