@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-task-shell-content.h"
 
 #include <glib/gi18n.h>
@@ -643,7 +647,8 @@ task_shell_content_class_init (ETaskShellContentClass *class)
 
 	shell_content_class = E_SHELL_CONTENT_CLASS (class);
 	shell_content_class->check_state = task_shell_content_check_state;
-	shell_content_class->focus_search_results = task_shell_content_focus_search_results;
+	shell_content_class->focus_search_results =
+		task_shell_content_focus_search_results;
 
 	g_object_class_install_property (
 		object_class,
