@@ -50,9 +50,6 @@
 #include "em-junk.h"
 #include "em-config.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 enum {
 	HEADER_LIST_NAME_COLUMN, /* displayable name of the header (may be a translation) */
 	HEADER_LIST_ENABLED_COLUMN, /* is the header enabled? */
@@ -165,56 +162,61 @@ jh_tree_refill (EMMailerPrefs *prefs)
 	g_slist_free (cjh);
 }
 
+static void
+jh_dialog_entry_changed_cb (GtkEntry *entry, gpointer user_data)
+{
+	GtkBuilder *builder = GTK_BUILDER (user_data);
+	GtkWidget *ok_button, *entry1, *entry2;
+	const gchar *name, *value;
+
+	ok_button = e_builder_get_widget (builder, "junk-header-ok");
+	entry1 = e_builder_get_widget (builder, "junk-header-name");
+	entry2 = e_builder_get_widget (builder, "junk-header-content");
+
+	name = gtk_entry_get_text (GTK_ENTRY (entry1));
+	value = gtk_entry_get_text (GTK_ENTRY (entry2));
+
+	gtk_widget_set_sensitive (ok_button, name && *name && value && *value);
+}
+
 static void
 jh_add_cb (GtkWidget *widget, gpointer user_data)
 {
+	GtkWidget *dialog;
+	GtkWidget *entry;
 	EMMailerPrefs *prefs = (EMMailerPrefs *) user_data;
-	GtkWidget *dialog, *l1, *l2, *entry1, *entry2, *vbox, *hbox;
-	GtkWidget *content_area;
-	gint response;
+	GtkBuilder *builder = gtk_builder_new ();
+	gchar *tok;
+	const gchar *name, *value;
+	GSList *list;
 
-	dialog = gtk_dialog_new_with_buttons (
-		_("Add Custom Junk Header"),
-		(GtkWindow *) gtk_widget_get_toplevel (widget),
-		GTK_DIALOG_DESTROY_WITH_PARENT,
-		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-		GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+	e_load_ui_builder_definition (builder, "mail-config.ui");
+	dialog = e_builder_get_widget (builder, "add-custom-junk-header");
+	jh_dialog_entry_changed_cb (NULL, builder);
 
-	vbox = gtk_vbox_new (FALSE, 6);
-	hbox = gtk_hbox_new (FALSE, 0);
-	l1 = gtk_label_new_with_mnemonic (_("Header Name:"));
-	l2 = gtk_label_new_with_mnemonic (_("Header Value Contains:"));
-	entry1 = gtk_entry_new ();
-	entry2 = gtk_entry_new ();
-	gtk_box_pack_start ((GtkBox *) hbox, l1, FALSE, FALSE, 6);
-	gtk_box_pack_start ((GtkBox *)hbox, entry1, FALSE, FALSE, 6);
-	gtk_box_pack_start ((GtkBox *)vbox, hbox, FALSE, FALSE, 6);
+	entry = e_builder_get_widget (builder, "junk-header-name");
+	g_signal_connect (entry, "changed",
+		G_CALLBACK (jh_dialog_entry_changed_cb), builder);
+	entry = e_builder_get_widget (builder, "junk-header-content");
+	g_signal_connect (entry, "changed",
+		G_CALLBACK (jh_dialog_entry_changed_cb), builder);
 
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start ((GtkBox *)hbox, l2, FALSE, FALSE, 6);
-	gtk_box_pack_start ((GtkBox *)hbox, entry2, FALSE, FALSE, 6);
-	gtk_box_pack_start ((GtkBox *)vbox, hbox, FALSE, FALSE, 6);
-
-	gtk_widget_show_all (vbox);
-	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-	gtk_container_add (GTK_CONTAINER (content_area), vbox);
-	response = gtk_dialog_run ((GtkDialog *)dialog);
-	if (response == GTK_RESPONSE_ACCEPT) {
-		const gchar *name = gtk_entry_get_text ((GtkEntry *)entry1);
-		const gchar *value = gtk_entry_get_text ((GtkEntry *)entry2);
-		gchar *tok;
-		GSList *list = gconf_client_get_list (prefs->gconf, "/apps/evolution/mail/junk/custom_header", GCONF_VALUE_STRING, NULL);
-
-		/* FIXME: Validate the values */
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		name = gtk_entry_get_text (GTK_ENTRY (e_builder_get_widget (builder, "junk-header-name")));
+		value = gtk_entry_get_text (GTK_ENTRY (e_builder_get_widget (builder, "junk-header-content")));
 
+		list = gconf_client_get_list (prefs->gconf, "/apps/evolution/mail/junk/custom_header", GCONF_VALUE_STRING, NULL);
 		tok = g_strdup_printf ("%s=%s", name, value);
 		list = g_slist_append (list, tok);
 		gconf_client_set_list (prefs->gconf, "/apps/evolution/mail/junk/custom_header", GCONF_VALUE_STRING, list, NULL);
-		g_slist_foreach (list, (GFunc)g_free, NULL);
 
+		g_slist_foreach (list, (GFunc) g_free, NULL);
 		g_slist_free (list);
 	}
+
+	g_object_unref (builder);
 	gtk_widget_destroy (dialog);
+
 	jh_tree_refill (prefs);
 }
 
@@ -261,7 +263,7 @@ jh_remove_cb (GtkWidget *widget, gpointer user_data)
 
 		gconf_client_set_list (prefs->gconf, "/apps/evolution/mail/junk/custom_header", GCONF_VALUE_STRING, list, NULL);
 
-		g_slist_foreach (list, (GFunc)g_free, NULL);
+		g_slist_foreach (list, (GFunc) g_free, NULL);
 		g_slist_free (list);
 		g_free (name);
 		g_free (value);
@@ -301,8 +303,8 @@ emmp_header_remove_sensitivity (EMMailerPrefs *prefs)
 	gboolean is_default;
 
 	/* remove button should be sensitive if the currenlty selected entry in the list view
-           is not a default header. if there are no entries, or none is selected, it should be
-           disabled
+	   is not a default header. if there are no entries, or none is selected, it should be
+	   disabled
 	*/
 	if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
 		gtk_tree_model_get (GTK_TREE_MODEL (prefs->header_list_store), &iter,
@@ -423,7 +425,7 @@ emmp_header_add_header (GtkWidget *widget, EMMailerPrefs *prefs)
 	GtkTreeIter iter;
 	const gchar *text = gtk_entry_get_text (prefs->entry_header);
 
-	g_strstrip ((gchar *)text);
+	g_strstrip ((gchar *) text);
 
 	if (text && (strlen (text)>0)) {
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -673,9 +675,12 @@ junk_plugin_changed (GtkWidget *combo, EMMailerPrefs *prefs)
 {
 	gchar *def_plugin;
 	const GList *plugins = mail_session_get_junk_plugins (prefs->session);
+	GtkTreeIter iter;
 
-	def_plugin = gtk_combo_box_text_get_active_text (
-		GTK_COMBO_BOX_TEXT (combo));
+	g_return_if_fail (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter));
+
+	def_plugin = NULL;
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (combo)), &iter, 0, &def_plugin, -1);
 
 	gconf_client_set_string (prefs->gconf, "/apps/evolution/mail/junk/default_plugin", def_plugin, NULL);
 	while (plugins) {
@@ -687,7 +692,7 @@ junk_plugin_changed (GtkWidget *combo, EMMailerPrefs *prefs)
 			CAMEL_SESSION (prefs->session)->junk_plugin =
 				CAMEL_JUNK_PLUGIN (&iface->camel);
 			status = e_plugin_invoke (iface->hook->plugin, iface->validate_binary, NULL) != NULL;
-			if ((gboolean)status == TRUE) {
+			if ((gboolean) status == TRUE) {
 				gchar *text, *html;
 				gtk_image_set_from_stock (prefs->plugin_image, "gtk-dialog-info", GTK_ICON_SIZE_MENU);
 				text = g_strdup_printf (_("%s plugin is available and the binary is installed."), iface->plugin_name);
@@ -708,6 +713,8 @@ junk_plugin_changed (GtkWidget *combo, EMMailerPrefs *prefs)
 		}
 		plugins = plugins->next;
 	}
+
+	g_free (def_plugin);
 }
 
 static void
@@ -729,7 +736,7 @@ junk_plugin_setup (GtkComboBox *combo_box, EMMailerPrefs *prefs)
 					"text", 0,
 					NULL);
 
-	if (!plugins || !g_list_length ((GList *)plugins)) {
+	if (!plugins || !g_list_length ((GList *) plugins)) {
 		GtkTreeIter iter;
 
 		gtk_list_store_append (store, &iter);
@@ -828,7 +835,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs,
 	l = NULL;
 	for (i = 0; i < G_N_ELEMENTS (emmp_items); i++)
 		l = g_slist_prepend (l, &emmp_items[i]);
-	e_config_add_items ((EConfig *)ec, l, NULL, NULL, emmp_free, prefs);
+	e_config_add_items ((EConfig *) ec, l, NULL, NULL, emmp_free, prefs);
 
 	/* General tab */
 
@@ -1055,7 +1062,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs,
 	renderer = gtk_cell_renderer_toggle_new ();
 	g_object_set (renderer, "activatable", TRUE, NULL);
 	g_signal_connect (renderer, "toggled", G_CALLBACK (emmp_header_list_enabled_toggled), prefs);
-        gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (prefs->header_list), -1,
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (prefs->header_list), -1,
 						     "Enabled", renderer,
 						     "active", HEADER_LIST_ENABLED_COLUMN,
 						     NULL);
@@ -1191,7 +1198,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs,
 
 	junk_book_lookup_button_toggled (prefs->junk_book_lookup, prefs);
 
-	prefs->junk_header_list_store = init_junk_tree ((GtkWidget *)prefs->junk_header_tree, prefs);
+	prefs->junk_header_list_store = init_junk_tree ((GtkWidget *) prefs->junk_header_tree, prefs);
 	toggle_button_init (prefs, prefs->junk_header_check, FALSE,
 			    "/apps/evolution/mail/junk/check_custom_header",
 			    G_CALLBACK (custom_junk_button_toggled));
@@ -1203,8 +1210,8 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs,
 
 	/* get our toplevel widget */
 	target = em_config_target_new_prefs (ec, prefs->gconf);
-	e_config_set_target ((EConfig *)ec, (EConfigTarget *)target);
-	toplevel = e_config_create_widget ((EConfig *)ec);
+	e_config_set_target ((EConfig *) ec, (EConfigTarget *) target);
+	toplevel = e_config_create_widget ((EConfig *) ec);
 	gtk_container_add (GTK_CONTAINER (prefs), toplevel);
 }
 
