@@ -40,7 +40,6 @@
 #include "e-util/e-util.h"
 #include "e-util/e-util-private.h"
 
-#include "mail-config.h"
 #include "em-config.h"
 #include "em-folder-selection-button.h"
 
@@ -198,7 +197,9 @@ widget_entry_changed_cb (GtkWidget *widget, gpointer data)
 {
 	const gchar *value;
 	gint port = -1;
-	GConfClient *gconf = mail_config_get_gconf_client ();
+	GConfClient *client;
+
+	client = gconf_client_get_default ();
 
 	/*
 	   Do not change the order of comparison -
@@ -206,21 +207,70 @@ widget_entry_changed_cb (GtkWidget *widget, gpointer data)
 	*/
 	if (GTK_IS_SPIN_BUTTON (widget)) {
 		port = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget));
-		gconf_client_set_int (gconf, (const gchar *)data, port, NULL);
+		gconf_client_set_int (client, (const gchar *) data, port, NULL);
 		d(g_print ("%s:%s: %s is SpinButton: value = [%d]\n", G_STRLOC, G_STRFUNC, (const gchar *)data, port));
 	} else if (GTK_IS_ENTRY (widget)) {
 		value = gtk_entry_get_text (GTK_ENTRY (widget));
-		gconf_client_set_string (gconf, (const gchar *)data, value, NULL);
+		gconf_client_set_string (client, (const gchar *) data, value, NULL);
 		d(g_print ("%s:%s: %s is Entry: value = [%s]\n", G_STRLOC, G_STRFUNC, (const gchar *)data, value));
 	}
 
+	g_object_unref (client);
+}
+
+static void
+ignore_hosts_entry_changed_cb (GtkWidget *widget, const gchar *key)
+{
+	const gchar *value;
+	GSList *lst = NULL;
+	GConfClient *client;
+
+	g_return_if_fail (widget != NULL);
+	g_return_if_fail (key != NULL);
+	g_return_if_fail (GTK_IS_ENTRY (widget));
+
+	/* transform comma-separated list of ignore_hosts to a string-list */
+	value = gtk_entry_get_text (GTK_ENTRY (widget));
+	if (value && *value) {
+		gchar **split = g_strsplit (value, ",", -1);
+
+		if (split) {
+			gint ii;
+
+			for (ii = 0; split[ii]; ii++) {
+				const gchar *tmp = split[ii];
+
+				if (tmp && *tmp) {
+					gchar *val = g_strstrip (g_strdup (tmp));
+
+					if (val && *val)
+						lst = g_slist_append (lst, val);
+					else
+						g_free (val);
+				}
+			}
+		}
+
+		g_strfreev (split);
+	}
+
+	client = gconf_client_get_default ();
+	if (!gconf_client_set_list (client, key, GCONF_VALUE_STRING, lst, NULL)) {
+		/* for cases where migration didn't happen, get rid of the old GConf key and "re-type" it */
+		gconf_client_unset (client, key, NULL);
+		gconf_client_set_list (client, key, GCONF_VALUE_STRING, lst, NULL);
+	}
+	g_object_unref (client);
+
+	g_slist_foreach (lst, (GFunc) g_free, NULL);
+	g_slist_free (lst);
 }
 
 /* plugin meta-data */
 static EMConfigItem emnp_items[] = {
 	{ E_CONFIG_BOOK, (gchar *) "", (gchar *) "network_preferences_toplevel", emnp_widget_glade },
 	{ E_CONFIG_PAGE, (gchar *) "00.general", (gchar *) "vboxNetworkGeneral", emnp_widget_glade },
-	{ E_CONFIG_SECTION, (gchar *) "00.general/00.proxy", (gchar *) "frameProxy", emnp_widget_glade },
+	{ E_CONFIG_SECTION, (gchar *) "00.general/00.proxy", (gchar *) "proxy-vbox", emnp_widget_glade },
 };
 
 static void
@@ -250,14 +300,14 @@ static void
 em_network_prefs_construct (EMNetworkPrefs *prefs)
 {
 	GtkWidget *toplevel;
-	GSList* l;
+	GSList *l, *ignore;
 	gchar *buf;
 	EMConfig *ec;
 	EMConfigTargetPrefs *target;
 	gboolean locked;
 	gint i, val, port;
 
-	prefs->gconf = mail_config_get_gconf_client ();
+	prefs->gconf = gconf_client_get_default ();
 
 	/* Make sure our custom widget classes are registered with
 	 * GType before we load the GtkBuilder definition file. */
@@ -278,7 +328,7 @@ em_network_prefs_construct (EMNetworkPrefs *prefs)
 	l = NULL;
 	for (i = 0; i < G_N_ELEMENTS (emnp_items); i++)
 		l = g_slist_prepend (l, &emnp_items[i]);
-	e_config_add_items ((EConfig *)ec, l, NULL, NULL, emnp_free, prefs);
+	e_config_add_items ((EConfig *) ec, l, NULL, NULL, emnp_free, prefs);
 
 	/* Proxy tab */
 
@@ -356,7 +406,7 @@ em_network_prefs_construct (EMNetworkPrefs *prefs)
 			  G_CALLBACK (widget_entry_changed_cb),
 			  (gpointer) GCONF_E_HTTPS_HOST_KEY);
 	g_signal_connect (prefs->ignore_hosts, "changed",
-			  G_CALLBACK (widget_entry_changed_cb),
+			  G_CALLBACK (ignore_hosts_entry_changed_cb),
 			  (gpointer) GCONF_E_IGNORE_HOSTS_KEY);
 	g_signal_connect (prefs->http_port, "value_changed",
 			  G_CALLBACK (widget_entry_changed_cb),
@@ -391,7 +441,33 @@ em_network_prefs_construct (EMNetworkPrefs *prefs)
 	gtk_entry_set_text (prefs->https_host, buf ? buf : "");
 	g_free (buf);
 
-	buf = gconf_client_get_string (prefs->gconf, GCONF_E_IGNORE_HOSTS_KEY, NULL);
+	buf = NULL;
+	ignore = gconf_client_get_list (prefs->gconf, GCONF_E_IGNORE_HOSTS_KEY, GCONF_VALUE_STRING, NULL);
+	if (ignore) {
+		/* reconstruct comma-separated list */
+		GSList *sl;
+		GString *str = NULL;
+
+		for (sl = ignore; sl; sl = sl->next) {
+			const gchar *value = sl->data;
+
+			if (value && *value) {
+				if (!str) {
+					str = g_string_new (value);
+				} else {
+					g_string_append (str, ",");
+					g_string_append (str, value);
+				}
+			}
+		}
+
+		g_slist_foreach (ignore, (GFunc) g_free, NULL);
+		g_slist_free (ignore);
+
+		if (str)
+			buf = g_string_free (str, FALSE);
+	}
+
 	gtk_entry_set_text (prefs->ignore_hosts, buf ? buf : "");
 	g_free (buf);
 
@@ -404,10 +480,10 @@ em_network_prefs_construct (EMNetworkPrefs *prefs)
 	g_free (buf);
 
 	port = gconf_client_get_int (prefs->gconf, GCONF_E_HTTP_PORT_KEY, NULL);
-	gtk_spin_button_set_value (prefs->http_port, (gdouble)port);
+	gtk_spin_button_set_value (prefs->http_port, (gdouble) port);
 
 	port = gconf_client_get_int (prefs->gconf, GCONF_E_HTTPS_PORT_KEY, NULL);
-	gtk_spin_button_set_value (prefs->https_port, (gdouble)port);
+	gtk_spin_button_set_value (prefs->https_port, (gdouble) port);
 
 #if 0
 	buf = gconf_client_get_string (prefs->gconf, GCONF_E_SOCKS_HOST_KEY, NULL);
@@ -415,7 +491,7 @@ em_network_prefs_construct (EMNetworkPrefs *prefs)
 	g_free (buf);
 
 	port = gconf_client_get_int (prefs->gconf, GCONF_E_SOCKS_PORT_KEY, NULL);
-	gtk_spin_button_set_value (prefs->socks_port, (gdouble)port);
+	gtk_spin_button_set_value (prefs->socks_port, (gdouble) port);
 #endif
 	emnp_set_markups (prefs);
 
@@ -433,8 +509,8 @@ em_network_prefs_construct (EMNetworkPrefs *prefs)
 
 	/* get our toplevel widget */
 	target = em_config_target_new_prefs (ec, prefs->gconf);
-	e_config_set_target ((EConfig *)ec, (EConfigTarget *)target);
-	toplevel = e_config_create_widget ((EConfig *)ec);
+	e_config_set_target ((EConfig *) ec, (EConfigTarget *) target);
+	toplevel = e_config_create_widget ((EConfig *) ec);
 	gtk_container_add (GTK_CONTAINER (prefs), toplevel);
 }
 
