@@ -16,7 +16,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <glib/gi18n-lib.h>
 
 #include <shell/e-shell.h>
@@ -26,6 +29,7 @@
 #include <e-util/e-import.h>
 
 #include <mail/e-mail-backend.h>
+#include <mail/e-mail-local.h>
 #include <mail/em-account-editor.h>
 #include <capplet/settings/mail-capplet-shell.h>
 #include <calendar/gui/calendar-config.h>
@@ -434,15 +438,19 @@ startup_wizard_new_assistant (EStartupWizard *extension)
 	EConfigItem *config_item;
 	GtkWidget *widget;
 	GSList *items = NULL;
+	const gchar *data_dir;
 
 	shell = startup_wizard_get_shell (extension);
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
 
 	backend = E_MAIL_BACKEND (shell_backend);
 	session = e_mail_backend_get_session (backend);
+	data_dir = e_shell_backend_get_data_dir (shell_backend);
+
+	e_mail_local_init (session, data_dir);
 
 	emae = em_account_editor_new (
-		NULL, EMAE_ASSISTANT, session,
+		NULL, EMAE_ASSISTANT, backend,
 		"org.gnome.evolution.mail.config.accountWizard");
 
 	config = E_CONFIG (emae->config);
@@ -592,8 +600,8 @@ startup_wizard_constructed (GObject *object)
 		shell, "event::ready-to-start",
 		G_CALLBACK (startup_wizard_run), extension);
 
-	if (G_OBJECT_CLASS (e_startup_wizard_parent_class)->constructed)
-		G_OBJECT_CLASS (e_startup_wizard_parent_class)->constructed (object);
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (e_startup_wizard_parent_class)->constructed (object);
 }
 
 static void
