@@ -21,11 +21,10 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <glib/gi18n-lib.h>
-#include <glib.h>
 
 #include <gtk/gtk.h>
 
@@ -146,34 +145,53 @@ user_changed_cb (GtkEntry *editable, ESource *source)
 static void
 browse_cal_clicked_cb (GtkButton *button, gpointer user_data)
 {
-	GtkEntry *url, *username;
-	GtkToggleButton *ssl;
-	gchar *new_url;
+	GtkEntry *url, *username, *usermail;
+	GtkToggleButton *ssl, *autoschedule;
+	gchar *new_url, *new_usermail;
+	gboolean new_autoschedule;
 
 	g_return_if_fail (button != NULL);
 
 	url = g_object_get_data (G_OBJECT (button), "caldav-url");
-	username = g_object_get_data (G_OBJECT (button), "caldav-username");
 	ssl = g_object_get_data (G_OBJECT (button), "caldav-ssl");
+	username = g_object_get_data (G_OBJECT (button), "caldav-username");
+	usermail = g_object_get_data (G_OBJECT (button), "caldav-usermail");
+	autoschedule = g_object_get_data (G_OBJECT (button), "caldav-autoschedule");
 
 	g_return_if_fail (url != NULL);
 	g_return_if_fail (GTK_IS_ENTRY (url));
-	g_return_if_fail (username != NULL);
-	g_return_if_fail (GTK_IS_ENTRY (username));
 	g_return_if_fail (ssl != NULL);
 	g_return_if_fail (GTK_IS_TOGGLE_BUTTON (ssl));
+	g_return_if_fail (username != NULL);
+	g_return_if_fail (GTK_IS_ENTRY (username));
+	g_return_if_fail (usermail != NULL);
+	g_return_if_fail (GTK_IS_ENTRY (usermail));
+	g_return_if_fail (autoschedule != NULL);
+	g_return_if_fail (GTK_IS_TOGGLE_BUTTON (autoschedule));
+
+	new_usermail = g_strdup (gtk_entry_get_text (usermail)),
+	new_autoschedule = gtk_toggle_button_get_active (autoschedule);
 
 	new_url = caldav_browse_server (
 		GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (button))),
 		gtk_entry_get_text (url),
 		gtk_entry_get_text (username),
 		gtk_toggle_button_get_active (ssl),
+		&new_usermail,
+		&new_autoschedule,
 		GPOINTER_TO_INT (user_data));
 
 	if (new_url) {
 		gtk_entry_set_text (url, new_url);
 		g_free (new_url);
+
+		if (new_usermail)
+			gtk_entry_set_text (usermail, new_usermail);
+
+		gtk_toggle_button_set_active (autoschedule, new_autoschedule);
 	}
+
+	g_free (new_usermail);
 }
 
 GtkWidget *
@@ -183,8 +201,9 @@ oge_caldav  (EPlugin                    *epl,
 	ECalConfigTargetSource *t = (ECalConfigTargetSource *) data->target;
 	ESource      *source;
 	SoupURI      *suri;
-	GtkWidget    *parent, *location, *ssl, *user, *browse_cal;
+	GtkWidget    *parent, *location, *ssl, *user, *mail, *autoschedule, *browse_cal;
 	gchar        *uri, *username;
+	guint         n_rows;
 
 	source = t->source;
 
@@ -214,25 +233,45 @@ oge_caldav  (EPlugin                    *epl,
 
 	location = e_plugin_util_add_entry (parent, _("_URL:"), NULL, NULL);
 	gtk_entry_set_text (GTK_ENTRY (location), uri);
-	g_signal_connect (G_OBJECT (location), "changed", G_CALLBACK (location_changed_cb), source);
+
+	g_signal_connect (
+		location, "changed",
+		G_CALLBACK (location_changed_cb), source);
 
 	ssl = e_plugin_util_add_check (parent, _("Use _SSL"), source, "ssl", "1", "0");
 
 	user = e_plugin_util_add_entry (parent, _("User_name:"), NULL, NULL);
 	gtk_entry_set_text (GTK_ENTRY (user), username ? username : "");
-	g_signal_connect (G_OBJECT (user), "changed", G_CALLBACK (user_changed_cb), source);
 
-        g_free (uri);
+	g_signal_connect (
+		user, "changed",
+		G_CALLBACK (user_changed_cb), source);
+
+	g_free (uri);
 	g_free (username);
 
+	mail = e_plugin_util_add_entry (parent, _("User e-_mail:"), source, "usermail");
+	autoschedule = e_plugin_util_add_check (
+		parent, _("Server _handles meeting invitations"),
+		source, "autoschedule", "1", "0");
+
 	browse_cal = gtk_button_new_with_mnemonic (_("Brows_e server for a calendar"));
 	gtk_widget_show (browse_cal);
-	gtk_table_attach (GTK_TABLE (parent), browse_cal, 1, 2, GTK_TABLE (parent)->nrows, GTK_TABLE (parent)->nrows + 1, GTK_FILL, 0, 0, 0);
+	g_object_get (parent, "n-rows", &n_rows, NULL);
+	gtk_table_attach (
+		GTK_TABLE (parent), browse_cal, 1, 2,
+		n_rows, n_rows + 1, GTK_FILL, 0, 0, 0);
 
 	g_object_set_data (G_OBJECT (browse_cal), "caldav-url", location);
-	g_object_set_data (G_OBJECT (browse_cal), "caldav-username", user);
 	g_object_set_data (G_OBJECT (browse_cal), "caldav-ssl", ssl);
-	g_signal_connect  (G_OBJECT (browse_cal), "clicked", G_CALLBACK (browse_cal_clicked_cb), GINT_TO_POINTER (t->source_type));
+	g_object_set_data (G_OBJECT (browse_cal), "caldav-username", user);
+	g_object_set_data (G_OBJECT (browse_cal), "caldav-usermail", mail);
+	g_object_set_data (G_OBJECT (browse_cal), "caldav-autoschedule", autoschedule);
+
+	g_signal_connect  (
+		browse_cal, "clicked",
+		G_CALLBACK (browse_cal_clicked_cb),
+		GINT_TO_POINTER (t->source_type));
 
 	e_plugin_util_add_refresh (parent, _("Re_fresh:"), source, "refresh");
 
