@@ -158,7 +158,7 @@ org_gnome_evolution_readdbx_supported (EPlugin *epl, EImportTarget *target)
 		return FALSE;
 	}
 
-	s = (EImportTargetURI *)target;
+	s = (EImportTargetURI *) target;
 
 	if (s->uri_src == NULL) {
 		return TRUE;
@@ -203,7 +203,6 @@ org_gnome_evolution_readdbx_getwidget (EImport *ei,
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
-	EMailSession *session;
 	GtkWidget *hbox, *w;
 	GtkLabel *label;
 	gchar *select_uri = NULL;
@@ -220,46 +219,57 @@ org_gnome_evolution_readdbx_getwidget (EImport *ei,
 		view = e_shell_window_get_active_view (shell_window);
 
 		if (view && g_str_equal (view, "mail")) {
-			EShellView *shell_view = e_shell_window_get_shell_view (shell_window, view);
+			EShellView *shell_view;
+			EMFolderTree *folder_tree = NULL;
+			EShellSidebar *shell_sidebar;
 
-			if (shell_view) {
-				EMFolderTree *folder_tree = NULL;
-				EShellSidebar *shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
+			shell_view = e_shell_window_get_shell_view (
+				shell_window, view);
 
-				g_object_get (shell_sidebar, "folder-tree", &folder_tree, NULL);
+			shell_sidebar = e_shell_view_get_shell_sidebar (
+				shell_view);
 
-				if (folder_tree)
-					select_uri = em_folder_tree_get_selected_uri (folder_tree);
-			}
+			g_object_get (
+				shell_sidebar, "folder-tree",
+				&folder_tree, NULL);
+
+			select_uri = em_folder_tree_get_selected_uri (
+				folder_tree);
 		}
 	}
 #endif
-	if (!select_uri)
-		select_uri = g_strdup (e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_INBOX));
+	if (!select_uri) {
+		const gchar *local_inbox_uri;
+		local_inbox_uri = e_mail_local_get_folder_uri (
+			E_MAIL_LOCAL_FOLDER_INBOX);
+		select_uri = g_strdup (local_inbox_uri);
+	}
 
 	hbox = gtk_hbox_new (FALSE, 0);
 
 	w = gtk_label_new_with_mnemonic (_("_Destination folder:"));
-	gtk_box_pack_start ((GtkBox *)hbox, w, FALSE, TRUE, 6);
+	gtk_box_pack_start ((GtkBox *) hbox, w, FALSE, TRUE, 6);
 
 	label = GTK_LABEL (w);
 
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
-	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
 
 	w = em_folder_selection_button_new (
-		session, _("Select folder"),
+		E_MAIL_BACKEND (shell_backend),
+		_("Select folder"),
 		_("Select folder to import into"));
 
 	gtk_label_set_mnemonic_widget (label, w);
-	em_folder_selection_button_set_selection ((EMFolderSelectionButton *)w, select_uri);
-	folder_selected ((EMFolderSelectionButton *)w, (EImportTargetURI *)target);
+	em_folder_selection_button_set_selection (
+		EM_FOLDER_SELECTION_BUTTON (w), select_uri);
+	folder_selected (
+		EM_FOLDER_SELECTION_BUTTON (w), (EImportTargetURI *) target);
 	g_signal_connect (w, "selected", G_CALLBACK(folder_selected), target);
-	gtk_box_pack_start ((GtkBox *)hbox, w, FALSE, TRUE, 6);
+	gtk_box_pack_start ((GtkBox *) hbox, w, FALSE, TRUE, 6);
 
 	w = gtk_vbox_new (FALSE, 0);
-	gtk_box_pack_start ((GtkBox *)w, hbox, FALSE, FALSE, 0);
+	gtk_box_pack_start ((GtkBox *) w, hbox, FALSE, FALSE, 0);
 	gtk_widget_show_all (w);
 
 	g_free (select_uri);
@@ -577,10 +587,10 @@ dbx_import_file (DbxImporter *m)
 	gint missing = 0;
 	m->status_what = NULL;
 	filename = g_filename_from_uri (
-		((EImportTargetURI *)m->target)->uri_src, NULL, NULL);
+		((EImportTargetURI *) m->target)->uri_src, NULL, NULL);
 
 	/* Destination folder, was set in our widget */
-	m->parent_uri = g_strdup (((EImportTargetURI *)m->target)->uri_dest);
+	m->parent_uri = g_strdup (((EImportTargetURI *) m->target)->uri_dest);
 
 	cancellable = e_activity_get_cancellable (m->base.activity);
 
@@ -602,7 +612,7 @@ dbx_import_file (DbxImporter *m)
 	camel_folder_freeze (folder);
 
 	filename = g_filename_from_uri (
-		((EImportTargetURI *)m->target)->uri_src, NULL, NULL);
+		((EImportTargetURI *) m->target)->uri_src, NULL, NULL);
 	m->dbx_fd = g_open (filename, O_RDONLY, 0);
 	g_free (filename);
 
@@ -657,7 +667,7 @@ dbx_import_file (DbxImporter *m)
 
 		msg = camel_mime_message_new ();
 		if (!camel_mime_part_construct_from_parser_sync (
-			(CamelMimePart *)msg, mp, NULL, NULL)) {
+			(CamelMimePart *) msg, mp, NULL, NULL)) {
 			/* set exception? */
 			g_object_unref (msg);
 			g_object_unref (mp);
@@ -707,7 +717,7 @@ dbx_import_import (DbxImporter *m,
 static void
 dbx_import_imported (DbxImporter *m)
 {
-	e_import_complete (m->target->import, (EImportTarget *)m->target);
+	e_import_complete (m->target->import, (EImportTarget *) m->target);
 }
 
 static void
