@@ -25,7 +25,6 @@
 #endif
 
 #include <string.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
@@ -41,6 +40,7 @@
 #include <mail/mail-tools.h>
 #include <mail/mail-mt.h>
 #include <libedataserver/e-account-list.h>
+#include <e-util/e-account-utils.h>
 #include <e-util/e-alert-dialog.h>
 #include <e-util/e-mktemp.h>
 #include <calendar/gui/itip-utils.h>
@@ -229,7 +229,7 @@ find_to_address (struct _itip_puri *pitip, icalcomponent *ical_comp, icalparamet
 {
 	EIterator *it;
 
-	it = e_list_get_iterator ((EList *)pitip->accounts);
+	it = e_list_get_iterator ((EList *) pitip->accounts);
 
 	if (!pitip->to_address && pitip->msg && pitip->folder) {
 		EAccount *account = em_utils_guess_account (pitip->msg, pitip->folder);
@@ -387,7 +387,7 @@ find_from_address (struct _itip_puri *pitip, icalcomponent *ical_comp)
 	if (param)
 		pitip->from_name = g_strdup (icalparameter_get_cn (param));
 
-	it = e_list_get_iterator ((EList *)pitip->accounts);
+	it = e_list_get_iterator ((EList *) pitip->accounts);
 	while (e_iterator_is_valid (it)) {
 		const EAccount *account = e_iterator_get (it);
 
@@ -834,7 +834,7 @@ find_server (struct _itip_puri *pitip, ECalComponent *comp)
 
 	parent_store = camel_folder_get_parent_store (pitip->folder);
 
-	url = CAMEL_SERVICE (parent_store)->url;
+	url = camel_service_get_camel_url (CAMEL_SERVICE (parent_store));
 	uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
 
 	itip_view_set_buttons_sensitive (ITIP_VIEW (pitip->view), FALSE);
@@ -964,7 +964,7 @@ change_status (icalcomponent *ical_comp, const gchar *address, icalparameter_par
 		} else {
 			EAccount *a;
 
-			a = itip_addresses_get_default ();
+			a = e_get_default_account ();
 
 			prop = icalproperty_new_attendee (a->id->address);
 			icalcomponent_add_property (ical_comp, prop);
@@ -1010,7 +1010,7 @@ message_foreach_part (CamelMimePart *part, GSList **part_list)
 			message_foreach_part (part, part_list);
 		}
 	} else if (CAMEL_IS_MIME_MESSAGE (containee)) {
-		message_foreach_part ((CamelMimePart *)containee, part_list);
+		message_foreach_part ((CamelMimePart *) containee, part_list);
 	}
 }
 
@@ -1179,7 +1179,7 @@ update_item (struct _itip_puri *pitip, ItipViewResponse response)
 			alarms = e_cal_component_get_alarm_uids (real_comp);
 
 			for (l = alarms; l; l = l->next) {
-				alarm = e_cal_component_get_alarm (real_comp, (const gchar *)l->data);
+				alarm = e_cal_component_get_alarm (real_comp, (const gchar *) l->data);
 
 				if (alarm) {
 					ECalComponentAlarm *aclone = e_cal_component_alarm_clone (alarm);
@@ -2259,9 +2259,8 @@ in_proper_folder (CamelFolder *folder)
 	EMailBackend *backend;
 	EMailSession *session;
 	MailFolderCache *folder_cache;
-	const gchar *folder_uri;
 	gboolean res = TRUE;
-	gint flags = 0;
+	CamelFolderInfoFlags flags = 0;
 
 	if (!folder)
 		return FALSE;
@@ -2272,8 +2271,6 @@ in_proper_folder (CamelFolder *folder)
 	session = e_mail_backend_get_session (backend);
 	folder_cache = e_mail_session_get_folder_cache (session);
 
-	folder_uri = camel_folder_get_uri (folder);
-
 	if (mail_folder_cache_get_folder_info_flags (folder_cache, folder, &flags)) {
 		/* it should be neither trash nor junk folder, */
 		res = ((flags & CAMEL_FOLDER_TYPE_TRASH) !=  CAMEL_FOLDER_TYPE_TRASH &&
@@ -2283,17 +2280,17 @@ in_proper_folder (CamelFolder *folder)
 			  /* or any other virtual folder */
 			  CAMEL_IS_VEE_FOLDER (folder) ||
 			  /* or anything else except of sent, outbox or drafts folder */
-			  (!em_utils_folder_is_sent (folder, folder_uri) &&
-			   !em_utils_folder_is_outbox (folder, folder_uri) &&
-			   !em_utils_folder_is_drafts (folder, folder_uri))
+			  (!em_utils_folder_is_sent (folder) &&
+			   !em_utils_folder_is_outbox (folder) &&
+			   !em_utils_folder_is_drafts (folder))
 			));
 	} else {
 		/* cannot check for Inbox folder here */
 		res = (folder->folder_flags & (CAMEL_FOLDER_IS_TRASH | CAMEL_FOLDER_IS_JUNK)) == 0 && (
 		      (CAMEL_IS_VEE_FOLDER (folder)) || (
-		      !em_utils_folder_is_sent (folder, folder_uri) &&
-		      !em_utils_folder_is_outbox (folder, folder_uri) &&
-		      !em_utils_folder_is_drafts (folder, folder_uri)));
+		      !em_utils_folder_is_sent (folder) &&
+		      !em_utils_folder_is_outbox (folder) &&
+		      !em_utils_folder_is_drafts (folder)));
 	}
 
 	return res;
@@ -2320,10 +2317,10 @@ format_itip_object (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject
 	shell = e_shell_get_default ();
 	shell_settings = e_shell_get_shell_settings (shell);
 
-	info = (struct _itip_puri *) em_format_find_puri ((EMFormat *)efh, pobject->classid);
+	info = (struct _itip_puri *) em_format_find_puri ((EMFormat *) efh, pobject->classid);
 
 	/* Accounts */
-	info->accounts = itip_addresses_get ();
+	info->accounts = e_get_account_list ();
 
 	/* Source Lists and open ecal clients */
 	for (i = 0; i < E_CAL_SOURCE_TYPE_LAST; i++) {
@@ -2343,7 +2340,7 @@ format_itip_object (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject
 	gtk_container_add (GTK_CONTAINER (eb), info->view);
 	gtk_widget_show (info->view);
 
-	response_enabled = in_proper_folder (((EMFormat*)efh)->folder);
+	response_enabled = in_proper_folder (((EMFormat*) efh)->folder);
 
 	if (!response_enabled) {
 		itip_view_set_mode (ITIP_VIEW (info->view), ITIP_VIEW_MODE_HIDE_ALL);
@@ -2692,7 +2689,7 @@ format_itip (EPlugin *ep, EMFormatHookTarget *target)
 	    !camel_folder_get_message_user_flag (target->format->folder, target->format->uid, "$has_cal"))
 		camel_folder_set_message_user_flag (target->format->folder, target->format->uid, "$has_cal", TRUE);
 
-	puri = (struct _itip_puri *)em_format_add_puri (target->format, sizeof (struct _itip_puri), classid, target->part, itip_attachment_frame);
+	puri = (struct _itip_puri *) em_format_add_puri (target->format, sizeof (struct _itip_puri), classid, target->part, itip_attachment_frame);
 
 	em_format_html_add_pobject ((EMFormatHTML *) target->format, sizeof (EMFormatHTMLPObject), classid, target->part, format_itip_object);
 
@@ -2893,7 +2890,7 @@ itip_attachment_frame (EMFormat *emf,
                        EMFormatPURI *puri,
                        GCancellable *cancellable)
 {
-	struct _itip_puri *info = (struct _itip_puri *)puri;
+	struct _itip_puri *info = (struct _itip_puri *) puri;
 
 	info->handle->handler (
 		emf, stream, info->puri.part,
