@@ -25,7 +25,7 @@
 /* Convert a mail message into a task */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <glib/gi18n-lib.h>
@@ -384,6 +384,7 @@ set_attachments (ECal *client, ECalComponent *comp, CamelMimeMessage *message)
 	/* XXX Does this take ownership of the list? */
 	e_cal_component_set_attachment_list (comp, uri_list);
 
+	e_attachment_store_remove_all (store);
 	g_object_unref (destination);
 	g_object_unref (store);
 }
@@ -432,7 +433,7 @@ report_error_idle (const gchar *format, const gchar *param)
 	err->param = g_strdup (param);
 
 	g_usleep (250);
-	g_idle_add ((GSourceFunc)do_report_error, err);
+	g_idle_add ((GSourceFunc) do_report_error, err);
 }
 
 struct _manage_comp
@@ -868,7 +869,7 @@ do_mail_to_event (AsyncData *data)
 
 		if (mcs) {
 			/* process this in the main thread, as we may ask user too */
-			g_idle_add ((GSourceFunc)do_manage_comp_idle, mcs);
+			g_idle_add ((GSourceFunc) do_manage_comp_idle, mcs);
 		}
 	}
 
