@@ -20,11 +20,6 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <glib.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <libedataserver/e-source.h>
@@ -42,7 +37,10 @@ struct _FormatHandler
 
 	gpointer data;
 
-	void (*save) (FormatHandler *handler, ESourceSelector *selector, ECalSourceType type, gchar *dest_uri);
+	void	(*save)		(FormatHandler *handler,
+				 ESourceSelector *selector,
+				 ECalSourceType type,
+				 gchar *dest_uri);
 };
 
 FormatHandler *csv_format_handler_new (void);
