@@ -19,9 +19,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-attachment-view.h"
 
-#include <config.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
