@@ -20,7 +20,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <stdlib.h>
 #include <string.h>
@@ -48,7 +50,9 @@ etssv_add       (ETableSubsetVariable *etssv,
 
 	if (etss->n_map + 1 > etssv->n_vals_allocated) {
 		etssv->n_vals_allocated += INCREMENT_AMOUNT;
-		etss->map_table = g_realloc (etss->map_table, etssv->n_vals_allocated * sizeof (gint));
+		etss->map_table = g_realloc (
+			etss->map_table,
+			etssv->n_vals_allocated * sizeof (gint));
 	}
 
 	etss->map_table[etss->n_map++] = row;
@@ -69,7 +73,9 @@ etssv_add_array (ETableSubsetVariable *etssv,
 
 	if (etss->n_map + count > etssv->n_vals_allocated) {
 		etssv->n_vals_allocated += MAX (INCREMENT_AMOUNT, count);
-		etss->map_table = g_realloc (etss->map_table, etssv->n_vals_allocated * sizeof (gint));
+		etss->map_table = g_realloc (
+			etss->map_table,
+			etssv->n_vals_allocated * sizeof (gint));
 	}
 	for (i = 0; i < count; i++)
 		etss->map_table[etss->n_map++] = array[i];
@@ -90,7 +96,9 @@ etssv_add_all   (ETableSubsetVariable *etssv)
 	rows = e_table_model_row_count (etss->source);
 	if (etss->n_map + rows > etssv->n_vals_allocated) {
 		etssv->n_vals_allocated += MAX (INCREMENT_AMOUNT, rows);
-		etss->map_table = g_realloc (etss->map_table, etssv->n_vals_allocated * sizeof (gint));
+		etss->map_table = g_realloc (
+			etss->map_table,
+			etssv->n_vals_allocated * sizeof (gint));
 	}
 	for (i = 0; i < rows; i++)
 		etss->map_table[etss->n_map++] = i;
@@ -109,7 +117,10 @@ etssv_remove    (ETableSubsetVariable *etssv,
 	for (i = 0; i < etss->n_map; i++) {
 		if (etss->map_table[i] == row) {
 			e_table_model_pre_change (etm);
-			memmove (etss->map_table + i, etss->map_table + i + 1, (etss->n_map - i - 1) * sizeof (gint));
+			memmove (
+				etss->map_table + i,
+				etss->map_table + i + 1,
+				(etss->n_map - i - 1) * sizeof (gint));
 			etss->n_map--;
 
 			e_table_model_row_deleted (etm, i);
@@ -213,7 +224,7 @@ e_table_subset_variable_clear (ETableSubsetVariable *etssv)
 	e_table_model_pre_change (etm);
 	etss->n_map = 0;
 	g_free (etss->map_table);
-	etss->map_table = (gint *)g_new (unsigned int, 1);
+	etss->map_table = (gint *) g_new (unsigned int, 1);
 	etssv->n_vals_allocated = 1;
 
 	e_table_model_changed (etm);
