@@ -20,7 +20,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -775,8 +777,8 @@ tree_canvas_reflow_idle (ETree *e_tree)
 		e_tree->priv->item,
 		"height", &height, "width", &width, NULL);
 
-	height = MAX ((gint)height, allocation.height);
-	width = MAX ((gint)width, allocation.width);
+	height = MAX ((gint) height, allocation.height);
+	width = MAX ((gint) width, allocation.width);
 
 	/* I have no idea why this needs to be -1, but it works. */
 	gnome_canvas_get_scroll_region (
@@ -815,7 +817,7 @@ tree_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc,
 	g_object_get (e_tree->priv->item,
 		      "height", &height,
 		      NULL);
-	height = MAX ((gint)height, alloc->height);
+	height = MAX ((gint) height, alloc->height);
 
 	g_object_set (e_tree->priv->item,
 		      "width", width,
@@ -1255,7 +1257,8 @@ e_tree_set_state_object (ETree *e_tree, ETableState *state)
 			     NULL);
 
 	if (e_tree->priv->etta)
-		e_tree_table_adapter_set_sort_info (e_tree->priv->etta, e_tree->priv->sort_info);
+		e_tree_table_adapter_set_sort_info (
+			e_tree->priv->etta, e_tree->priv->sort_info);
 
 	e_tree_state_change (e_tree);
 }
@@ -2063,11 +2066,17 @@ e_tree_get_next_row      (ETree *e_tree,
 			return e_sorter_sorted_to_model (E_SORTER (e_tree->priv->sorter), i);
 		} else
 			return -1;
-	} else
-		if (model_row < e_table_model_row_count (E_TABLE_MODEL (e_tree->priv->etta)) - 1)
+	} else {
+		gint row_count;
+
+		row_count = e_table_model_row_count (
+			E_TABLE_MODEL (e_tree->priv->etta));
+
+		if (model_row < row_count - 1)
 			return model_row + 1;
 		else
 			return -1;
+	}
 }
 
 gint
@@ -2967,7 +2976,8 @@ scroll_timeout (gpointer data)
 static void
 scroll_on (ETree *et, guint scroll_direction)
 {
-	if (et->priv->scroll_idle_id == 0 || scroll_direction != et->priv->scroll_direction) {
+	if (et->priv->scroll_idle_id == 0 ||
+			scroll_direction != et->priv->scroll_direction) {
 		if (et->priv->scroll_idle_id != 0)
 			g_source_remove (et->priv->scroll_idle_id);
 		et->priv->scroll_direction = scroll_direction;
@@ -3041,7 +3051,8 @@ collapse_drag (ETree *et, ETreePath drop)
 {
 	GList *list;
 
-	/* We only want to leave open parents of the node dropped in.  Not the node itself. */
+	/* We only want to leave open parents of the node dropped in.
+	 * Not the node itself. */
 	if (drop) {
 		drop = e_tree_model_node_get_parent (et->priv->model, drop);
 	}
@@ -3097,7 +3108,9 @@ context_connect (ETree *et, GdkDragContext *context)
 		return;
 
 	if (et->priv->last_drop_context)
-		g_object_weak_unref (G_OBJECT (et->priv->last_drop_context), context_destroyed, et);
+		g_object_weak_unref (
+			G_OBJECT (et->priv->last_drop_context),
+			context_destroyed, et);
 	else
 		g_object_ref (et);
 
